@@ -151,7 +151,7 @@ CREATE INDEX node_configlog_configlog_1 on node_configlog (conflogid);
 CREATE INDEX node_configlog_configlog_2 on node_configlog (nodeid,tablename);
 
 CREATE TABLE history_str_sync (
-	id		serial			,
+	id		bigint unsigned not null auto_increment unique			,
 	nodeid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	clock		integer		DEFAULT '0'	NOT NULL,
@@ -161,7 +161,7 @@ CREATE TABLE history_str_sync (
 CREATE INDEX history_str_sync_1 on history_str_sync (nodeid,id);
 
 CREATE TABLE history_sync (
-	id		serial			,
+	id		bigint unsigned not null auto_increment unique			,
 	nodeid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	clock		integer		DEFAULT '0'	NOT NULL,
@@ -171,7 +171,7 @@ CREATE TABLE history_sync (
 CREATE INDEX history_sync_1 on history_sync (nodeid,id);
 
 CREATE TABLE history_uint_sync (
-	id		serial			,
+	id		bigint unsigned not null auto_increment unique			,
 	nodeid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	clock		integer		DEFAULT '0'	NOT NULL,
@@ -517,6 +517,7 @@ CREATE TABLE items_applications (
 	PRIMARY KEY (itemappid)
 ) type=InnoDB;
 CREATE INDEX items_applications_1 on items_applications (applicationid,itemid);
+CREATE INDEX items_applications_2 on items_applications (itemid);
 
 CREATE TABLE mappings (
 	mappingid		bigint unsigned		DEFAULT '0'	NOT NULL,
