@@ -158,6 +158,19 @@ CREATE TABLE history_str_sync (
 	value		varchar2(255)		DEFAULT ''	,
 	PRIMARY KEY (id)
 );
+CREATE SEQUENCE history_str_sync_id
+START WITH 1
+INCREMENT BY 1
+NOMAXVALUE;
+CREATE TRIGGER history_str_sync_trigger
+BEFORE INSERT ON history_str_sync
+FOR EACH ROW
+BEGIN
+	IF (:new.id IS NULL OR :new.id = 0) THEN
+		SELECT history_str_sync_id.nextval INTO :new.id FROM dual;
+	END IF;
+END;
+/
 CREATE INDEX history_str_sync_1 on history_str_sync (nodeid,id);
 
 CREATE TABLE history_sync (
@@ -168,6 +181,19 @@ CREATE TABLE history_sync (
 	value		number(20,4)		DEFAULT '0.0000'	NOT NULL,
 	PRIMARY KEY (id)
 );
+CREATE SEQUENCE history_sync_id
+START WITH 1
+INCREMENT BY 1
+NOMAXVALUE;
+CREATE TRIGGER history_sync_trigger
+BEFORE INSERT ON history_sync
+FOR EACH ROW
+BEGIN
+	IF (:new.id IS NULL OR :new.id = 0) THEN
+		SELECT history_sync_id.nextval INTO :new.id FROM dual;
+	END IF;
+END;
+/
 CREATE INDEX history_sync_1 on history_sync (nodeid,id);
 
 CREATE TABLE history_uint_sync (
@@ -178,6 +204,19 @@ CREATE TABLE history_uint_sync (
 	value		number(20)		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (id)
 );
+CREATE SEQUENCE history_uint_sync_id
+START WITH 1
+INCREMENT BY 1
+NOMAXVALUE;
+CREATE TRIGGER history_uint_sync_trigger
+BEFORE INSERT ON history_uint_sync
+FOR EACH ROW
+BEGIN
+	IF (:new.id IS NULL OR :new.id = 0) THEN
+		SELECT history_uint_sync_id.nextval INTO :new.id FROM dual;
+	END IF;
+END;
+/
 CREATE INDEX history_uint_sync_1 on history_uint_sync (nodeid,id);
 
 CREATE TABLE services_times (
