@@ -45,12 +45,17 @@ include_once "include/page_header.php";
 	check_fields($fields);
 ?>
 <?php
+	if(! (DBfetch(DBselect('select graphid from graphs where graphid='.$_REQUEST['graphid']))) )
+	{
+		show_error_message(S_NO_GRAPH_DEFINED);
+
+	}
+
 	$denyed_hosts = get_accessible_hosts_by_user($USER_DETAILS, PERM_READ_ONLY, PERM_MODE_LT);
 	
 	if( !($db_data = DBfetch(DBselect("select g.*,h.host,h.hostid from graphs g left join graphs_items gi on g.graphid=gi.graphid ".
 		" left join items i on gi.itemid=i.itemid left join hosts h on i.hostid=h.hostid ".
 		" where g.graphid=".$_REQUEST["graphid"].
-		/* " and ".DBid2nodeid("g.graphid")."=".$ZBX_CURNODEID. */ /* NOTE: the chart can display any accesiable graph! */
 		" and ( h.hostid not in (".$denyed_hosts.") OR h.hostid is NULL) "))))
 	{
 		access_deny();
