@@ -38,12 +38,16 @@ include_once "include/page_header.php";
 	check_fields($fields);
 ?>
 <?php
+	if(! (DBfetch(DBselect('select serviceid from services where serviceid='.$_REQUEST["serviceid"]))) )
+	{
+		fatal_error(S_NO_IT_SERVICE_DEFINED);
+	}
+
 	$denyed_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_MODE_LT);
 	
 	if( !($service = DBfetch(DBselect("select s.* from services s left join triggers t on s.triggerid=t.triggerid ".
 		" left join functions f on t.triggerid=f.triggerid left join items i on f.itemid=i.itemid ".
 		" where (i.hostid is NULL or i.hostid not in (".$denyed_hosts.")) ".
-		/* " and ".DBid2nodeid("s.serviceid")."=".$ZBX_CURNODEID. */ /* NOTE: allow displaying all accessiables services */
 		" and s.serviceid=".$_REQUEST["serviceid"]
 		))))
 	{
