@@ -28,8 +28,7 @@
         	$page["type"] = PAGE_TYPE_XML;
         	$page["file"] = "zabbix_export.xml";
 	}
-	else
-	{
+	else{
 	        $page["title"] = "S_EXPORT_IMPORT";
         	$page["file"] = "exp_imp.php";
 	}
@@ -133,6 +132,8 @@ include_once "include/page_header.php";
 	}
 
 	$form = new CForm();
+	$form->SetMethod('get');
+	
 	$cmbConfig = new CComboBox('config', $config, 'submit()');
 	$cmbConfig->AddItem(0, S_EXPORT);
 	$cmbConfig->AddItem(1, S_IMPORT);
@@ -207,10 +208,10 @@ include_once "include/page_header.php";
 								' where t.triggerid=f.triggerid and f.itemid=i.itemid'.
 								' group by f.triggerid, i.hostid, t.description',
 					S_GRAPH		=> !isset($graphs[$host['hostid']]) ? null :
-								'select g.name as info, i.hostid, count(distinct i.hostid) as cnt'.
+								'select MIN(g.name) as info, i.hostid, count(distinct i.hostid) as cnt'.
 								' from graphs_items gi, items i, graphs g '.
 								' where g.graphid=gi.graphid and gi.itemid=i.itemid'.
-								' group by gi.graphid, i.hostid'
+								' group by gi.graphid, i.hostid '
 
 					);
 				foreach($sqls as $el_type => $sql)
@@ -220,7 +221,7 @@ include_once "include/page_header.php";
 					$db_els = DBselect($sql);
 					while($el = DBfetch($db_els))
 					{
-						if($el['cnt'] != 1 || $el['hostid'] != $host['hostid']) continue;
+						if($el['cnt'] != 1 || (bccomp($el['hostid'] , $host['hostid']) != 0)) continue;
 						$el_table->AddRow(array($el_type, $el['info']));
 					}
 				}
@@ -248,8 +249,7 @@ include_once "include/page_header.php";
 			
 			$table->ShowEnd();
 		}
-		else
-		{
+		else{
 	/* table HOSTS */
 			$form = new CForm(null,'post');
 			$form->SetName('hosts');
@@ -258,17 +258,18 @@ include_once "include/page_header.php";
 			
 			$cmbGroups = new CComboBox("groupid",get_request("groupid",0),"submit()");
 			$cmbGroups->AddItem(0,S_ALL_SMALL);
-			$result=DBselect("select distinct g.groupid,g.name from groups g,hosts_groups hg,hosts h".
-					" where h.hostid in (".$available_hosts.") ".
-					" and g.groupid=hg.groupid and h.hostid=hg.hostid".
-					" order by g.name");
-			while($row=DBfetch($result))
-			{
+			$result=DBselect('select distinct g.groupid,g.name '.
+					' from groups g,hosts_groups hg,hosts h'.
+					' where h.hostid in ('.$available_hosts.') '.
+						' and g.groupid=hg.groupid '.
+						' and h.hostid=hg.hostid '.
+					' order by g.name');
+			while($row=DBfetch($result)){
 				$cmbGroups->AddItem($row["groupid"],$row["name"]);
-				if($row["groupid"] == $_REQUEST["groupid"]) $correct_host = 1;
+				if((bccomp($row["groupid"] , $_REQUEST["groupid"])==0)) $correct_host = 1;
 			}
-			if(!isset($correct_host))
-			{
+			
+			if(!isset($correct_host)){
 				unset($_REQUEST["groupid"]);
 				$cmbGroups->SetValue(0);
 			}
@@ -297,19 +298,22 @@ include_once "include/page_header.php";
 				*/
 				));
 		
-			$sql = "select h.* from";
-			if(isset($_REQUEST["groupid"]))
-			{
-				$sql .= " hosts h,hosts_groups hg where";
-				$sql .= " hg.groupid=".$_REQUEST["groupid"]." and hg.hostid=h.hostid and";
-			} else  $sql .= " hosts h where";
-			$sql .=	" h.hostid in (".$available_hosts.") ".
-				" order by h.host";
+			$sql = 'select h.* from';
+			if(isset($_REQUEST['groupid'])){
+				$sql .= ' hosts h,hosts_groups hg ';
+				$sql .= ' where hg.groupid='.$_REQUEST['groupid'].' and hg.hostid=h.hostid and';
+			} 
+			else{  
+				$sql .= ' hosts h where';
+			}
+			
+			$sql .=	' h.hostid in ('.$available_hosts.') '.
+				' order by h.host';
 
 			$result=DBselect($sql);
 		
-			while($row=DBfetch($result))
-			{
+			while($row=DBfetch($result)){
+			
 				$host=new CCol(array(
 					new CCheckBox('hosts['.$row['hostid'].']',
 						isset($hosts[$row['hostid']]) || !isset($update),
@@ -320,9 +324,11 @@ include_once "include/page_header.php";
 				
 				if($row["status"] == HOST_STATUS_MONITORED){
 					$status=new CSpan(S_MONITORED, "off");
-				} else if($row["status"] == HOST_STATUS_NOT_MONITORED) {
+				} 
+				else if($row["status"] == HOST_STATUS_NOT_MONITORED) {
 					$status=new CSpan(S_NOT_MONITORED, "on");
-				} else if($row["status"] == HOST_STATUS_TEMPLATE)
+				} 
+				else if($row["status"] == HOST_STATUS_TEMPLATE)
 					$status=new CCol(S_TEMPLATE,"unknown");
 				else if($row["status"] == HOST_STATUS_DELETED)
 					$status=new CCol(S_DELETED,"unknown");
@@ -331,15 +337,13 @@ include_once "include/page_header.php";
 				
 				/* calculate items */
 				$item_cnt = DBfetch(DBselect('select count(itemid) as cnt from items where hostid='.$row['hostid']));
-				if($item_cnt['cnt'] > 0)
-				{
+				if($item_cnt['cnt'] > 0){
 					$item_cnt = array(new CCheckBox('items['.$row['hostid'].']',
 							isset($items[$row['hostid']]) || !isset($update),
 							NULL,true),
 						$item_cnt['cnt']);
 				}
-				else
-				{
+				else{
 					$item_cnt = '-';
 				}
 				
@@ -347,7 +351,7 @@ include_once "include/page_header.php";
 				$trigger_cnt = 0;
 				$db_triggers = DBselect('select f.triggerid, i.hostid, count(distinct i.hostid) as cnt from functions f, items i '.
 					' where f.itemid=i.itemid group by f.triggerid, i.hostid');
-				while($db_tr = DBfetch($db_triggers)) if($db_tr['cnt'] == 1 && $db_tr['hostid'] == $row['hostid']) $trigger_cnt++;
+				while($db_tr = DBfetch($db_triggers)) if($db_tr['cnt'] == 1 && (bccomp($db_tr['hostid'] , $row['hostid'])==0)) $trigger_cnt++;
 				if($trigger_cnt > 0)
 				{
 					$trigger_cnt = array(new CCheckBox('triggers['.$row['hostid'].']',
@@ -365,7 +369,7 @@ include_once "include/page_header.php";
 				$db_graphs = DBselect('select gi.graphid, i.hostid, count(distinct i.hostid) as cnt'.
 					' from graphs_items gi, items i '.
 					' where gi.itemid=i.itemid group by gi.graphid, i.hostid');
-				while($db_tr = DBfetch($db_graphs)) if($db_tr['cnt'] == 1 && $db_tr['hostid'] == $row['hostid']) $graph_cnt++;
+				while($db_tr = DBfetch($db_graphs)) if($db_tr['cnt'] == 1 && (bccomp($db_tr['hostid'] , $row['hostid'])==0)) $graph_cnt++;
 				if($graph_cnt > 0)
 				{
 					$graph_cnt = array(new CCheckBox('graphs['.$row['hostid'].']',
@@ -380,21 +384,19 @@ include_once "include/page_header.php";
 				
 				/* $screens = 0; */
 
-				if($row["status"] == HOST_STATUS_TEMPLATE)
-				{
+				if($row["status"] == HOST_STATUS_TEMPLATE){
 					$ip = $dns = $port = '-';
 				}
-				else
-				{
-					$ip = $row["ip"];
-					$dns = $row["dns"];
+				else{
+					$ip = (empty($row["ip"]))?'-':$row["ip"];
+					$dns = (empty($row["dns"]))?'-':$row["dns"];
 
 					if($row["useip"]==1)
 						$ip = bold($ip);
 					else
 						$dns = bold($dns);
 
-					$port = $row["port"];
+					$port = (empty($row["port"]))?'-':$row["port"];
 				}
 
 				$table->AddRow(array(
