@@ -54,8 +54,7 @@ include_once "include/page_header.php";
 		"filter_task"=>	array(T_ZBX_STR, O_OPT,	 null,	
 			IN(FILTER_TAST_SHOW.','.FILTER_TAST_HIDE.','.FILTER_TAST_MARK.','.FILTER_TAST_INVERT_MARK), null),
 		"filter"=>	array(T_ZBX_STR, O_OPT,	 null,	null, null),
-		"mark_color"=>	array(T_ZBX_STR, O_OPT,	 null,	
-			IN(MARK_COLOR_RED.','.MARK_COLOR_GREEN.','.MARK_COLOR_BLUE), null),
+		"mark_color"=>	array(T_ZBX_STR, O_OPT,	 null,	IN(MARK_COLOR_RED.','.MARK_COLOR_GREEN.','.MARK_COLOR_BLUE), null),
 		
 		"cmbloglist"=>	array(T_ZBX_INT, O_OPT,	 null,	DB_ID, null),
 
@@ -87,7 +86,7 @@ include_once "include/page_header.php";
 		if(isset($_REQUEST["remove_log"]) && isset($_REQUEST["cmbloglist"]))
 		{
 			foreach($_REQUEST["itemid"] as $id => $itemid)
-				if($itemid == $_REQUEST["cmbloglist"])
+				if((bccomp($itemid , $_REQUEST["cmbloglist"])==0))
 					unset($_REQUEST["itemid"][$id]);
 		}
 
@@ -192,6 +191,8 @@ include_once "include/page_header.php";
 		}
 
 		$form = new CForm();
+		$form->SetMethod('get');
+		
 		$form->AddVar("itemid",$_REQUEST["itemid"]);
 
 		if($_REQUEST["action"]!="showlatest")
@@ -206,7 +207,7 @@ include_once "include/page_header.php";
 		
 		$cmbAction = new CComboBox("action",$_REQUEST["action"],"submit()");
 
-		if(in_array($item_type,array(ITEM_VALUE_TYPE_FLOAT,ITEM_VALUE_TYPE_UINT64)))
+		if(str_in_array($item_type,array(ITEM_VALUE_TYPE_FLOAT,ITEM_VALUE_TYPE_UINT64)))
 		{
 			$cmbAction->AddItem("showgraph",S_GRAPH_OF_SPECIFIED_PERIOD);
 		}
@@ -254,6 +255,8 @@ include_once "include/page_header.php";
 				$mark_color = get_request("mark_color",0);
 
 				$r_header = new CForm();
+				$r_header->SetMethod('get');
+				
 				$r_header->AddVar("action",$_REQUEST["action"]);
 				$r_header->AddVar("from",$_REQUEST["from"]);
 				$r_header->AddVar("period",$_REQUEST["period"]);
@@ -270,7 +273,7 @@ include_once "include/page_header.php";
 					new CTextBox("filter",$filter,25),
 					$cmbFTask,SPACE));
 
-				if(in_array($filter_task,array(FILTER_TAST_MARK,FILTER_TAST_INVERT_MARK)))
+				if(str_in_array($filter_task,array(FILTER_TAST_MARK,FILTER_TAST_INVERT_MARK)))
 				{
 					$cmbColor = new CComboBox("mark_color",$mark_color);
 					$cmbColor->AddItem(MARK_COLOR_RED,S_AS_RED);
@@ -402,7 +405,8 @@ include_once "include/page_header.php";
 					);
 
 				$row["value"] = trim($row["value"],"\r\n");
-				array_push($new_row,htmlspecialchars($row["value"]));
+//				array_push($new_row,htmlspecialchars($row["value"]));
+				array_push($new_row,htmlspecialchars(encode_log($row["value"])));
 
 				if(!isset($_REQUEST["plaintext"]))
 				{
@@ -479,7 +483,7 @@ COpt::profiling_start("history");
 					$value = $row["value"]; 
 
 				$new_row = array(date("Y.M.d H:i:s",$row["clock"]));
-				if(in_array($item_type,array(ITEM_VALUE_TYPE_FLOAT,ITEM_VALUE_TYPE_UINT64)))
+				if(str_in_array($item_type,array(ITEM_VALUE_TYPE_FLOAT,ITEM_VALUE_TYPE_UINT64)))
 				{
 					array_push($new_row,$value);
 				}
@@ -505,10 +509,8 @@ COpt::profiling_stop("history");
 		}
 	}
 
-	if(!isset($_REQUEST["plaintext"]))
-	{
-		if(in_array($_REQUEST["action"],array("showvalues","showgraph")))
-		{
+	if(!isset($_REQUEST["plaintext"])){
+		if(($_REQUEST["action"]=="showvalues") || ($_REQUEST['action'] == "showgraph")){
 			navigation_bar("history.php",$to_save_request);
 		}
 	}
