@@ -1,7 +1,7 @@
 <?php
 /* 
 ** ZABBIX
-** Copyright (C) 2000-2005 SIA Zabbix
+** Copyright (C) 2000-2007 SIA Zabbix
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,23 +31,19 @@ include_once "include/page_header.php";
 	$_REQUEST["config"] = get_request("config",get_profile("web.hosts.config",0));
 	
 	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,null,PERM_RES_IDS_ARRAY,get_current_nodeid());
-	if(isset($_REQUEST["hostid"]) && $_REQUEST["hostid"] > 0 && !in_array($_REQUEST["hostid"], $available_hosts)) 
+	if(isset($_REQUEST["hostid"]) && $_REQUEST["hostid"] > 0 && !uint_in_array($_REQUEST["hostid"], $available_hosts)) 
 	{
 		access_deny();
 	}
-	if(isset($_REQUEST["apphostid"]) && $_REQUEST["apphostid"] > 0 && !in_array($_REQUEST["apphostid"], $available_hosts)) 
+	if(isset($_REQUEST["apphostid"]) && $_REQUEST["apphostid"] > 0 && !uint_in_array($_REQUEST["apphostid"], $available_hosts)) 
 	{
 		access_deny();
 	}
 
 	if(count($available_hosts) == 0) $available_hosts = array(-1);
-	$available_hosts = implode(',', $available_hosts);
 
-	if(isset($_REQUEST["groupid"]) && $_REQUEST["groupid"] > 0)
-	{
-		if(!in_array($_REQUEST["groupid"], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,null,
-			PERM_RES_IDS_ARRAY,get_current_nodeid())))
-		{
+	if(isset($_REQUEST["groupid"]) && $_REQUEST["groupid"] > 0){
+		if(!uint_in_array($_REQUEST["groupid"], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,null,PERM_RES_IDS_ARRAY,get_current_nodeid()))){
 			access_deny();
 		}
 	}
@@ -64,13 +60,13 @@ include_once "include/page_header.php";
 		"groups"=>	array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID, NULL),
 		"applications"=>array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID, NULL),
 /* host */
-		"hostid"=>	array(T_ZBX_INT, O_OPT,	P_SYS,  DB_ID,		'{config}==0&&{form}=="update"'),
-		"host"=>	array(T_ZBX_STR, O_OPT,	NULL,   NOT_EMPTY,	'({config}==0||{config}==3)&&isset({save})'),
-		"dns"=>		array(T_ZBX_STR, O_OPT,	NULL,	NULL,		'{config}==0&&isset({save})'),
-		"useip"=>	array(T_ZBX_STR, O_OPT, NULL,	IN('0,1'),	'{config}==0&&isset({save})'),
-		"ip"=>		array(T_ZBX_IP, O_OPT, NULL,	NULL,		'{config}==0&&isset({save})'),
-		"port"=>	array(T_ZBX_INT, O_OPT,	NULL,	BETWEEN(0,65535),'{config}==0&&isset({save})'),
-		"status"=>	array(T_ZBX_INT, O_OPT,	NULL,	IN("0,1,3"),	'{config}==0&&isset({save})'),
+		"hostid"=>	array(T_ZBX_INT, O_OPT,	P_SYS,  DB_ID,		'(isset({config})&&({config}==0 || {config}==2))&&(isset({form})&&({form}=="update"))'),
+		"host"=>	array(T_ZBX_STR, O_OPT,	NULL,   NOT_EMPTY,	'isset({config})&&({config}==0||{config}==3)&&isset({save})'),
+		"dns"=>		array(T_ZBX_STR, O_OPT,	NULL,	NULL,		'(isset({config})&&({config}==0))&&isset({save})'),
+		"useip"=>	array(T_ZBX_STR, O_OPT, NULL,	IN('0,1'),	'(isset({config})&&({config}==0))&&isset({save})'),
+		"ip"=>		array(T_ZBX_IP, O_OPT, NULL,	NULL,		'(isset({config})&&({config}==0))&&isset({save})'),
+		"port"=>	array(T_ZBX_INT, O_OPT,	NULL,	BETWEEN(0,65535),'(isset({config})&&({config}==0))&&isset({save})'),
+		"status"=>	array(T_ZBX_INT, O_OPT,	NULL,	IN("0,1,3"),	'(isset({config})&&({config}==0))&&isset({save})'),
 
 		"newgroup"=>		array(T_ZBX_STR, O_OPT, NULL,   NULL,	NULL),
 		"templates"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,	NULL),
@@ -87,16 +83,19 @@ include_once "include/page_header.php";
 		"software"=>	array(T_ZBX_STR, O_OPT, NULL,   NULL,	'isset({useprofile})'),
 		"contact"=>	array(T_ZBX_STR, O_OPT, NULL,   NULL,	'isset({useprofile})'),
 		"location"=>	array(T_ZBX_STR, O_OPT, NULL,   NULL,	'isset({useprofile})'),
-		"notes"=>	array(T_ZBX_STR, O_OPT, NULL,   NULL,	'isset({useprofile})'),
+		"notes"=>	array(T_ZBX_STR, O_OPT, NULL,   NULL,	'isset({useprofile})'),		
 /* group */
-		"groupid"=>	array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,		'{config}==1&&{form}=="update"'),
-		"gname"=>	array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,	'{config}==1&&isset({save})'),
+		"groupid"=>	array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,		'(isset({config})&&({config}==1))&&(isset({form})&&({form}=="update"))'),
+		"gname"=>	array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,	'(isset({config})&&({config}==1))&&isset({save})'),
 
 /* application */
-		"applicationid"=>array(T_ZBX_INT,O_OPT,	P_SYS,	DB_ID,		'{config}==4&&{form}=="update"'),
-		"appname"=>	array(T_ZBX_STR, O_NO,	NULL,	NOT_EMPTY,	'{config}==4&&isset({save})'),
-		"apphostid"=>	array(T_ZBX_INT, O_OPT, NULL,	DB_ID.'{}>0',	'{config}==4&&isset({save})'),
+		"applicationid"=>array(T_ZBX_INT,O_OPT,	P_SYS,	DB_ID,		'(isset({config})&&({config}==4))&&(isset({form})&&({form}=="update"))'),
+		"appname"=>	array(T_ZBX_STR, O_NO,	NULL,	NOT_EMPTY,	'(isset({config})&&({config}==4))&&isset({save})'),
+		"apphostid"=>	array(T_ZBX_INT, O_OPT, NULL,	DB_ID.'{}>0',	'(isset({config})&&({config}==4))&&isset({save})'),
 		"apptemplateid"=>array(T_ZBX_INT,O_OPT,	NULL,	DB_ID,	NULL),
+		
+/* host linkage form */
+		"tname"=>	array(T_ZBX_STR, O_OPT,	NULL,   NOT_EMPTY,	'isset({config})&&({config}==2)&&isset({save})'),
 
 /* actions */
 		"activate"=>	array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, NULL, NULL),	
@@ -123,7 +122,7 @@ include_once "include/page_header.php";
 	check_fields($fields);
 
 	if($_REQUEST["config"]==4)
-		validate_group_with_host(PERM_READ_WRITE,array("always_select_first_host"),'web.last.conf.groupid', 'web.last.conf.hostid');
+		validate_group_with_host(PERM_READ_WRITE,array("always_select_first_host","only_current_node"),'web.last.conf.groupid', 'web.last.conf.hostid');
 	elseif($_REQUEST["config"]==0 || $_REQUEST["config"]==3)
 		validate_group(PERM_READ_WRITE,array(),'web.last.conf.groupid');
 
@@ -132,30 +131,94 @@ include_once "include/page_header.php";
 <?php
 
 /************ ACTIONS FOR HOSTS ****************/
+// Original mod by scricca@vipsnet.net
+// Modified by Aly
+/* this code menages operations to unlink 1 template from multiple hosts */
+	if ($_REQUEST["config"]==2 && (isset($_REQUEST["unlink"]))){
+		$hosts = get_request("hosts",array());
+		if(isset($_REQUEST["hostid"])){
+			$templateid=$_REQUEST["hostid"];
+			$result = false;
+// Permission check			
+			$tmp_hosts = array_diff($hosts,$available_hosts);
+			$hosts = array_diff($hosts,$tmp_hosts);
+			unset($tmp_hosts);
+//--
+			foreach($hosts as $id => $hostid){
+				$result=unlink_template($hostid,$templateid);
+				
+				if($result){
+					$host=get_host_by_hostid($hostid);
+					add_audit(AUDIT_ACTION_UPDATE,AUDIT_RESOURCE_HOST,
+						"Host [".$host["host"]."] IP [".$host["ip"]."] ".
+						"Status [".$host["status"]."]");
+				}
+			}
+
+			show_messages($result, S_UNLINK_FROM_TEMPLATE, NULL);
+					
+			unset($_REQUEST["unlink"]);
+			unset($_REQUEST["hostid"]);
+			unset($_REQUEST["form"]);
+		}
+	}
+/* this code menages operations to link 1 template to multiple hosts */
+	if($_REQUEST["config"]==2 && (isset($_REQUEST["save"]))){
+		if(isset($_REQUEST['hostid'])){
+			$hosts = get_request('hosts',array());
+			$templateid=$_REQUEST['hostid'];
+			$result = false;
+// Permission check
+			$tmp_hosts = array_diff($hosts,$available_hosts);
+			$hosts = array_diff($hosts,$tmp_hosts);
+			unset($tmp_hosts);
+//--
+			
+			$template_name=DBfetch(DBselect('SELECT host FROM hosts WHERE hostid='.$templateid));			
+			foreach($hosts as $id => $hostid){
+			
+				$host_groups=DBfetch(DBselect('SELECT groupid FROM hosts_groups WHERE hostid='.$hostid));
+				$host=get_host_by_hostid($hostid);
+				
+				$templates_tmp=get_templates_by_hostid($hostid);
+				$templates_tmp[$templateid]=$template_name["host"];
+
+				$result=update_host($hostid,$host["host"],$host["port"],$host["status"],
+									$host["useip"],$host["dns"],$host["ip"],
+									$templates_tmp,'',$host_groups);
+				if($result){
+					add_audit(AUDIT_ACTION_UPDATE,AUDIT_RESOURCE_HOST,
+						"Host [".$host["host"]."] IP [".$host["ip"]."] ".
+						"Status [".$host["status"]."]");
+				}
+			}
+			show_messages($result, S_LINK_TO_TEMPLATE, NULL);
+			
+			unset($_REQUEST["save"]);
+			unset($_REQUEST["hostid"]);
+			unset($_REQUEST["form"]);
+		}
+	}
+//---------  END MOD ------------
 /* UNLINK HOST */
-	if(($_REQUEST["config"]==0 || $_REQUEST["config"]==3) && (isset($_REQUEST["unlink"]) || isset($_REQUEST["unlink_and_clear"])))
-	{
+	else if(($_REQUEST["config"]==0 || $_REQUEST["config"]==3) && (isset($_REQUEST["unlink"]) || isset($_REQUEST["unlink_and_clear"]))){
 		$_REQUEST['clear_templates'] = get_request('clear_templates', array());
-		if(isset($_REQUEST["unlink"]))
-		{
+		if(isset($_REQUEST["unlink"])){
 			$unlink_templates = array_keys($_REQUEST["unlink"]);
 		}
-		else
-		{
+		else{
 			$unlink_templates = array_keys($_REQUEST["unlink_and_clear"]);
 			$_REQUEST['clear_templates'] = array_merge($_REQUEST['clear_templates'],$unlink_templates);
 		}
 		foreach($unlink_templates as $id) unset($_REQUEST['templates'][$id]);
 	}
 /* CLONE HOST */
-	elseif(($_REQUEST["config"]==0 || $_REQUEST["config"]==3) && isset($_REQUEST["clone"]) && isset($_REQUEST["hostid"]))
-	{
+	elseif(($_REQUEST["config"]==0 || $_REQUEST["config"]==3) && isset($_REQUEST["clone"]) && isset($_REQUEST["hostid"])){
 		unset($_REQUEST["hostid"]);
 		$_REQUEST["form"] = "clone";
 	}
 /* SAVE HOST */
-	elseif(($_REQUEST["config"]==0 || $_REQUEST["config"]==3) && isset($_REQUEST["save"]))
-	{
+	elseif(($_REQUEST["config"]==0 || $_REQUEST["config"]==3) && isset($_REQUEST["save"])){
 		$useip = get_request("useip",0);
 
 		$groups=get_request("groups",array());
@@ -264,7 +327,7 @@ include_once "include/page_header.php";
 			{
 				$host=get_host_by_hostid($db_host["hostid"]);
 
-				if(!in_array($db_host["hostid"],$hosts)) continue;
+				if(!uint_in_array($db_host["hostid"],$hosts)) continue;
 				if(!delete_host($db_host["hostid"], $unlink_mode))	continue;
 				$result = 1;
 
@@ -281,7 +344,7 @@ include_once "include/page_header.php";
 	{
 		global $USER_DETAILS;
 
-		if(!in_array($_REQUEST['add_to_group'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,null,
+		if(!uint_in_array($_REQUEST['add_to_group'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,null,
 			PERM_RES_IDS_ARRAY,get_current_nodeid())))
 		{
 			access_deny();
@@ -297,7 +360,7 @@ include_once "include/page_header.php";
 	{
 		global $USER_DETAILS;
 
-		if(!in_array($_REQUEST['delete_from_group'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,null,
+		if(!uint_in_array($_REQUEST['delete_from_group'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,null,
 			PERM_RES_IDS_ARRAY,get_current_nodeid())))
 		{
 			access_deny();
@@ -318,7 +381,7 @@ include_once "include/page_header.php";
 		$db_hosts=DBselect('select hostid from hosts where '.DBin_node('hostid'));
 		while($db_host=DBfetch($db_hosts))
 		{
-			if(!in_array($db_host["hostid"],$hosts)) continue;
+			if(!uint_in_array($db_host["hostid"],$hosts)) continue;
 			$host=get_host_by_hostid($db_host["hostid"]);
 			$res=update_host_status($db_host["hostid"],$status);
 
@@ -405,7 +468,7 @@ include_once "include/page_header.php";
 			$db_groups=DBselect('select groupid, name from groups where '.DBin_node('groupid'));
 			while($db_group=DBfetch($db_groups))
 			{
-				if(!in_array($db_group["groupid"],$groups)) continue;
+				if(!uint_in_array($db_group["groupid"],$groups)) continue;
 			
 				if(!($group = get_hostgroup_by_groupid($db_group["groupid"]))) continue;
 
@@ -431,7 +494,7 @@ include_once "include/page_header.php";
 			' and '.DBin_node('h.hostid'));
 		while($db_host=DBfetch($db_hosts))
 		{
-			if(!in_array($db_host["groupid"],$groups)) continue;
+			if(!uint_in_array($db_host["groupid"],$groups)) continue;
 			$host=get_host_by_hostid($db_host["hostid"]);
 			if(!update_host_status($db_host["hostid"],$status))	continue;
 
@@ -495,7 +558,7 @@ include_once "include/page_header.php";
 
 			while($db_app = DBfetch($db_applications))
 			{
-				if(!in_array($db_app["applicationid"],$applications))	continue;
+				if(!uint_in_array($db_app["applicationid"],$applications))	continue;
 				if(!delete_application($db_app["applicationid"]))	continue;
 				$result = 1;
 
@@ -508,12 +571,46 @@ include_once "include/page_header.php";
 		}
 		unset($_REQUEST["delete"]);
 	}
+	elseif(($_REQUEST["config"]==4) &&(isset($_REQUEST["activate"])||isset($_REQUEST["disable"]))){
+/* group operations */
+		$result = true;
+		$applications = get_request("applications",array());
+
+		foreach($applications as $id => $appid){
+	
+			$sql = 'SELECT ia.itemid,i.hostid,i.key_'.
+					' FROM items_applications ia '.
+					  ' LEFT JOIN items i ON ia.itemid=i.itemid '.
+					' WHERE ia.applicationid='.$appid.
+					  ' AND i.hostid='.$_REQUEST['hostid'].
+					  ' AND '.DBin_node('ia.applicationid');
+
+			$res_items = DBselect($sql);
+			while($item=DBfetch($res_items)){
+
+					if(isset($_REQUEST["activate"])){
+						if($result&=activate_item($item['itemid'])){
+							$host = get_host_by_hostid($item['hostid']);
+							add_audit(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_ITEM,S_ITEM.' ['.$item['key_'].'] ['.$id.'] '.S_HOST.' ['.$host['host'].'] '.S_ITEMS_ACTIVATED);
+						}
+					}
+					else{
+						if($result&=disable_item($item['itemid'])){
+							$host = get_host_by_hostid($item['hostid']);
+							add_audit(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_ITEM,S_ITEM." [".$item["key_"]."] [".$id."] ".S_HOST." [".$host['host']."] ".S_ITEMS_DISABLED);
+						}
+					}
+			}
+		}
+		(isset($_REQUEST["activate"]))?show_messages($result, S_ITEMS_ACTIVATED, null):show_messages($result, S_ITEMS_DISABLED, null);
+	}
 	
 	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,null,null,get_current_nodeid()); /* update available_hosts after ACTIONS */
 ?>
 <?php
 	$frmForm = new CForm();
-
+	$frmForm->SetMethod('get');
+	
 	$cmbConf = new CComboBox("config",$_REQUEST["config"],"submit()");
 	$cmbConf->AddItem(0,S_HOSTS);
 	$cmbConf->AddItem(3,S_TEMPLATES);
@@ -549,40 +646,43 @@ include_once "include/page_header.php";
 	show_table_header(S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES, $frmForm);
 	echo BR;
 ?>
-
 <?php
-	if($_REQUEST["config"]==0 || $_REQUEST["config"]==3)
-	{
+	if($_REQUEST["config"]==0 || $_REQUEST["config"]==3){
 		$show_only_tmp = 0;
 		if($_REQUEST["config"]==3)
 			$show_only_tmp = 1;
 
-		if(isset($_REQUEST["form"]))
-		{
+		if(isset($_REQUEST["form"])){
 			insert_host_form($show_only_tmp);
-		} else {
-			$status_filter = " and h.status not in (".HOST_STATUS_DELETED.",".HOST_STATUS_TEMPLATE.") ";
+		}
+		else {
+			$status_filter = ' AND h.status NOT IN ('.HOST_STATUS_DELETED.','.HOST_STATUS_TEMPLATE.') ';
 			if($show_only_tmp==1)
-				$status_filter = " and h.status in (".HOST_STATUS_TEMPLATE.") ";
+				$status_filter = ' AND h.status IN ('.HOST_STATUS_TEMPLATE.') ';
 				
 			$cmbGroups = new CComboBox("groupid",get_request("groupid",0),"submit()");
 			$cmbGroups->AddItem(0,S_ALL_SMALL);
-			$result=DBselect("select distinct g.groupid,g.name from groups g,hosts_groups hg,hosts h".
-					" where h.hostid in (".$available_hosts.") ".
-					" and g.groupid=hg.groupid and h.hostid=hg.hostid".$status_filter.
-					" order by g.name");
-			while($row=DBfetch($result))
-			{
+			$result=DBselect('SELECT DISTINCT g.groupid,g.name '.
+					' FROM groups g,hosts_groups hg,hosts h '.
+					' WHERE h.hostid IN ('.$available_hosts.') '.
+						' AND g.groupid=hg.groupid '.
+						' AND h.hostid=hg.hostid'.
+						$status_filter.
+					' ORDER BY g.name');
+					
+			while($row=DBfetch($result)){
 				$cmbGroups->AddItem($row["groupid"],$row["name"]);
-				if($row["groupid"] == $_REQUEST["groupid"]) $correct_host = 1;
+				if((bccomp($row["groupid"], $_REQUEST["groupid"]) == 0)) $correct_host = 1;
 			}
-			if(!isset($correct_host))
-			{
+			
+			if(!isset($correct_host)){
 				$_REQUEST["groupid"] = 0;
 				$cmbGroups->SetValue($_REQUEST["groupid"]);
 			}
 
 			$frmForm = new CForm();
+			$frmForm->SetMethod('get');
+
 			$frmForm->AddVar("config",$_REQUEST["config"]);
 			$frmForm->AddItem(S_GROUP.SPACE);
 			$frmForm->AddItem($cmbGroups);
@@ -593,6 +693,7 @@ include_once "include/page_header.php";
 			if(isset($_REQUEST["groupid"]) && $_REQUEST["groupid"]==0) unset($_REQUEST["groupid"]);
 
 			$form = new CForm();
+			
 			$form->SetName('hosts');
 			$form->AddVar("config",get_request("config",0));
 
@@ -610,20 +711,20 @@ include_once "include/page_header.php";
 				S_ACTIONS
 				));
 		
-			$sql="select h.* from";
-			if(isset($_REQUEST["groupid"]))
-			{
-				$sql .= " hosts h,hosts_groups hg where";
-				$sql .= " hg.groupid=".$_REQUEST["groupid"]." and hg.hostid=h.hostid and";
-			} else  $sql .= " hosts h where";
-			$sql .=	" h.hostid in (".$available_hosts.") ".
+			$sql='SELECT h.* FROM';
+			if(isset($_REQUEST["groupid"])){
+				$sql .= ' hosts h,hosts_groups hg ';
+				$sql .= ' WHERE hg.groupid='.$_REQUEST["groupid"].' and hg.hostid=h.hostid and';
+			} 
+			else  $sql .= ' hosts h where';
+			
+			$sql .=	' h.hostid in ('.$available_hosts.') '.
 				$status_filter.
-				" order by h.host";
+				' ORDER BY h.host';
 
 			$result=DBselect($sql);
 		
-			while($row=DBfetch($result))
-			{
+			while($row=DBfetch($result)){
 				$add_to = array();
 				$delete_from = array();
 
@@ -637,8 +738,7 @@ include_once "include/page_header.php";
 					));
 		
 				
-				if($show_only_tmp)
-				{
+				if($show_only_tmp){
 					$dns = NULL;
 					$ip = NULL;
 					$port = NULL;
@@ -646,11 +746,10 @@ include_once "include/page_header.php";
 					$available = NULL;
 					$error = NULL;
 				}
-				else
-				{
-					$dns = $row['dns'];
-					$ip = $row['ip'];
-					$port = $row["port"];
+				else{
+					$dns = empty($row['dns'])?'-':$row['dns'];
+					$ip = empty($row['ip'])?'-':$row['ip'];
+					$port = empty($row['port'])?'-':$row["port"];
 
 					if(1 == $row['useip'])
 						$ip = bold($ip);
@@ -661,7 +760,8 @@ include_once "include/page_header.php";
 						$status=new CLink(S_MONITORED,"hosts.php?hosts%5B%5D=".$row["hostid"].
 							"&disable=1".url_param("config").url_param("groupid"),
 							"off");
-					} else if($row["status"] == HOST_STATUS_NOT_MONITORED) {
+					} 
+					else if($row["status"] == HOST_STATUS_NOT_MONITORED) {
 						$status=new CLink(S_NOT_MONITORED,"hosts.php?hosts%5B%5D=".$row["hostid"].
 							"&activate=1".url_param("config").url_param("groupid"),
 							"on");
@@ -679,8 +779,11 @@ include_once "include/page_header.php";
 					else if($row["available"] == HOST_AVAILABLE_UNKNOWN)
 						$available=new CCol(S_UNKNOWN,"unknown");
 
-					if($row["error"] == "")	$error = new CCol(SPACE,"off");
-					else			$error = new CCol($row["error"],"on");
+					$row["error"] = trim($row["error"]);
+					if(empty($row["error"]))
+						$error = new CCol('-',"off");
+					else 
+						$error = new CCol($row["error"],"on");
 
 				}
 
@@ -691,9 +794,11 @@ include_once "include/page_header.php";
 					array(S_GRAPHS, 'graphs.php?hostid='.$row['hostid'], array('tw'=>'_blank')),
 					);
 
-				$db_groups = DBselect('select g.groupid, g.name from groups g left join hosts_groups hg '.
-						' on g.groupid=hg.groupid and hg.hostid='.$row['hostid'].
-						' where hostid is NULL order by g.name,g.groupid');
+				$db_groups = DBselect('SELECT g.groupid, g.name '.
+						' FROM groups g '.
+							' LEFT JOIN hosts_groups hg on g.groupid=hg.groupid and hg.hostid='.$row['hostid'].
+						' WHERE hostid is NULL '.
+						' ORDER BY g.name,g.groupid');
 				while($group_data = DBfetch($db_groups))
 				{
 					$add_to[] = array($group_data['name'], '?'.
@@ -738,7 +843,7 @@ include_once "include/page_header.php";
 					$dns,
 					$ip,
 					$port,
-					implode(', ',$templates),
+					empty($templates)?'-':implode(', ',$templates),
 					$status,
 					$available,
 					$error,
@@ -761,15 +866,17 @@ include_once "include/page_header.php";
 
 		}
 	}
-	elseif($_REQUEST["config"]==1)
-	{
+	elseif($_REQUEST["config"]==1){
 		if(isset($_REQUEST["form"]))
 		{
 			insert_hostgroups_form(get_request("groupid",NULL));
-		} else {
+		} 
+		else {
 			show_table_header(S_HOST_GROUPS_BIG);
 
 			$form = new CForm('hosts.php');
+			$form->SetMethod('get');
+			
 			$form->SetName('groups');
 			$form->AddVar("config",get_request("config",0));
 
@@ -780,27 +887,31 @@ include_once "include/page_header.php";
 						"CheckAll('".$form->GetName()."','all_groups');"),
 					SPACE,
 					S_NAME),
+				" # ",
 				S_MEMBERS));
 
 			$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,null,null,get_current_nodeid());
 
-			$db_groups=DBselect("select groupid,name from groups".
-					" where groupid in (".$available_groups.")".
-					" order by name");
-			while($db_group=DBfetch($db_groups))
-			{
-				$db_hosts = DBselect("select distinct h.host, h.status".
-					" from hosts h, hosts_groups hg".
-					" where h.hostid=hg.hostid and hg.groupid=".$db_group["groupid"].
-					" and h.hostid in (".$available_hosts.")".
-					" and h.status not in (".HOST_STATUS_DELETED.") order by host");
+			$db_groups=DBselect('select groupid,name from groups'.
+					' where groupid in ('.$available_groups.')'.
+					' order by name');
+			while($db_group=DBfetch($db_groups)){
+				$db_hosts = DBselect('select distinct h.host, h.status'.
+					' from hosts h, hosts_groups hg'.
+					' where h.hostid=hg.hostid '.
+						' and hg.groupid='.$db_group['groupid'].
+						' and h.hostid in ('.$available_hosts.')'.
+						' and h.status not in ('.HOST_STATUS_DELETED.') '.
+						' order by host');
 
 				$hosts = array();
+				$count = 0;
 				while($db_host=DBfetch($db_hosts)){
 					$style = $db_host["status"]==HOST_STATUS_MONITORED ? NULL: ( 
 						$db_host["status"]==HOST_STATUS_TEMPLATE ? "unknown" :
 						"on");
 					array_push($hosts,unpack_object(new CSpan($db_host["host"],$style)));
+					$count++;
 				}
 
 				$table->AddRow(array(
@@ -812,7 +923,8 @@ include_once "include/page_header.php";
 							"hosts.php?form=update&groupid=".$db_group["groupid"].
 							url_param("config"),'action')
 					),
-					implode(', ',$hosts)
+					$count,
+					empty($hosts)?'-':implode(', ',$hosts)
 					));
 			}
 			$table->SetFooter(new CCol(array(
@@ -827,58 +939,73 @@ include_once "include/page_header.php";
 			$form->Show();
 		}
 	}
-	elseif($_REQUEST["config"]==2)
-	{
-		show_table_header(S_TEMPLATE_LINKAGE_BIG);
-
-		$table = new CTableInfo(S_NO_LINKAGES);
-		$table->SetHeader(array(S_TEMPLATES,S_HOSTS));
-
-		$templates = DBSelect("select * from hosts where status=".HOST_STATUS_TEMPLATE.
-			" and hostid in (".$available_hosts.")".
-			" order by host");
-		while($template = DBfetch($templates))
-		{
-			$hosts = DBSelect("select h.* from hosts h, hosts_templates ht where ht.templateid=".$template["hostid"].
-				" and ht.hostid=h.hostid ".
-				" and h.status not in (".HOST_STATUS_TEMPLATE.")".
-				" and h.hostid in (".$available_hosts.")".
-				" order by host");
-			$host_list = array();
-			while($host = DBfetch($hosts))
-			{
-				if($host["status"] == HOST_STATUS_NOT_MONITORED)
-				{
-					array_push($host_list, unpack_object(new CSpan($host["host"],"on")));
+// Original mod by scricca@vipsnet.net
+// Modified by Aly
+/* this code adds links to Template Names in Template_Linkage page and link them to the form in forms.inc.php */
+	else if($_REQUEST["config"]==2){
+	
+		if(isset($_REQUEST["form"])){
+			insert_template_form(get_request("hostid",NULL));
+		} 
+		else{
+	
+			show_table_header(S_TEMPLATE_LINKAGE_BIG);
+		
+			$table = new CTableInfo(S_NO_LINKAGES);
+			$table->SetHeader(array(S_TEMPLATES,S_HOSTS));
+		
+			$templates = DBSelect('SELECT h.* FROM hosts h'.
+					' WHERE h.status='.HOST_STATUS_TEMPLATE.
+						' AND h.hostid IN ('.$available_hosts.')'.
+					' ORDER BY h.host');
+			while($template = DBfetch($templates)){
+			
+				$hosts = DBSelect('SELECT h.* '.
+					' FROM hosts h, hosts_templates ht '.
+					' WHERE ht.templateid='.$template['hostid'].
+						' AND ht.hostid=h.hostid '.
+						' AND h.status<>'.HOST_STATUS_TEMPLATE.
+						' AND h.hostid in ('.$available_hosts.')'.
+					' ORDER BY host');
+				$host_list = array();
+				while($host = DBfetch($hosts)){
+					if($host['status'] == HOST_STATUS_NOT_MONITORED){
+						array_push($host_list, unpack_object(new CSpan($host['host'],'on')));
+					}
+					else{
+						array_push($host_list, $host['host']);
+					}
 				}
-				else
-				{
-					array_push($host_list, $host["host"]);
-				}
-			}
-			$table->AddRow(array(
-				new CSpan($template["host"],"unknown"),
-				implode(', ',$host_list)
+				$table->AddRow(array(		
+					new CCol(array(
+						new CLink($template['host'],'hosts.php?form=update&hostid='.
+							$template['hostid'].url_param('hostid').url_param('config'), 'action')
+						),'unknown'),
+					empty($host_list)?'-':implode(', ',$host_list)
 				));
+			}
+			
+			$table->Show();
 		}
-
-		$table->Show();
+//----- END MODE -----
 	}
-	elseif($_REQUEST["config"]==4)
-	{
-		if(isset($_REQUEST["form"]))
-		{
+	else if($_REQUEST["config"]==4){
+		if(isset($_REQUEST["form"])){
 			insert_application_form();
-		} else {
+		} 
+		else {
 	// Table HEADER
 			$form = new CForm();
-
+			$form->SetMethod('get');
+			
 			$cmbGroup = new CComboBox("groupid",$_REQUEST["groupid"],"submit();");
 			$cmbGroup->AddItem(0,S_ALL_SMALL);
 
-			$result=DBselect("select distinct g.groupid,g.name from groups g,hosts_groups hg".
-				" where g.groupid=hg.groupid and hg.hostid in (".$available_hosts.") ".
-				" order by name");
+			$result=DBselect('select distinct g.groupid,g.name '.
+						' from groups g,hosts_groups hg'.
+						' where g.groupid=hg.groupid '.
+							' and hg.hostid in ('.$available_hosts.') '.
+						' order by name');
 			while($row=DBfetch($result))
 			{
 				$cmbGroup->AddItem($row["groupid"],$row["name"]);
@@ -886,25 +1013,28 @@ include_once "include/page_header.php";
 			$form->AddItem(S_GROUP.SPACE);
 			$form->AddItem($cmbGroup);
 
-			if(isset($_REQUEST["groupid"]) && $_REQUEST["groupid"]>0)
-			{
-				$sql="select distinct h.hostid,h.host from hosts h,hosts_groups hg".
-					" where hg.groupid=".$_REQUEST["groupid"]." and hg.hostid=h.hostid ".
-					" and h.hostid in (".$available_hosts.") ".
-					" and h.status<>".HOST_STATUS_DELETED." group by h.hostid,h.host order by h.host";
+			if(isset($_REQUEST["groupid"]) && $_REQUEST["groupid"]>0){
+				$sql='select distinct h.hostid,h.host '.
+					' from hosts h,hosts_groups hg'.
+					' where hg.groupid='.$_REQUEST['groupid'].
+						' and hg.hostid=h.hostid '.
+						' and h.hostid in ('.$available_hosts.') '.
+						' and h.status<>'.HOST_STATUS_DELETED.
+					' group by h.hostid,h.host '.
+					' order by h.host';
 			}
-			else
-			{
-				$sql="select distinct h.hostid,h.host from hosts h ".
-					" where h.status<>".HOST_STATUS_DELETED.
-					" and h.hostid in (".$available_hosts.") ".
-					" group by h.hostid,h.host order by h.host";
+			else{
+				$sql='select distinct h.hostid,h.host '.
+					' from hosts h '.
+					' where h.status<>'.HOST_STATUS_DELETED.
+						' and h.hostid in ('.$available_hosts.') '.
+					' group by h.hostid,h.host '.
+					' order by h.host';
 			}
 			$cmbHosts = new CComboBox("hostid",$_REQUEST["hostid"],"submit();");
 
 			$result=DBselect($sql);
-			while($row=DBfetch($result))
-			{
+			while($row=DBfetch($result)){
 				$cmbHosts->AddItem($row["hostid"],$row["host"]);
 			}
 
@@ -920,8 +1050,7 @@ include_once "include/page_header.php";
 
 			$table = new CTableInfo();
 			$table->SetHeader(array(
-				array(new CCheckBox("all_applications",NULL,
-					"CheckAll('".$form->GetName()."','all_applications');"),
+				array(new CCheckBox("all_applications",NULL,"CheckAll('".$form->GetName()."','all_applications');"),
 				SPACE,
 				S_APPLICATION),
 				S_SHOW
@@ -952,9 +1081,7 @@ include_once "include/page_header.php";
 
 
 				$table->AddRow(array(
-					array(new CCheckBox("applications[]",NULL,NULL,$db_app["applicationid"]),
-					SPACE,
-					$name),
+					array(new CCheckBox("applications[]",NULL,NULL,$db_app["applicationid"]),SPACE,$name),
 					array(new CLink(S_ITEMS,"items.php?hostid=".$db_app["hostid"],"action"),
 					SPACE."($rows)")
 					));
