@@ -42,7 +42,7 @@ include_once "include/page_header.php";
 		"groupid"=>	array(T_ZBX_INT, O_OPT,	 P_SYS,	DB_ID,null),
 		"hostid"=>	array(T_ZBX_INT, O_OPT,  P_SYS,	DB_ID,'isset({form})||isset({save})'),
 
-		"httptestid"=>	array(T_ZBX_INT, O_NO,	 P_SYS,	DB_ID,'{form}=="update"'),
+		"httptestid"=>	array(T_ZBX_INT, O_NO,	 P_SYS,	DB_ID,'(isset({form})&&({form}=="update"))'),
 		"application"=>	array(T_ZBX_STR, O_OPT,  null,	NOT_EMPTY,'isset({save})'),
 		"name"=>	array(T_ZBX_STR, O_OPT,  null,	NOT_EMPTY.KEY_PARAM(),'isset({save})'),
 		"delay"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,86400),'isset({save})'),
@@ -80,7 +80,7 @@ include_once "include/page_header.php";
 	
 	$accessible_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,null,null,get_current_nodeid());
 
-	if(isset($_REQUEST['hostid']) && !in_array($_REQUEST['hostid'], explode(',',$accessible_hosts)))
+	if(isset($_REQUEST['hostid']) && !uint_in_array($_REQUEST['hostid'], explode(',',$accessible_hosts)))
 	{
 		unset($_REQUEST['hostid']);
 	}
@@ -99,7 +99,7 @@ include_once "include/page_header.php";
 			$_REQUEST["applications"] = array();
 			$show_all_apps = 1;
 		}
-		elseif(!in_array($_REQUEST["applicationid"],$_REQUEST["applications"]))
+		elseif(!uint_in_array($_REQUEST["applicationid"],$_REQUEST["applications"]))
 		{
 			array_push($_REQUEST["applications"],$_REQUEST["applicationid"]);
 		}
@@ -323,7 +323,7 @@ include_once "include/page_header.php";
 	{
 		foreach($_REQUEST['steps'] as $s2id => $s2)
 		{
-			if($s1['name'] == $s2['name'] && $s1id != $s2id)
+			if((strcmp($s1['name'],$s2['name'])==0) && $s1id != $s2id)
 			{
 				$_REQUEST['steps'][$s1id] = $_REQUEST['steps'][$s2id];
 				unset($_REQUEST['steps'][$s2id]);
@@ -333,7 +333,8 @@ include_once "include/page_header.php";
 	$_REQUEST['steps'] = array_merge(get_request('steps',array())); /* reinitialize keys */
 
 	$form = new CForm();
-
+	$form->SetMethod('get');
+	
 	$form->AddVar("hostid",$_REQUEST["hostid"]);
 
 	$form->AddItem(new CButton("form",S_CREATE_SCENARIO));
@@ -346,10 +347,12 @@ include_once "include/page_header.php";
 	{
 // FORM
 		insert_httptest_form();
-	} else {
+	} 
+	else {
 
 // Table HEADER
 		$form = new CForm();
+		$form->SetMethod('get');
 		
 		$form->AddItem(array('[', 
 			new CLink($showdisabled ? S_HIDE_DISABLED_SCENARIOS: S_SHOW_DISABLED_SCENARIOS,
@@ -395,7 +398,7 @@ include_once "include/page_header.php";
 			$cmbHosts->AddItem($row["hostid"],$row["host"]);
 
 			if($_REQUEST["hostid"]!=0){
-				if($_REQUEST["hostid"]==$row["hostid"])
+				if((bccomp($_REQUEST["hostid"], $row["hostid"])==0))
 					$correct_hostid = 'ok';
 			}
 			if($first_hostid <= 0)
@@ -451,7 +454,7 @@ include_once "include/page_header.php";
 		while($httptest_data = DBfetch($db_httptests))
 		{
 			++$httptest_cnt;
-			if(!in_array($db_app["applicationid"],$_REQUEST["applications"]) && !isset($show_all_apps)) continue;
+			if(!uint_in_array($db_app["applicationid"],$_REQUEST["applications"]) && !isset($show_all_apps)) continue;
 
 			$name = array();
 
@@ -493,7 +496,7 @@ include_once "include/page_header.php";
 		}
 		if($httptest_cnt > 0)
 		{
-			if(in_array($db_app["applicationid"],$_REQUEST["applications"]) || isset($show_all_apps))
+			if(uint_in_array($db_app["applicationid"],$_REQUEST["applications"]) || isset($show_all_apps))
 				$link = new CLink(new CImg("images/general/opened.gif"),
 					"?close=1&applicationid=".$db_app["applicationid"].
 					url_param("groupid").url_param("hostid").url_param("applications").
