@@ -58,7 +58,7 @@ include_once "include/page_header.php";
 			$_REQUEST["applications"] = array();
 			$show_all_apps = 1;
 		}
-		elseif(!in_array($_REQUEST["applicationid"],$_REQUEST["applications"]))
+		elseif(!uint_in_array($_REQUEST["applicationid"],$_REQUEST["applications"]))
 		{
 			array_push($_REQUEST["applications"],$_REQUEST["applicationid"]);
 		}
@@ -87,11 +87,12 @@ include_once "include/page_header.php";
 <?php
 // Table HEADER
 	$form = new CForm();
+	$form->SetMethod('get');
 	
 	$cmbGroup = new CComboBox("groupid",$_REQUEST["groupid"],"submit();");
 	$cmbGroup->AddItem(0,S_ALL_SMALL);
 
-	$accessible_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,null,null,get_current_nodeid());
+	$accessible_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,null,null,get_current_nodeid());
 	$accessible_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_LIST, null, null, get_current_nodeid());
 
 	$result=DBselect('select distinct g.groupid,g.name from groups g, hosts_groups hg, hosts h, '.
@@ -146,6 +147,8 @@ include_once "include/page_header.php";
 
 // TABLE
 	$form = new CForm();
+	$form->SetMethod('get');
+	
 	$form->SetName('scenarios');
 	$form->AddVar('hostid',$_REQUEST["hostid"]);
 
@@ -191,7 +194,7 @@ include_once "include/page_header.php";
 		while($httptest_data = DBfetch($db_httptests))
 		{
 			++$httptest_cnt;
-			if(!in_array($db_app["applicationid"],$_REQUEST["applications"]) && !isset($show_all_apps)) continue;
+			if(!uint_in_array($db_app["applicationid"],$_REQUEST["applications"]) && !isset($show_all_apps)) continue;
 
 			$name = array();
 
@@ -250,7 +253,7 @@ include_once "include/page_header.php";
 		}
 		if($httptest_cnt > 0)
 		{
-			if(in_array($db_app["applicationid"],$_REQUEST["applications"]) || isset($show_all_apps))
+			if(uint_in_array($db_app["applicationid"],$_REQUEST["applications"]) || isset($show_all_apps))
 				$link = new CLink(new CImg("images/general/opened.gif"),
 					"?close=1&applicationid=".$db_app["applicationid"].
 					url_param("groupid").url_param("hostid").url_param("applications").
