@@ -74,7 +74,7 @@
 			$this->options['size'] = 1;
 			$this->SetAction($action);
 		}
-		function SetAction($value='submit()', $event='onChange')
+		function SetAction($value='submit()', $event='onchange')
 		{
 			$this->AddOption($event,$value);
 		}
@@ -85,12 +85,16 @@
 		function AddItem($value, $caption='', $selected=NULL, $enabled='yes')
 		{
 //			if($enabled=='no') return;	/* disable item method 1 */
-
-			if(is_null($selected))
-			{
+			if(is_null($selected)){
 				$selected = 'no';
-				if($value == $this->value || (is_array($this->value) && in_array($value, $this->value)))
+				if(is_array($this->value)) {
+					if(str_in_array($value,$this->value))
+						$selected = 'yes';
+				}
+				else if(strcmp($value,$this->value) == 0)
+				{
 					$selected = 'yes';
+				}
 			}
 
 			parent::AddItem(new CComboItem($value,$caption,$selected,$enabled));
@@ -185,8 +189,14 @@
 		{
 			if(is_null($selected))
 			{
-				if($value == $this->value || (is_array($this->value) && in_array($value, $this->value)))
+				if(is_array($this->value)) {
+					if(str_in_array($value,$this->value))
+						$this->value_exist = 1;
+				}
+				else if(strcmp($value,$this->value) == 0)
+				{
 					$this->value_exist = 1;
+				}
 			}
 
 			parent::AddItem($value,$caption,$selected,$enabled);
