@@ -22,10 +22,21 @@
 	class CHelp extends CLink
 	{
 /* public */
-		function CHelp($url="index.php")
+		function CHelp($url="index.php",$side=null)
 		{
+			if(is_null($side)) $side = 'right';
+			if($side == 'right')
+			{
+				$pside = 'left';
+			}
+			else
+			{
+				$side = 'left';
+				$pside = 'right';
+			}
+
 			parent::CLink(new CImg('images/general/help.gif','?'), 'http://www.zabbix.com/manual/v1.1/'.$url);
-			$this->options['style'] = 'float:right';
+			$this->options['style'] = 'padding-'.$pside.': 5px; float:'.$side;
 			$this->options['target'] = '_blank';
 		}
 	}
