@@ -73,8 +73,8 @@
 					}
 					break;
 				case "ORACLE":
-					$DB = ocilogon($DB_USER, $DB_PASSWORD, $DB_DATABASE);
-					//$DB = ocilogon($DB_USER, $DB_PASSWORD, "(DESCRIPTION=(ADDRESS=(PROTOCOL=TCP)(HOST=$DB_SERVER)(PORT=1521))(CONNECT_DATA=(SERVICE_NAME=$DB_DATABASE)))");
+//					$DB = ociplogon($DB_USER, $DB_PASSWORD, $DB_DATABASE);
+					$DB = ociplogon($DB_USER, $DB_PASSWORD, "(DESCRIPTION=(ADDRESS=(PROTOCOL=TCP)(HOST=$DB_SERVER)(PORT=1521))(CONNECT_DATA=(SERVICE_NAME=$DB_DATABASE)))");
 					if(!$DB)
 					{
 						$error = "Error connecting to database";
@@ -298,7 +298,7 @@ COpt::savesqlrequest($query);
 			case "ORACLE":
 				if(is_numeric($limit))
 				{
-					$query = 'select * from ('.$query.') where rownum<'.intval($limit);
+					$query = 'select * from ('.$query.') where rownum<='.intval($limit);
 				}
 
 				$stid=OCIParse($DB,$query);
@@ -414,11 +414,22 @@ COpt::savesqlrequest($query);
 				$result = pg_fetch_array($cursor);
 				break;
 			case "ORACLE":
+				$text_datatypes = array('VARCHAR','VARCHAR2','CLOB');
 				if(ocifetchinto($cursor, $row, OCI_ASSOC+OCI_NUM+OCI_RETURN_NULLS))
 				{
 					$result = array();
 					$keys = (array_keys($row));
-					foreach ($keys as $k)		$result[strtolower($k)] = $row[$k];
+					foreach ($keys as $k)
+					{
+						$field = is_int($k) ? $k + 1 : $k;
+						$column_type  = ocicolumntype($cursor, $field);
+						$field_is_null = ocicolumnisnull($cursor, $field);
+
+						if ($field_is_null && str_in_array($column_type,$text_datatypes))
+							$result[strtolower($k)] = '';
+						else
+							$result[strtolower($k)] = $row[$k];
+					}
 				} 
 				break;
 			case "SQLITE3":
@@ -437,15 +448,43 @@ COpt::savesqlrequest($query);
 	
 
 /* string value prepearing */
-if(isset($DB_TYPE) && $DB_TYPE == "ORACLE") {	
-	function	zbx_dbstr($var)	{
+/* string value prepearing */
+if(isset($DB_TYPE) && $DB_TYPE == "ORACLE") {
+	function zbx_dbstr($var)	{
 		return "'".ereg_replace('\'','\'\'',$var)."'";	
 	}
-} else {			
-	function	zbx_dbstr($var)	{
-		return "'".addslashes($var)."'";
+	
+	function zbx_dbcast_2bigint($field){
+		return ' CAST('.$field.' AS NUMBER(20)) ';
 	}
 }
+else if(isset($DB_TYPE) && $DB_TYPE == "MYSQL") {
+	function zbx_dbstr($var)	{
+		return "'".mysql_real_escape_string($var)."'";
+	}
+	
+	function zbx_dbcast_2bigint($field){
+		return ' CAST('.$field.' AS UNSIGNED) ';
+	}
+}
+else if(isset($DB_TYPE) && $DB_TYPE == "POSTGRESQL") {
+	function zbx_dbstr($var)	{
+		return "'".pg_escape_string($var)."'";
+	}
+	
+	function zbx_dbcast_2bigint($field){
+		return ' CAST('.$field.' AS BIGINT) ';
+	}
+}
+else {			
+	function zbx_dbstr($var)	{
+		return "'".addslashes($var)."'";
+	}
+	
+	function zbx_dbcast_2bigint($field){
+		return ' CAST('.$field.' AS BIGINT) ';
+	}
+} 
 
 	function	zbx_dbconcat($params)
 	{
@@ -460,6 +499,18 @@ if(isset($DB_TYPE) && $DB_TYPE == "ORACLE") {
 		}
 	}
 
+	function zbx_sql_mod($x,$y){
+		global $DB_TYPE;
+
+		switch($DB_TYPE)
+		{
+			case "SQLITE3":
+				return ' ('.$x.' %% '.$y.')';
+			default:
+				return ' MOD('.$x.','.$y.')';
+		}
+	}
+
 	function DBid2nodeid($id_name)
 	{
 		global $DB_TYPE;
@@ -528,7 +579,7 @@ if(isset($DB_TYPE) && $DB_TYPE == "ORACLE") {
 			fatal_error('Incorrect type of "nodes" for "in_node". Passed ['.gettype($nodes).']');
 		}
 
-		return in_array(id2nodeid($id_var), $nodes);
+		return uint_in_array(id2nodeid($id_var), $nodes);
 	}
 
 	function	get_dbid($table,$field)
@@ -538,21 +589,28 @@ if(isset($DB_TYPE) && $DB_TYPE == "ORACLE") {
 		$found = false;
 		do
 		{
-			$row = DBfetch(DBselect('select nextid from ids '.
-						' where nodeid='.$nodeid.
-						' and table_name=\''.$table.'\' '.
-						' and field_name=\''.$field.'\''));
+			global $ZBX_LOCALNODEID;
 
-			if(!$row || is_null($row["nextid"]))
+			$min=bcadd(bcmul($nodeid,"100000000000000"),bcmul($ZBX_LOCALNODEID,"100000000000"));
+			$max=bcadd(bcadd(bcmul($nodeid,"100000000000000"),bcmul($ZBX_LOCALNODEID,"100000000000")),"99999999999");
+			$row = DBfetch(DBselect("select nextid from ids where nodeid=$nodeid and table_name='$table' and field_name='$field'"));
+			if(!$row)
 			{
-				$row=DBfetch(DBselect("select max($field) as id from $table where ".DBin_node($field, $nodeid)));
+				$row=DBfetch(DBselect("select max($field) as id from $table where $field>=$min and $field<=$max"));
 				if(!$row || is_null($row["id"]))
 				{
 					DBexecute("insert into ids (nodeid,table_name,field_name,nextid) ".
-						" values ($nodeid,'$table','$field',".bcadd(bcmul($nodeid,"100000000000000"),1).")");
+						" values ($nodeid,'$table','$field',$min)");
 				}
 				else
 				{
+					/*
+					$ret1 = $row["id"];
+					if($ret1 >= $max) {
+						"Maximum number of id's was exceeded"
+					}
+					*/
+
 					DBexecute("insert into ids (nodeid,table_name,field_name,nextid) values ($nodeid,'$table','$field',".$row["id"].")");
 				}
 				continue;
@@ -560,6 +618,10 @@ if(isset($DB_TYPE) && $DB_TYPE == "ORACLE") {
 			else
 			{
 				$ret1 = $row["nextid"];
+				if((bccomp($ret1,$min) < 0) || !(bccomp($ret1,$max) < 0)) {
+					DBexecute("delete from ids where nodeid=$nodeid and table_name='$table' and field_name='$field'");
+					continue;
+				}
 	
 				DBexecute("update ids set nextid=nextid+1 where nodeid=$nodeid and table_name='$table' and field_name='$field'");
 	
@@ -583,4 +645,28 @@ if(isset($DB_TYPE) && $DB_TYPE == "ORACLE") {
 
 		return $ret2;
 	}
+
+	function DBin_condition($fieldname, $array)
+	{
+		global $DB_TYPE;
+
+		$condition = $fieldname.' IN (';
+		
+		switch($DB_TYPE) {
+			case 'ORACLE':
+				$items = array_chunk($array, 1000);
+				$chunks = count($items);
+				for ($i = 0; $i < $chunks; $i++) {
+					if ($i > 0)
+						$condition .= ') OR '.$fieldname.' IN (';
+					$condition .= implode(",",$items[$i]);
+				}
+				$condition .= ')';
+				if ($chunks > 1)
+					$condition = '('.$condition.')';
+				return $condition;
+			default:
+				return $condition.implode(",",$array).')';
+		}
+	}
 ?>
