@@ -339,6 +339,9 @@
 	define('ZBX_NODE_LOCAL',	1);
 	define('ZBX_NODE_MASTER',	2);
 
+	define('ZBX_FLAG_TRIGGER',	0);
+	define('ZBX_FLAG_EVENT',	1);
+
 	define('HTTPTEST_STATUS_ACTIVE',	0);
 	define('HTTPTEST_STATUS_DISABLED',	1);
 
@@ -422,10 +425,15 @@
 	define('ZBX_EXPRESSION_MACRO_ID', 13);
 	define('ZBX_EXPRESSION_RIGHT_ID', 14);
 
+/* Define if your logs are in non-standard format */
+/*	define('ZBX_LOG_ENCODING_DEFAULT', 'Shift_JIS');*/
+
 	define('ZBX_MIN_PERIOD', 3600);
 	define('ZBX_MAX_PERIOD', 12*31*24*3600);
 	define('ZBX_PERIOD_DEFAULT', ZBX_MIN_PERIOD);
 
+	define('ZBX_HAVE_IPV6', 1);
+
 	global $_GET, $_POST, $_COOKIE, $_REQUEST;
 
 /* Support for PHP5. PHP5 does not have $HTTP_..._VARS */
