@@ -77,11 +77,11 @@
 
 		switch($drawtype)
 		{
-			case GRAPH_ITEM_DRAWTYPE_LINE:		$drawtype = "Line";		break;
-			case GRAPH_ITEM_DRAWTYPE_FILLED_REGION:	$drawtype = "Filled region";	break;
-			case GRAPH_ITEM_DRAWTYPE_BOLD_LINE:	$drawtype = "Bold line";	break;
-			case GRAPH_ITEM_DRAWTYPE_DOT:		$drawtype = "Dot";		break;
-			case GRAPH_ITEM_DRAWTYPE_DASHED_LINE:	$drawtype = "Dashed line";	break;
+			case GRAPH_ITEM_DRAWTYPE_LINE:		$drawtype = S_LINE;		break;
+			case GRAPH_ITEM_DRAWTYPE_FILLED_REGION:	$drawtype = S_FILLED_REGION;	break;
+			case GRAPH_ITEM_DRAWTYPE_BOLD_LINE:	$drawtype = S_BOLD_LINE;	break;
+			case GRAPH_ITEM_DRAWTYPE_DOT:		$drawtype = S_DOT;		break;
+			case GRAPH_ITEM_DRAWTYPE_DASHED_LINE:	$drawtype = S_DASHED_LINE;	break;
 			default: $drawtype = S_UNKNOWN;		break;
 		}
 		return $drawtype;
@@ -206,9 +206,9 @@
 
 		foreach($gitems as $gitem)
 		{
-			if ( !($db_item = DBfetch(DBselect('select new.itemid from items new, items dest '.
+			if ( !($db_item = DBfetch(DBselect('select src.itemid from items src, items dest '.
 					       ' where dest.itemid='.$gitem['itemid'].
-					       ' and new.key_=dest.key_ and new.hostid='.$dest_hostid))) )
+					       ' and src.key_=dest.key_ and src.hostid='.$dest_hostid))) )
 			{
 
 				$item = get_item_by_itemid($gitem['itemid']);
@@ -414,7 +414,7 @@
 				$new_hostid = $db_item['hostid'];
 			}
 
-			if ( $host['hostid'] != $new_hostid )
+			if ( (bccomp($host['hostid'] ,$new_hostid ) != 0))
 			{
 				error('You must use items only from host "'.$host['host'].'" for template graph "'.$name.'"');
 				return $result;
@@ -595,7 +595,7 @@
 
 				$tmp_host = DBfetch(get_hosts_by_graphid($db_graph['templateid']));
 
-				if( !in_array($tmp_host['hostid'], $templateid))
+				if( !uint_in_array($tmp_host['hostid'], $templateid))
 					continue;
 			}
 
@@ -790,12 +790,13 @@
 			array_push($saved_request,$ext_saved_request);
 
 		$form = new CForm($url);
-
+		$form->SetMethod('get');	
+		
 		$form->AddItem(S_PERIOD.SPACE);
 
 		$period = get_request('period',ZBX_PERIOD_DEFAULT);
 
-		if(in_array($period,array(3600,2*3600,4*3600,8*3600,12*3600,24*3600,7*24*3600,31*24*3600,365*24*3600)))
+		if(uint_in_array($period,array(3600,2*3600,4*3600,8*3600,12*3600,24*3600,7*24*3600,31*24*3600,365*24*3600)))
 			$custom_per = ZBX_MIN_PERIOD;
 		else
 			$custom_per = $period;
