@@ -23,6 +23,7 @@ require_once "include/graphs.inc.php";
 require_once "include/profiles.inc.php";
 require_once "include/triggers.inc.php";
 require_once "include/items.inc.php";
+require_once "include/httptest.inc.php";
 
 /* HOST GROUP functions */
 	function	add_host_to_group($hostid, $groupid)
@@ -327,12 +328,13 @@ require_once "include/items.inc.php";
 	 * Comments: !!! Don't forget sync code with C !!!
 	 *
 	 */
-	function	unlink_template($hostid, $templateid, $unlink_mode = true)
-	{
-		if( !is_numeric($templateid) ) fatal_error('Not supported type for [templateid] in [unlink_template] - ['.$templateid.']');
+	function	unlink_template($hostid, $templateid, $unlink_mode = true){
+		if(!is_numeric($templateid)) 
+			fatal_error('Not supported type for [templateid] in [unlink_template] - ['.$templateid.']');
 
-		delete_template_elements($hostid, $templateid, $unlink_mode);
-		DBexecute("delete from hosts_templates where hostid=".$hostid.' and templateid='.$templateid);
+		$result = delete_template_elements($hostid, $templateid, $unlink_mode);
+		$result&= DBexecute("delete from hosts_templates where hostid=".$hostid.' and templateid='.$templateid);
+	return $result;
 	}
 
 	/*
@@ -353,6 +355,7 @@ require_once "include/items.inc.php";
 		delete_template_triggers($hostid, $templateid, $unlink_mode);
 		delete_template_items($hostid, $templateid, $unlink_mode);
 		delete_template_applications($hostid, $templateid, $unlink_mode);
+	return true;
 	}	
 
 	/*
@@ -454,17 +457,23 @@ require_once "include/items.inc.php";
 
 	// disable actions
 		$db_actions = DBselect("select distinct actionid from conditions ".
-			" where conditiontype=".CONDITION_TYPE_HOST." and value=".$hostid);
+			" where conditiontype=".CONDITION_TYPE_HOST." and value=".zbx_dbstr($hostid));
 		while($db_action = DBfetch($db_actions))
 		{
 			DBexecute("update actions set status=".ACTION_STATUS_DISABLED.
 				" where actionid=".$db_action["actionid"]);
 		}
 	// delete action conditions
-		DBexecute('delete from conditions where conditiontype='.CONDITION_TYPE_HOST.' and value='.$hostid);
+		DBexecute('delete from conditions where conditiontype='.CONDITION_TYPE_HOST.' and value='.zbx_dbstr($hostid));
 
 	// delete host profile
 		delete_host_profile($hostid);
+		
+	// delete web tests
+		$db_httptests = get_httptests_by_hostid($hostid);
+		while($db_httptest = DBfetch($db_httptests)){
+			delete_httptest($db_httptest['httptestid']);
+		}
 
 	// delete host
 		return DBexecute("delete from hosts where hostid=$hostid");
@@ -587,33 +596,37 @@ require_once "include/items.inc.php";
 		{
 			fatal_error("Incorrest options for get_correct_group_and_host");
 		}
-
+		
 		global $USER_DETAILS;
 		
 		$first_hostid_in_group = 0;
 
-		$allow_all_hosts = (in_array("allow_all_hosts",$options)) ? 1 : 0;
-		$always_select_first_host = in_array("always_select_first_host",$options) ? 1 : 0;
-		$only_current_node = in_array("only_current_node",$options) ? 1 : 0;
+		$allow_all_hosts = (str_in_array("allow_all_hosts",$options)) ? 1 : 0;
+		$always_select_first_host = str_in_array("always_select_first_host",$options) ? 1 : 0;
+		$only_current_node = str_in_array("only_current_node",$options) ? 1 : 0;
 
-		if(in_array("monitored_hosts",$options))
+		if(str_in_array("monitored_hosts",$options))
 			$with_host_status = " and h.status=".HOST_STATUS_MONITORED;
-		elseif(in_array('real_hosts',$options))
+		elseif(str_in_array('real_hosts',$options))
 			$with_host_status = " and h.status<>".HOST_STATUS_TEMPLATE;
 		else
 			$with_host_status = "";
 
-		if(in_array("with_monitored_items",$options)){
+		if(str_in_array("with_monitored_items",$options)){
 			$item_table = ",items i";	$with_items = " and h.hostid=i.hostid and i.status=".ITEM_STATUS_ACTIVE;
-		}elseif(in_array("with_items",$options)){
+		}else if(str_in_array("with_items",$options)){
 			$item_table = ",items i";	$with_items = " and h.hostid=i.hostid";
 		} else {
-			$item_table = "";		$with_items = "";
+			$item_table = "";
+			$with_items = "";
 		}
 
 		$with_node = "";
 
-		$accessed_hosts = get_accessible_hosts_by_user($USER_DETAILS,$perm);
+		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,$perm,null,null,get_current_nodeid(!$only_current_node));
+
+//SDI(get_current_nodeid(!$only_current_node));
+//SDI($available_hosts);
 
 		if(is_null($a_groupid))
 		{
@@ -622,13 +635,30 @@ require_once "include/items.inc.php";
 		else
 		{
 			$groupid = $a_groupid;
+			
+			if(($groupid < 0) && str_in_array('always_select_first_group',$options)){
+				$with_node = ' AND '.DBin_node('g.groupid', get_current_nodeid(!$only_current_node));
+
+				$sql = 'SELECT DISTINCT g.name,g.groupid '.
+								' FROM groups g, hosts_groups hg, hosts h'.$item_table.
+								' WHERE hg.groupid=g.groupid '.
+									' AND h.hostid=hg.hostid '.
+									' AND h.hostid IN ('.$available_hosts.') '.
+									$with_host_status.
+									$with_items.
+									$with_node.
+								' ORDER BY g.name';
+//SDI($groupid);
+				$groupid=($grp = DBfetch(DBselect($sql,1)))?$grp['groupid']:0;
+//SDI($groupid);
+			}
 
 			if($groupid > 0)
 			{
 				$with_node = " and ".DBin_node('g.groupid', get_current_nodeid(!$only_current_node));
-				
+
 				if(!DBfetch(DBselect("select distinct g.groupid from groups g, hosts_groups hg, hosts h".$item_table.
-					" where hg.groupid=g.groupid and h.hostid=hg.hostid and h.hostid in (".$accessed_hosts.") ".
+					" where hg.groupid=g.groupid and h.hostid=hg.hostid and h.hostid in (".$available_hosts.") ".
 					" and g.groupid=".$groupid.$with_host_status.$with_items.$with_node)))
 				{
 					$groupid = 0;
@@ -636,6 +666,7 @@ require_once "include/items.inc.php";
 			}
 
 		}
+
 		if(is_null($a_hostid))
 		{
 			$hostid = 0;
@@ -662,9 +693,10 @@ require_once "include/items.inc.php";
 				}
 
 				$with_node = " and ".DBin_node('h.hostid',get_current_nodeid(!$only_current_node));
-				
+//SDI('C: '.$a_groupid.' : '.$a_hostid);
+
 				if($db_host = DBfetch(DBselect("select distinct h.hostid,h.host from hosts h ".$item_table.$group_table.
-					" where h.hostid in (".$accessed_hosts.") "
+					" where h.hostid in (".$available_hosts.") "
 					.$with_host_status.$with_items.$witth_group.$with_node.
 					" order by h.host")))
 				{
@@ -677,21 +709,20 @@ require_once "include/items.inc.php";
 				{
 					if(!DBfetch(DBselect("select distinct h.hostid from hosts h".$item_table.
 						" where h.hostid=".$hostid.$with_host_status.$with_items.$with_node.
-						" and h.hostid in (".$accessed_hosts.") ")))
+						" and h.hostid in (".$available_hosts.") ")))
 					{
 							$hostid = 0;
 					}
 				}
-
 				if(($hostid < 0) || ($hostid == 0 && $always_select_first_host == 1)) /* incorrect host */
 				{
 					$hostid = $first_hostid_in_group;
 				}
 			}
 		}
-
-		$group_correct	= ($groupid == $a_groupid) ? 1 : 0;
-		$host_correct	= ($hostid == $a_hostid) ? 1 : 0;
+		
+		$group_correct	= (bccomp($groupid ,$a_groupid)==0) ? 1 : 0;
+		$host_correct	= (bccomp($hostid ,$a_hostid)==0) ? 1 : 0;
 		return array(
 			"groupid"	=> $groupid,
 			"group_correct"	=> $group_correct,
@@ -721,10 +752,12 @@ require_once "include/items.inc.php";
 
 		$_REQUEST["groupid"]    = get_request("groupid", -1 );
 		$_REQUEST["hostid"]     = get_request("hostid", get_profile($host_var,0));
-		
+
 		if($_REQUEST["groupid"] == -1)
 		{
 			$_REQUEST["groupid"] = get_profile($group_var,0);
+			
+			if(!in_node($_REQUEST["groupid"])) $_REQUEST["groupid"] = 0;
 
 			if ($_REQUEST["hostid"] > 0 && !DBfetch(DBselect('select groupid from hosts_groups '.
 				' where hostid='.$_REQUEST["hostid"].' and groupid='.$_REQUEST["groupid"])))
@@ -732,15 +765,15 @@ require_once "include/items.inc.php";
 					$_REQUEST["groupid"] = 0;
 			}
 		}
-		
-		if(in_array("always_select_first_host",$options) && $_REQUEST["hostid"] == 0 && $_REQUEST["groupid"] != 0)
+
+		if(uint_in_array("always_select_first_host",$options) && $_REQUEST["hostid"] == 0 && $_REQUEST["groupid"] != 0)
 			$_REQUEST["hostid"] = -1;
 
 		$result = get_correct_group_and_host($_REQUEST["groupid"],$_REQUEST["hostid"], $perm, $options);
 
 		$_REQUEST["groupid"]    = $result["groupid"];
 		$_REQUEST["hostid"]     = $result["hostid"];
-
+		
 		update_profile($host_var,$_REQUEST["hostid"]);
 		update_profile($group_var,$_REQUEST["groupid"]);
 	}
@@ -757,14 +790,16 @@ require_once "include/items.inc.php";
 	 * Comments:
 	 *
 	 */
-	function	validate_group($perm, $options = array(),$group_var=null)
-	{
+	function	validate_group($perm, $options = array(),$group_var=null){
 		if(is_null($group_var)) $group_var = "web.latest.groupid";
-
 		$_REQUEST["groupid"]    = get_request("groupid",get_profile($group_var,0));
 
+		if(!in_node($_REQUEST["groupid"])) $_REQUEST["groupid"] = 0;
+		
+		if(str_in_array('always_select_first_group',$options) && ($_REQUEST['groupid'] == 0))
+			$_REQUEST['groupid'] = -1;
+		
 		$result = get_correct_group_and_host($_REQUEST["groupid"],null,$perm,$options);
-
 		$_REQUEST["groupid"]    = $result["groupid"];
 
 		update_profile($group_var,$_REQUEST["groupid"]);
@@ -815,7 +850,7 @@ require_once "include/items.inc.php";
 
 		$host = get_host_by_hostid($hostid);
 		
-		if($applicationid==null)
+		if(is_null($applicationid))
 		{
 			$applicationid_new = get_dbid("applications","applicationid");
 			if($result = DBexecute("insert into applications (applicationid,name,hostid,templateid)".
@@ -832,7 +867,7 @@ require_once "include/items.inc.php";
 
 		if(!$result)	return $result;
 
-		if($applicationid==null)
+		if(is_null($applicationid))
 		{// create application for childs
 			$applicationid = $applicationid_new;
 
@@ -983,13 +1018,11 @@ require_once "include/items.inc.php";
 		return	false;
 	}
 
-	function	&get_items_by_applicationid($applicationid)
-	{
+	function &get_items_by_applicationid($applicationid){
 		return DBselect("select i.* from items i,items_applications ia where i.itemid=ia.itemid and ia.applicationid=$applicationid");
 	}
 
-	function	&get_applications_by_hostid($hostid)
-	{
+	function &get_applications_by_hostid($hostid){
 		return DBselect('select * from applications where hostid='.$hostid);
 	}
 
@@ -1007,11 +1040,9 @@ require_once "include/items.inc.php";
 	 *           $templateid can be numeric or numeric array
 	 *
 	 */
-	function        delete_template_applications($hostid, $templateid = null, $unlink_mode = false)
-	{
+	function delete_template_applications($hostid, $templateid = null, $unlink_mode = false){
 		$db_apps = get_applications_by_hostid($hostid);
-		while($db_app = DBfetch($db_apps))
-		{
+		while($db_app = DBfetch($db_apps)){
 			if($db_app["templateid"] == 0)
 				continue;
 
@@ -1023,7 +1054,7 @@ require_once "include/items.inc.php";
 				unset($skip);
 				if( ($tmp_app_data = get_application_by_applicationid($db_app["templateid"])) )
 				{
-					if( !in_array($tmp_app_data["hostid"], $templateid) )
+					if( !uint_in_array($tmp_app_data["hostid"], $templateid) )
 					{
 						$skip = true;
 						break;
