@@ -231,7 +231,7 @@
 			if(eregi('^((.)*)(\[\"((.)*)\"\,\"((.)*)\"\,\"((.)*)\"\,\"([0-9]+)\"\])$', $key, $arr))
 			{
 				$g=$arr[1];
-				if(!in_array($g,array("grpmax","grpmin","grpsum","grpavg")))
+				if(!str_in_array($g,array("grpmax","grpmin","grpsum","grpavg")))
 				{
 					error("Group function [$g] is not one of [grpmax,grpmin,grpsum,grpavg]");
 					return FALSE;
@@ -242,7 +242,7 @@
 				$g=$arr[6];
 				// Item function
 				$g=$arr[8];
-				if(!in_array($g,array("last", "min", "max", "avg", "sum","count")))
+				if(!str_in_array($g,array("last", "min", "max", "avg", "sum","count")))
 				{
 					error("Item function [$g] is not one of [last, min, max, avg, sum,count]");
 					return FALSE;
@@ -423,13 +423,18 @@
 
 		DBexecute("update items set lastlogsize=0 where itemid=$itemid and key_<>".zbx_dbstr($key));
 
-		$result = DBexecute("delete from items_applications where itemid=$itemid");
-		foreach($applications as $appid)
-		{
-			$itemappid=get_dbid("items_applications","itemappid");
-			DBexecute("insert into items_applications (itemappid,itemid,applicationid) values($itemappid,".$itemid.",".$appid.")");
+		if(isset($_REQUEST['applications_visible'])){	
+			$result = DBexecute("delete from items_applications where itemid=$itemid");
+			foreach($applications as $appid)
+			{
+				$itemappid=get_dbid("items_applications","itemappid");
+				DBexecute("insert into items_applications (itemappid,itemid,applicationid) values($itemappid,".$itemid.",".$appid.")");
+			}
 		}
 
+		if ($status == ITEM_STATUS_ACTIVE)
+			DBexecute("update items set error='' where itemid=$itemid and status<>$status");
+
 		$result=DBexecute(
 			"update items set description=".zbx_dbstr($description).",key_=".zbx_dbstr($key).",".
 			"hostid=$hostid,delay=$delay,history=$history,nextcheck=0,type=$type,status=".$status.','.
@@ -492,7 +497,8 @@
 					"trends"		=> array('template' => 1 , 'httptest' => 1),
 					"logtimefmt"		=> array(),
 					"valuemapid"		=> array('httptest' => 1),
-					"delay_flex"		=> array());
+					"delay_flex"		=> array()
+					);
 
 		$item_data = get_item_by_itemid($itemid);
 
@@ -549,7 +555,7 @@
 
 				$db_tmp_item = get_item_by_itemid($db_item["templateid"]);
 
-				if ( !in_array($db_tmp_item["hostid"], $templateid) )
+				if ( !uint_in_array($db_tmp_item["hostid"], $templateid) )
 					continue;
 			}
 
@@ -676,12 +682,10 @@
 
 	# Activate Item
 
-	function	activate_item($itemid)
-	{
+	function	activate_item($itemid){
 		 // first update status for child items
 		$db_tmp_items = DBselect("select itemid, hostid from items where templateid=$itemid");
-		while($db_tmp_item = DBfetch($db_tmp_items))
-		{
+		while($db_tmp_item = DBfetch($db_tmp_items)){
 		// recursion
 			activate_item($db_tmp_item["itemid"]);
 		}
@@ -859,28 +863,43 @@ COpt::profiling_start('prepare data');
 
 		unset($items);
 		unset($hosts);
-		while($row = DBfetch($result))
-		{
+		// get rid of warnings about $triggers undefined
+		$items = array();
+		while($row = DBfetch($result)){
+			$descr = item_description($row["description"],$row["key_"]);
 			$row['host'] = get_node_name_by_elid($row['hostid']).$row['host'];
-			$hosts[$row['host']] = $row['host'];
-			$items[item_description($row["description"],$row["key_"])][$row['host']] = array(
-				'itemid'	=> $row['itemid'],
-				'value_type'	=> $row['value_type'],
-				'lastvalue'	=> $row['lastvalue'],
-				'units'		=> $row['units'],
-				'description'	=> $row['description'],
-				'valuemapid'    => $row['valuemapid'],
-				'severity'	=> $row['priority'],
-				'tr_value'	=> $row['tr_value'],
-				'triggerid'	=> $row['triggerid']
+			$hosts[strtolower($row['host'])] = $row['host'];
+
+			// A little tricky check for attempt to overwrite active trigger (value=1) with
+			// inactive or active trigger with lower priority.
+			if (!isset($items[$descr][$row['host']]) ||
+				(
+					(($items[$descr][$row['host']]['tr_value'] == TRIGGER_VALUE_FALSE) && ($row['tr_value'] == TRIGGER_VALUE_TRUE)) ||
+					(
+						(($items[$descr][$row['host']]['tr_value'] == TRIGGER_VALUE_FALSE) || ($row['tr_value'] == TRIGGER_VALUE_TRUE)) &&
+						($row['priority'] > $items[$descr][$row['host']]['severity'])
+					)
+				)
+			)
+			{
+					$items[$descr][$row['host']] = array(
+					'itemid'	=> $row['itemid'],
+					'value_type'=> $row['value_type'],
+					'lastvalue'	=> $row['lastvalue'],
+					'units'		=> $row['units'],
+					'description'=> $row['description'],
+					'valuemapid' => $row['valuemapid'],
+					'severity'	=> $row['priority'],
+					'tr_value'	=> $row['tr_value'],
+					'triggerid'	=> $row['triggerid']
 				);
+			}
 		}
-		if(!isset($hosts))
-		{
+		if(!isset($hosts)){
 			return $table;
 		}
 
-		sort($hosts);
+		ksort($hosts);
 COpt::profiling_stop('prepare data');
 COpt::profiling_start('prepare table');
 		$header=array(new CCol(S_ITEMS,'center'));
@@ -1016,6 +1035,9 @@ COpt::profiling_stop('prepare table');
 		if($use_housekeeper)
 		{
 			$housekeeperid = get_dbid('housekeeper','housekeeperid');
+			DBexecute("insert into housekeeper (housekeeperid,tablename,field,value)".
+				" values ($housekeeperid,'history_text','itemid',$itemid)");
+			$housekeeperid = get_dbid('housekeeper','housekeeperid');
 			DBexecute("insert into housekeeper (housekeeperid,tablename,field,value)".
 				" values ($housekeeperid,'history_log','itemid',$itemid)");
 			$housekeeperid = get_dbid('housekeeper','housekeeperid');
@@ -1030,6 +1052,7 @@ COpt::profiling_stop('prepare table');
 			return TRUE;
 		}
 
+		DBexecute("delete from history_text where itemid=$itemid");
 		DBexecute("delete from history_log where itemid=$itemid");
 		DBexecute("delete from history_uint where itemid=$itemid");
 		DBexecute("delete from history_str where itemid=$itemid");
@@ -1056,7 +1079,23 @@ COpt::profiling_stop('prepare table');
 	
 	function	format_lastvalue($db_item)
 	{
-		if(isset($db_item["lastvalue"]))
+		if($db_item["value_type"] == ITEM_VALUE_TYPE_LOG)
+		{
+			$row=DBfetch(DBselect("select max(id) as max from history_log where itemid=".$db_item["itemid"]));
+
+			if($row && !is_null($row['max']))
+			{
+				$row2=DBfetch(DBselect("select value from history_log where id=".$row["max"]));
+				$lastvalue=nbsp(htmlspecialchars(substr($row2["value"],0,20)));
+				if(strlen($db_item["lastvalue"]) > 20)
+					$lastvalue .= " ...";
+			}
+			else
+			{
+				$lastvalue="-";
+			}
+		}
+		else if(isset($db_item["lastvalue"]))
 		{
 			if($db_item["value_type"] == ITEM_VALUE_TYPE_FLOAT)
 			{
@@ -1070,11 +1109,15 @@ COpt::profiling_stop('prepare table');
 			{
 				$lastvalue="...";
 			}
+			else if($db_item["value_type"] == ITEM_VALUE_TYPE_STR)
+			{
+					$lastvalue=nbsp(htmlspecialchars(substr($db_item["lastvalue"],0,20)));
+					if(strlen($db_item["lastvalue"]) > 20)
+						$lastvalue .= " ...";
+			}
 			else
 			{
-				$lastvalue=nbsp(htmlspecialchars(substr($db_item["lastvalue"],0,20)));
-				if(strlen($db_item["lastvalue"]) > 20)
-					$lastvalue .= " ...";
+				$lastvalue="Unknown value type";
 			}
 			if($db_item["valuemapid"] > 0);
 				$lastvalue = replace_value_by_map($lastvalue, $db_item["valuemapid"]);
@@ -1086,4 +1129,66 @@ COpt::profiling_stop('prepare table');
 		}
 		return $lastvalue;
 	}
+
+	/*
+	 * Function: item_get_history
+	 *
+	 * Description:
+	 *     Get value from history
+	 *
+	 * Peremeters:
+	 *     itemid - item ID
+	 *     last  - 0 - last value (clock is used), 1 - last value
+	 *
+	 * Author:
+	 *     Alexei Vladishev
+	 *
+	 * Comments:
+	 *
+	 */
+	function	item_get_history($db_item, $last = 1, $clock = 0)
+	{
+		$value = NULL;
+
+		switch($db_item["value_type"])
+		{
+		case	ITEM_VALUE_TYPE_FLOAT:
+			$table = "history";
+			break;
+		case	ITEM_VALUE_TYPE_UINT64:
+			$table = "history_uint";
+			break;
+		case	ITEM_VALUE_TYPE_TEXT:
+			$table = "history_text";
+			break;
+		case	ITEM_VALUE_TYPE_STR:
+			$table = "history_str";
+			break;
+		case	ITEM_VALUE_TYPE_LOG:
+		default:
+			$table = "history_log";
+			break;
+		}
+		if ($last == 0)
+		{
+			$sql = "select value from $table where itemid=".$db_item["itemid"]." and clock=$clock";
+			$row = DBfetch(DBselect($sql, 1));
+			if($row)
+				$value = $row["value"];
+		}
+		else
+		{
+			$sql = "select max(clock) as clock from $table where itemid=".$db_item["itemid"];
+			$row = DBfetch(DBselect($sql));
+			if ($row && !is_null($row["clock"]))
+			{
+				$clock = $row["clock"];
+				$sql = "select value from $table where itemid=".$db_item["itemid"]." and clock=$clock";
+				$row = DBfetch(DBselect($sql, 1));
+				if($row)
+					$value = $row["value"];
+			}
+		}
+		return $value;
+	}
 ?>
