@@ -62,11 +62,6 @@
 	"S_AVERAGE"=>				"Average",
 	"S_HIGH"=>				"",
 	"S_DISASTER"=>				"",
-	"S_REPEAT"=>				"ظ",
-	"S_REPEATS"=>				"ظ",
-	"S_NO_REPEATS"=>			"ظ",
-	"S_NUMBER_OF_REPEATS"=>			"ظ",
-	"S_DELAY_BETWEEN_REPEATS"=>		"ظ",
 
 //	alarms.php
 	"S_ALARMS"=>				"alarms",
@@ -197,17 +192,8 @@
 	"S_IMAGE_UPDATED"=>			"Image updated",
 	"S_CANNOT_UPDATE_IMAGE"=>		"Cannot update image",
 	"S_UPDATE_SELECTED_IMAGE"=>		"Update selected image?",
-	"S_AUTOREGISTRATION"=>			"Autoregistration",
-	"S_AUTOREGISTRATION_RULES_BIG"=>	"AUTOREGISTRATION RULES",
 	"S_PRIORITY"=>				"ȼ",
 	"S_PATTERN"=>				"Pattern",
-	"S_NO_AUTOREGISTRATION_RULES_DEFINED"=>	"No autoregistration rules defined",
-	"S_AUTOREGISTRATION_ADDED"=>		"Autoregistration added",
-	"S_CANNOT_ADD_AUTOREGISTRATION"=>	"Canot add autoregistration",
-	"S_AUTOREGISTRATION_UPDATED"=>		"Autoregistration updated",
-	"S_AUTOREGISTRATION_WAS_NOT_UPDATED"=>	"Autoregistration was not updated",
-	"S_AUTOREGISTRATION_DELETED"=>		"Autoregistration deleted",
-	"S_AUTOREGISTRATION_WAS_NOT_DELETED"=>	"Autoregistration was not deleted",
 	"S_OTHER"=>				"Other",
 	"S_OTHER_PARAMETERS"=>			"",
 	"S_REFRESH_UNSUPPORTED_ITEMS"=>		"Refresh unsupported items (in sec)",
