@@ -188,6 +188,7 @@
 //	acknow.php
 	'S_ACKNOWLEDGES'=>			'Acknowledges',
 	'S_ACKNOWLEDGE'=>			'Acknowledge',
+	'S_RETURN'=>				'Return',
 	'S_ACKNOWLEDGE_ALARM_BY'=>		'Acknowledge alarm by',
 	'S_ADD_COMMENT_BY'=>			'Add comment by',
 	'S_COMMENT_ADDED'=>			'Comment added',
@@ -283,6 +284,7 @@
 	'S_AND_OR_BIG'=>			'AND / OR',
 	'S_AND_BIG'=>				'AND',
 	'S_AND'=>				'and',
+	'S_AND_SYMB'=>			'&',
 	'S_OR_BIG'=>				'OR',
 	'S_OR'=>				'or',
 	'S_TYPE_OF_CALCULATION'=>		'Type of calculation',
@@ -295,6 +297,7 @@
 	'S_NOT_LIKE_SMALL'=>			'not like',
 	'S_IN_SMALL'=>				'in',
 	'S_NOT_IN_SMALL'=>			'not in',
+	'S_RETRIES_LEFT'=>			'Retries left',
 
 //	alarms.php
 	'S_ALARMS'=>				'Alarms',
@@ -364,6 +367,13 @@
 	'S_WHITE'=>				'White',
 	'S_YELLOW'=>				'Yellow',
 
+// Lines
+	'S_LINE'=>				'Line',
+	'S_FILLED_REGION'=>			'Filled region',
+	'S_BOLD_LINE'=>				'Bold line',
+	'S_DOT'=>				'Dot',
+	'S_DASHED_LINE'=>			'Dashed line',
+
 //	config.php
 	'S_CANNNOT_UPDATE_VALUE_MAP'=>		'Cannot update value map',
 	'S_VALUE_MAP_ADDED'=>			'Value map added',
@@ -474,8 +484,8 @@
 	'S_COMPARE'=>				'Compare',
 
 //	Footer
-	'S_ZABBIX_VER'=>			'ZABBIX 1.4.2',
-	'S_COPYRIGHT_BY'=>			'Copyright 2001-2007 by ',
+	'S_ZABBIX_VER'=>			'ZABBIX 1.4.6',
+	'S_COPYRIGHT_BY'=>			'Copyright 2001-2008 by ',
 	'S_CONNECTED_AS'=>			'Connected as',
 	'S_SIA_ZABBIX'=>			'SIA Zabbix',
 
@@ -546,6 +556,7 @@
 	'S_LOCAL'=>				'Local',
 	'S_SOURCE'=>				'Source',
 	'S_SHOW_UNKNOWN'=>			'Show unknown',
+	'S_HIDE_UNKNOWN'=>			'Hide unknown',
 
 	'S_SHOW_SELECTED'=>			'Show selected',
 	'S_HIDE_SELECTED'=>			'Hide selectede',
@@ -778,6 +789,7 @@
 	'S_ORIGINAL'=>				'Original',
 	'S_NEW_FLEXIBLE_INTERVAL'=>		'New flexible interval',
 	'S_FLEXIBLE_INTERVALS'=>		'Flexible intervals (sec)',
+	'S_NO_FLEXIBLE_INTERVALS'=>		'No flexible intervals',
 
 //	events.php
 	'S_LATEST_EVENTS'=>			'Latest events',
@@ -791,7 +803,6 @@
 
 //	sysmap.php
 	'S_LINK'=>				'Link',
-	'S_LABEL'=>				'Label',
 	'S_X'=>					'X',
 	'S_Y'=>					'Y',
 	'S_ICON_ON'=>				'Icon (on)',
@@ -801,11 +812,23 @@
 	'S_ELEMENT_2'=>				'Element 2',
 	'S_LINK_STATUS_INDICATOR'=>		'Link status indicator',
 	'S_CONFIGURATION_OF_NETWORK_MAPS'=>	'Configuration of network maps',
+	'S_CONFIGURATION_OF_NETWORK_MAPS_BIG'=>	'CONFIGURATION OF NETWORK MAPS',
+	'S_DISPLAYED_ELEMENTS'=>		'DISPLAYED ELEMENTS',
+	'S_CONNECTORS'=>			'CONNECTORS',
+	'S_ADD_ELEMENT'=>			'Add element',
+	'S_CREATE_CONNECTION'=>			'Create connection',
+	'S_COORDINATE_X'=>			'Coordinate X',
+	'S_COORDINATE_Y'=>			'Coordinate Y',
+	'S_TYPE_OFF'=>				'Type (OFF)',
+	'S_TYPE_ON'=>				'Type (ON)',
+	'S_COLOR_OFF'=>				'Color (OFF)',
+	'S_COLOR_ON'=>				'Color (ON)',
+	
+	
 
 //	sysmaps.php
 	'S_MAPS_BIG'=>				'MAPS',
 	'S_NO_MAPS_DEFINED'=>			'No maps defined',
-	'S_CONFIGURATION_OF_NETWORK_MAPS'=>	'CONFIGURATION OF NETWORK MAPS',
 	'S_CREATE_MAP'=>			'Create Map',
 	'S_ICON_LABEL_LOCATION'=>		'Icon label location',
 	'S_BOTTOM'=>				'Bottom',
@@ -992,11 +1015,11 @@
 	'S_EDIT'=>				'Edit',
 	'S_DIMENSION_COLS_ROWS'=>		'Dimension (cols x rows)',
 
-	'S_SLIDESHOWS'=>			'Slideshows',
-	'S_SLIDESHOW'=>				'Slideshow',
-	'S_CONFIGURATION_OF_SLIDESHOWS_BIG'=>	'CONFIGURATION OF SLIDESHOWS',
-	'S_SLIDESHOWS_BIG'=>			'SLIDESHOWS',
-	'S_NO_SLIDESHOWS_DEFINED'=>		'No slideshows defined',
+	'S_SLIDESHOWS'=>			'Slide shows',
+	'S_SLIDESHOW'=>				'Slide show',
+	'S_CONFIGURATION_OF_SLIDESHOWS_BIG'=>	'CONFIGURATION OF SLIDE SHOWS',
+	'S_SLIDESHOWS_BIG'=>			'SLIDE SHOWS',
+	'S_NO_SLIDESHOWS_DEFINED'=>		'No slide shows defined',
 	'S_COUNT_OF_SLIDES'=>			'Count of slides',
 	'S_NO_SLIDES_DEFINED'=>			'No slides defined',
 	'S_SLIDES'=>				'Slides',
@@ -1024,9 +1047,9 @@
 
 	'S_STYLE'=>				'Style',
 	'S_VERTICAL'=>				'Vertical',
-	'S_HORISONTAL'=>			'Horisontal',
+	'S_HORISONTAL'=>			'Horizontal',
 
-	'S_HORISONTAL_ALIGN'=>			'Horisontal align',
+	'S_HORISONTAL_ALIGN'=>			'Horizontal align',
 	'S_LEFT'=>				'Left',
 	'S_CENTER'=>				'Center',
 	'S_RIGHT'=>				'Right',
@@ -1168,6 +1191,9 @@
 	'S_LAST_OF'=>				'Last of',
 	'S_SHOW_DISABLED_TRIGGERS'=>		'Show disabled triggers',
 	'S_HIDE_DISABLED_TRIGGERS'=>		'Hide disabled triggers',
+	'S_THE_TRIGGER_DEPENDS_ON'=>		'The trigger depends on',
+	'S_NO_DEPENDENCES_DEFINED'=>		'No dependences defined',
+	'S_NEW_DEPENDENCY'=>			'New dependency',
 
 
 //	tr_comments.php
@@ -1187,6 +1213,7 @@
 	'S_HIDE_DETAILS'=>			'Hide details',
 	'S_SHOW_DETAILS'=>			'Show details',
 	'S_SELECT'=>				'Select',
+	'S_INVERSE_SELECT'=>			'Inverse Select',
 	'S_HIDE_SELECT'=>			'Hide select',
 	'S_TRIGGERS_BIG'=>			'TRIGGERS',
 	'S_NAME_BIG'=>				'NAME',
@@ -1282,11 +1309,13 @@
 	'S_ITALIAN_IT'=>			'Italian (IT)',
 	'S_LATVIAN_LV'=>			'Latvian (LV)',
 	'S_RUSSIAN_RU'=>			'Russian (RU)',
+	'S_PORTUGUESE_PT'=>			'Portuguese (PT)',
 	'S_SPANISH_SP'=>			'Spanish (SP)',
 	'S_SWEDISH_SE'=>			'Swedish (SE)',
 	'S_JAPANESE_JP'=>			'Japanese (JP)',
 	'S_CHINESE_CN'=>			'Chinese (CN)',
 	'S_DUTCH_NL'=>				'Dutch (NL)',
+	'S_HUNGARY_HU'=>			'Hungary (HU)',
 
 //	index.php
 	'S_ZABBIX_BIG'=>			'ZABBIX',
