@@ -96,11 +96,6 @@
 	"S_AVERAGE"=>						"Gemiddelde",
 	"S_HIGH"=>							"Hoog",
 	"S_DISASTER"=>						"Catastrofe",
-	"S_REPEAT"=>						"Herhaal",
-	"S_REPEATS"=>						"Herhalingen",
-	"S_NO_REPEATS"=>					"Geen herhalingen",
-	"S_NUMBER_OF_REPEATS"=>				"Nummer herhalingen",
-	"S_DELAY_BETWEEN_REPEATS"=>			"Vertraging tussen herhalingen",
 	"S_CREATE_ACTION"=>					"Maak een actie",
 
 //	alarms.php
@@ -245,17 +240,8 @@
 	"S_IMAGE_UPDATED"=>					"Afbeelding bijgewerkt",
 	"S_CANNOT_UPDATE_IMAGE"=>			"Kan niet afbeelding bijwerken",
 	"S_UPDATE_SELECTED_IMAGE"=>			"Werk bij geselecteerde afbeelding?",
-	"S_AUTOREGISTRATION"=>				"Autoregistratie",
-	"S_AUTOREGISTRATION_RULES_BIG"=>	"AUTOREGISTRATIE REGELS",
 	"S_PRIORITY"=>						"Prioriteit",
 	"S_PATTERN"=>						"Patroon",
-	"S_NO_AUTOREGISTRATION_RULES_DEFINED"=>	"Geen autoregistratie regels gedefineerd",
-	"S_AUTOREGISTRATION_ADDED"=>			"Autoregistratie toegevoegd",
-	"S_CANNOT_ADD_AUTOREGISTRATION"=>		"Kan autoregistratie niet toevoegen",
-	"S_AUTOREGISTRATION_UPDATED"=>			"Autoregistratie bijgewerkt",
-	"S_AUTOREGISTRATION_WAS_NOT_UPDATED"=>	"Autoregistratie was niet bijgewerkt",
-	"S_AUTOREGISTRATION_DELETED"=>			"Autoregistratie verwijderd",
-	"S_AUTOREGISTRATION_WAS_NOT_DELETED"=>	"Autoregistratie was niet verwijderd",
 	"S_OTHER"=>								"Anders",
 	"S_OTHER_PARAMETERS"=>					"Andere parameters",
 	"S_REFRESH_UNSUPPORTED_ITEMS"=>		"Vernieuw niet ondersteunde items (in sec)",
@@ -269,7 +255,6 @@
 	"S_NO_PERMISSIONS"=>				"Geen toegang !",
 	"S_LATEST_DATA_BIG"=>				"LAATSTE DATA",
 	"S_ALL_SMALL"=>						"alle",
-	"S_ALL"=>							"Alle",
 	"S_MINUS_ALL_MINUS"=>				"- alle -",
 	"S_MINUS_OTHER_MINUS"=>				"- andere -",
 	"S_DESCRIPTION_LARGE"=>				"OMSCHRIJVING",
@@ -279,10 +264,7 @@
 	"S_COMPARE"=>						"Vergelijk",
 
 //	Footer
-	"S_ZABBIX_VER"=>					"ZABBIX 1.1",
-	"S_COPYRIGHT_BY"=>					"Auteursrecht 2001-2006 ",
 	"S_CONNECTED_AS"=>					"Verbonden als",
-	"S_SIA_ZABBIX"=>					"SIA Zabbix",
 
 //	graph.php
 	"S_CONFIGURATION_OF_GRAPH"=>		"Configuratie van grafieken",
