@@ -4,7 +4,7 @@
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
 ** Este programa es software libre; es posible redistribuirlo y/o modicarlo
-** bajo los trminos de la GNU General Public License publcada por 
+** bajo los trminos de la GNU General Public License publicada por 
 ** la Free Software Foundation; tanto la versin 2 de la Licencia como
 ** (a eleccin) cualquier versin posterior.
 **
@@ -13,7 +13,7 @@
 ** para uso COMERCIAL o PARTICULAR. Ver la Licencia
 ** Pblica General (GNU) para ms detalles.
 **
-** Debe haber recibido una copia de la Licencia Pcliba General (GNU)
+** Debe haber recibido una copia de la Licencia Pblica General (GNU)
 ** junto con este programa; de no ser as, escriba a Free Software
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/
@@ -26,20 +26,21 @@
 	'S_DATE_FORMAT_YMDHMS'=>		'd M H:i:s',
 	'S_DATE_FORMAT_YMD'=>			'd M Y',
 	'S_HTML_CHARSET'=>			'iso-8859-1',
-	'S_ACTIVATE_SELECTED'=>			'Activar seleccionados',
-	'S_DISABLE_SELECTED'=>			'Desactivar seleccionados',
-	'S_DELETE_SELECTED'=>			'Eliminar seleccionados',
-	'S_COPY_SELECTED_TO'=>			'Copiar seleccionados a ...',
+	'S_ACTIVATE_SELECTED'=>			'Activar',
+	'S_DISABLE_SELECTED'=>			'Desactivar',
+	'S_DELETE_SELECTED'=>			'Eliminar',
+	'S_COPY_SELECTED_TO'=>			'Copiar a ...',
 	
 //	dicoveryconf.php
 	'S_HOST_IP'=>				'IP del equipo',
 	'S_SERVICE_TYPE'=>			'Tipo de servicio',
 	'S_SERVICE_PORT'=>			'Puerto del servicio',
-	'S_DISCOVERY_STATUS'=>			'Estado de descubrimiento',
+	'S_DISCOVERY_STATUS'=>			'Estado del descubrimiento',
+	'S_RECEIVED_VALUE'=>			'Valor recibido',
 	'S_UPTIME_DOWNTIME'=>			'Tiempo operativo/Tiempo inoperativo',
 	'S_DISCOVERY_RULE'=>			'Regla de descubrimiento',
 	'S_DISCOVERY'=>				'Descubrimiento',
-	'S_DISCOVERY_BIG'=>			'DESCUBRIMIENTO',
+	'S_DISCOVERY_BIG'=>			'REGLAS DE DESCUBRIMIENTO',
 	'S_CONFIGURATION_OF_DISCOVERY'=>	'Configuracin de descubrimiento',
 	'S_CONFIGURATION_OF_DISCOVERY_BIG'=>	'CONFIGURACIN DE DESCUBRIMIENTO',
 	'S_NO_DISCOVERY_RULES_DEFINED'=>	'No se han definido reglas de descubrimiento',
@@ -93,6 +94,7 @@
 	'S_STATE'=>				'Estado',
 
 //	httpconf.php
+	'S_STATUS_CODES'=>			'Cdigos de estado',
 	'S_WEB'=>				'Web',
 	'S_CONFIGURATION_OF_WEB_MONITORING'=>	'Configuracin de la monitorizacin Web',
 	'S_CONFIGURATION_OF_WEB_MONITORING_BIG'=>'CONFIGURACIN DE LA MONITORIZACIN WEB',
@@ -110,7 +112,7 @@
 	'S_DISABLE_SELECTED_SCENARIOS_Q'=>	'Desactivar los escenarios seleccionados?',
 	'S_DELETE_SELECTED_SCENARIOS_Q'=>	'Eliminar los escenarios seleccionados?',
 	'S_DELETE_SCENARIO_Q'=>			'Eliminar escenario?',
-	'S_CLEAN_HISTORY_SELECTED_SCENARIOS'=>	'Limpiar el histrico de los escenarios selecionados?',
+	'S_CLEAN_HISTORY_SELECTED_SCENARIOS'=>	'Limpiar el histrico',
 	'S_SCENARIO_UPDATED'=>			'Escenario actualizado',
 	'S_CANNOT_UPDATE_SCENARIO'=>		'No es posible actualizar el escenario',
 	'S_SCENARIO_ADDED'=>			'Escenario aadido',
@@ -127,11 +129,11 @@
 	'S_STEP_OF_SCENARIO'=>			'Paso del escenario',
 
 //	exp_imp.php
-	'S_ELEMENT'=>				'Elemento',
+	'S_ELEMENT'=>				'Grupo',
 	'S_ELEMENTS'=>				'Elementos',
 	'S_ONLY_HOST_INFO'=>			'Slo informacin del equipo',
 	'S_EXPORT_IMPORT'=>			'Exportar/Importar',
-	'S_IMPORT_FILE'=>			'Importar fichero',
+	'S_IMPORT_FILE'=>			'Fichero para importar',
 	'S_IMPORT'=>				'Importar',
 	'S_IMPORT_BIG'=>			'IMPORTAR',
 	'S_IMPORT_HOSTS'=>			'Importar equipos',
@@ -142,10 +144,23 @@
 	'S_PREVIEW'=>				'Previsualizar',
 	'S_BACK'=>				'Retroceder',
 	'S_NO_DATA_FOR_EXPORT'=>		'No existen datos para exportar',
-	'S_RULES'=>				'Reglas',
-	'S_SKIP'=>				'Avanzar',
-	'S_EXISTING'=>				'Existe',
-	'S_MISSING'=>				'No existe',
+	'S_RULES'=>				'Reglas aplicables a cada grupo',
+	'S_SKIP'=>				'Omitir',
+	'S_EXISTING'=>				'Si existe',
+	'S_MISSING'=>				'Si no existe',
+	'S_REFRESH'=>				'Refrescar',
+
+//	admin.php
+	'S_PREVIOUS'=>				'<< Anterior',
+	'S_NEXT'=>				'Siguiente >>',
+	'S_RETRY'=>				'Reintentar',
+	'S_FINISH'=>				'Finalizar',
+	'S_FAIL'=>				'Ha fallado',
+	'S_UPDATE_BIG'=>			'ACTUALIZACIN',
+	'S_INSTALLATION'=>			'Instalacin',
+	'S_NEW_INSTALLATION'=>			'Nueva instalacin',
+	'S_NEW_INSTALLATION_BIG'=>		'NUEVA INSTALACIN',
+	'S_INSTALLATION_UPDATE'=>		'Instalacin/Actualizacin',
 
 //	node.php
 	'S_TIME_ZONE'=>				'Zona horaria',
@@ -161,7 +176,9 @@
 	'S_NODE_DELETED'=>			'Nodo eliminado',
 	'S_CANNOT_DELETE_NODE'=>		'No es posible eliminar el nodo',
 	'S_CURRENT_NODE'=>			'Nodo actual',
-	
+	'S_CURRENT_NODE_ONLY'=>			'Slo el nodo actual',
+	'S_WITH_SUBNODES'=>			'Incluir subnodos',
+
 //	acknow.php
 	'S_ACKNOWLEDGES'=>			'Aceptadas',
 	'S_ACKNOWLEDGE'=>			'Aceptada',
@@ -179,16 +196,16 @@
 	'S_FILTER_HOST'=>			'Filtro: Equipo',
 	'S_FILTER_TRIGGER'=>			'Filtro: Iniciador',
 	'S_FILTER_TRIGGER_NAME'=>		'Filtro: Nombre del iniciador',
-	'S_FILTER_TRIGGER_SEVERITY'=>		'Filtro: Severidad del iniciador',
-	'S_FILTER_WHEN_TRIGGER_BECOMES'=>	'Filtro: Cuando el iniciador se lanza',
-	'S_OPERATION_TYPE'=>			'Tipo de operacin',
+	'S_FILTER_TRIGGER_SEVERITY'=>		'Filtro: Gravedad del iniciador',
+	'S_FILTER_WHEN_TRIGGER_BECOMES'=>	'Filtro: Cuando se lanza el iniciador',
+	'S_OPERATION_TYPE'=>			'Operacin a realizar',
 	'S_SEND_MESSAGE'=>			'Enviar mensaje',
 	'S_REMOTE_COMMAND'=>			'Comando remoto',
 	'S_REMOTE_COMMANDS'=>			'Comandos remotos',
 	'S_FILTER'=>				'Filtro',
-	'S_FILTER_TYPE'=>			'Tipo de iniciador',
+	'S_FILTER_TYPE'=>			'Tipo de alerta',
 	'S_TRIGGER_NAME'=>			'Nombre del iniciador',
-	'S_TRIGGER_SEVERITY'=>			'Severidad del iniciador',
+	'S_TRIGGER_SEVERITY'=>			'Gravedad del iniciador',
 	'S_TRIGGER_VALUE'=>			'Valor del iniciador',
 	'S_TIME_PERIOD'=>			'Perodo de tiempo',
 	'S_TRIGGER_DESCRIPTION'=>		'Descripcin del iniciador',
@@ -231,30 +248,45 @@
 	'S_SCOPE'=>				'Alcance',
 	'S_SEND_MESSAGE_TO'=>			'Enviar mensaje a',
 	'S_RUN_REMOTE_COMMANDS'=>		'Ejecutar comandos remotos',
-	'S_WHEN_TRIGGER'=>			'Cuando el iniciador',
+	'S_WHEN_TRIGGER'=>			'Cuando el iniciador:',
 	'S_DELAY'=>				'Demora',
 	'S_SUBJECT'=>				'Ttulo',
-	'S_ON'=>				'ON',
-	'S_OFF'=>				'OFF',
+	'S_ON'=>				'ACTIVO',
+	'S_OFF'=>				'INACTIVO',
 	'S_NO_ACTIONS_DEFINED'=>		'No se han definido acciones',
-	'S_SINGLE_USER'=>			'Solo a un usuario',
-	'S_USER_GROUP'=>			'Grupo de usuarios',
+	'S_SINGLE_USER'=>			'Un usuario',
+	'S_USER_GROUP'=>			'Un grupo de usuarios',
 	'S_GROUP'=>				'Grupo',
 	'S_USER'=>				'Usuario',
-	'S_ON_OR_OFF'=>				'ON u OFF',
+	'S_ON_OR_OFF'=>				'Activo o Inactivo',
 	'S_DELAY_BETWEEN_MESSAGES_IN_SEC'=>	'Demora entre mensajes (en seg)',
-	'S_DELAY_BETWEEN_EXECUTIONS_IN_SEC'=>			'Demora entre ejecuciones (en seg)',
+	'S_DELAY_BETWEEN_EXECUTIONS_IN_SEC'=>	'Demora entre ejecuciones (en seg)',
 	'S_MESSAGE'=>				'Mensaje',
-	'S_THIS_TRIGGER_ONLY'=>			'Slo este iniciador',
+	'S_THIS_TRIGGER_ONLY'=>			'Slo para este iniciador',
 	'S_ALL_TRIGGERS_OF_THIS_HOST'=>		'Todos los iniciadores de este equipo',
 	'S_ALL_TRIGGERS'=>			'Todos los iniciadores',
-	'S_USE_IF_TRIGGER_SEVERITY'=>		'Utilizar si la severidad del iniciador es igual o mayor que',
-	'S_NOT_CLASSIFIED'=>			'Sin clasificar',
-	'S_INFORMATION'=>			'Informacin',
-	'S_WARNING'=>				'Advertencia',
-	'S_AVERAGE'=>				'Medio',
-	'S_HIGH'=>				'Alto',
-	'S_DISASTER'=>				'Crtico',
+	'S_USE_IF_TRIGGER_SEVERITY'=>		'Utilizar si la gravedad del iniciador es igual o mayor que',
+	'S_NOT_CLASSIFIED'=>			'No clasificada',
+	'S_INFORMATION'=>			'Informativa',
+	'S_WARNING'=>				'Baja',
+	'S_AVERAGE'=>				'Media',
+	'S_HIGH'=>				'Alta',
+	'S_DISASTER'=>				'Crtica',
+	'S_AND_OR_BIG'=>			'Y / O',
+	'S_AND_BIG'=>				'Y',
+	'S_AND'=>				'y',
+	'S_OR_BIG'=>				'O',
+	'S_OR'=>				'o',
+	'S_TYPE_OF_CALCULATION'=>		'Tipo de clculo',
+	'S_CREATE_ACTION'=>			'Crear accin',
+	'S_ENABLE_SELECTED_ACTIONS_Q'=>		'Activar acciones seleccionadas?',
+	'S_DISABLE_SELECTED_ACTIONS_Q'=>	'Desactivar acciones seleccionadas?',
+	'S_DELETE_SELECTED_ACTIONS_Q'=>		'Eliminar acciones seleccionadas?',
+	'S_DELETE_SELECTED_ACTION_Q'=>		'Eliminar accin seleccionada?',
+	'S_LIKE_SMALL'=>			'igual que',
+	'S_NOT_LIKE_SMALL'=>			'distinto de',
+	'S_IN_SMALL'=>				'contenido en',
+	'S_NOT_IN_SMALL'=>			'no contenido en',
 
 //	alarms.php
 	'S_ALARMS'=>				'Alarmas',
@@ -262,14 +294,14 @@
 	'S_ALARMS_BIG'=>			'ALARMAS',
 	'S_SHOW_ONLY_LAST_100'=>		'Mostrar nicamente las ltimas 100',
 	'S_SHOW_ALL'=>				'Mostrar todo',
-	'S_TIME'=>				'Tiempo',
+	'S_TIME'=>				'Fecha y hora',
 	'S_STATUS'=>				'Estado',
 	'S_DURATION'=>				'Duracin',
 	'S_SUM'=>				'Suma',
-	'S_TRUE_BIG'=>				'VERDADERO',
-	'S_FALSE_BIG'=>				'FALSO',
-	'S_DISABLED_BIG'=>			'DESACTIVADA',
-	'S_UNKNOWN_BIG'=>			'DESCONOCIDA',
+	'S_TRUE_BIG'=>				'ACTIVO',
+	'S_FALSE_BIG'=>				'INACTIVO',
+	'S_DISABLED_BIG'=>			'DESACTIVADO',
+	'S_UNKNOWN_BIG'=>			'DESCONOCIDO',
 
 //	actions.php
 	'S_HISTORY_OF_ACTIONS_BIG'=>		'HISTRICO DE ACCIONES',
@@ -325,19 +357,19 @@
 	'S_YELLOW'=>				'Amarillo',
 
 //	config.php
-	'S_CANNNOT_UPDATE_VALUE_MAP'=>		'No es posible actualizar valor en el mapa',
-	'S_VALUE_MAP_ADDED'=>			'Valor del mapa aadido',
-	'S_CANNNOT_ADD_VALUE_MAP'=>		'No es posible aadir valor al mapa',
-	'S_VALUE_MAP_DELETED'=>			'Valor del mapa eliminado',
-	'S_CANNNOT_DELETE_VALUE_MAP'=>		'No es posible eliminar valor del mapa',
-	'S_VALUE_MAP_UPDATED'=>			'Valor del mapa actualizado',
-	'S_VALUE_MAPPING_BIG'=>			'AGREGANDO VALOR AL MAPA',
-	'S_VALUE_MAPPING'=>			'Agregando valor al mapa',
-	'S_VALUE_MAP'=>				'Valor del mapa',
-	'S_MAPPING'=>				'Creando mapa',
-	'S_NEW_MAPPING'=>			'Creando nuevo mapa',
-	'S_NO_MAPPING_DEFINED'=>		'No se han definido mapas',
-	'S_CREATE_VALUE_MAP'=>			'Creando valor para el mapa',
+	'S_CANNNOT_UPDATE_VALUE_MAP'=>		'No es posible actualizar la asignacin',
+	'S_VALUE_MAP_ADDED'=>			'Asignacin aadida',
+	'S_CANNNOT_ADD_VALUE_MAP'=>		'No es posible aadir la asignacin',
+	'S_VALUE_MAP_DELETED'=>			'Asignacin eliminada',
+	'S_CANNNOT_DELETE_VALUE_MAP'=>		'No es posible eliminar la asignacin',
+	'S_VALUE_MAP_UPDATED'=>			'Asignacin actualizada',
+	'S_VALUE_MAPPING_BIG'=>			'ASIGNACIN DE VALORES',
+	'S_VALUE_MAPPING'=>			'Asignacin de valores',
+	'S_VALUE_MAP'=>				'Valor => Cadena asignada',
+	'S_MAPPING'=>				'Creando asginacin',
+	'S_NEW_MAPPING'=>			'Creando nueva asignacin',
+	'S_NO_MAPPING_DEFINED'=>		'No se han definido asignaciones',
+	'S_CREATE_VALUE_MAP'=>			'Asignar nuevo valor',
 	'S_CONFIGURATION_OF_ZABBIX'=>		'Configuracin de ZABBIX',
 	'S_CONFIGURATION_OF_ZABBIX_BIG'=>	'CONFIGURACIN DE ZABBIX',
 	'S_CONFIGURATION_UPDATED'=>		'Configuracin actualizada',
@@ -358,8 +390,8 @@
 	'S_SMTP_EMAIL'=>			'SMTP email',
 	'S_SCRIPT_NAME'=>			'Nombre del script',
 	'S_DELETE_SELECTED_MEDIA'=>		'Eliminar el tipo de medio seleccionado?',
-	'S_DELETE_SELECTED_IMAGE'=>		'Eliminar la imagen seleccionada?',
-	'S_HOUSEKEEPER'=>			'Administrador',
+	'S_DELETE_SELECTED_IMAGE'=>		'Eliminar la imgen seleccionada?',
+	'S_HOUSEKEEPER'=>			'Caducidad para acciones y eventos',
 	'S_MEDIA_TYPES'=>			'Tipos de medios',
 	'S_ESCALATION_RULES'=>			'Reglas de escalado',
 	'S_ESCALATION'=>			'Escalado',
@@ -401,13 +433,13 @@
 	'S_UPDATE_SELECTED_IMAGE'=>		'Actualizar la imgen seleccionada?',
 	'S_PRIORITY'=>				'Prioridad',
 	'S_PATTERN'=>				'Modelo',
-	'S_OTHER'=>				'Otros',
-	'S_OTHER_PARAMETERS'=>			'Otros parmetros',
-	'S_REFRESH_UNSUPPORTED_ITEMS'=>		'Refrescar parmetros monitorizados no soportados en (segudos)',
-	'S_CREATE_MEDIA_TYPE'=>			'Crear Tipos de Medio',
+	'S_OTHER'=>				'Otras configuraciones',
+	'S_OTHER_PARAMETERS'=>			'Otras configuraciones',
+	'S_REFRESH_UNSUPPORTED_ITEMS'=>		'Tiempo de refresco para monitores no soportados en (segudos)',
+	'S_CREATE_MEDIA_TYPE'=>			'Crear Tipo de Medio',
 	'S_CREATE_IMAGE'=>			'Crear Imgen',
 	'S_CREATE_RULE'=>			'Crear Regla',
-	'S_WORKING_TIME'=>			'Tiempo trabajando',
+	'S_WORKING_TIME'=>			'Jornada laboral',
 	'S_USER_GROUP_FOR_DATABASE_DOWN_MESSAGE'=>'Grupo de usuarios para mensajes de base de datos cada',
 	'S_INCORRECT_GROUP'=>			'Grupo incorrecto',
 	'S_NOTHING_TO_DO'=>			'Nada que hacer',
@@ -429,19 +461,22 @@
 	'S_MINUS_OTHER_MINUS'=>			'- otros -',
 	'S_DESCRIPTION_LARGE'=>			'DESCRIPCIN',
 	'S_DESCRIPTION_SMALL'=>			'Descripcin',
-	'S_GRAPH'=>				'Grfico',
+	'S_GRAPH'=>				'Grficos',
 	'S_TREND'=>				'Tendencia',
 	'S_COMPARE'=>				'Comparar',
 
 //	Footer
+	'S_ZABBIX_VER'=>			'ZABBIX 1.4.2',
+	'S_COPYRIGHT_BY'=>			'Copyright 2001-2007 por ',
 	'S_CONNECTED_AS'=>			'Conectado como',
+	'S_SIA_ZABBIX'=>			'SIA Zabbix',
 
 //	graph.php
 	'S_CONFIGURATION_OF_GRAPH'=>		'Configuracin del grfico',
 	'S_CONFIGURATION_OF_GRAPH_BIG'=>	'CONFIGURACIN DEL GRFICO',
-	'S_ITEM_ADDED'=>			'Elemento aadido',
-	'S_ITEM_UPDATED'=>			'Elemento actualizado',
-	'S_ITEMS_UPDATED'=>			'Elementos actualizados',
+	'S_ITEM_ADDED'=>			'Monitor aadido',
+	'S_ITEM_UPDATED'=>			'Monitor actualizado',
+	'S_ITEMS_UPDATED'=>			'Monitores actualizados',
 	'S_SORT_ORDER_UPDATED'=>		'rden de clasificacin actualizada',
 	'S_CANNOT_UPDATE_SORT_ORDER'=>		'No es posible actualizar el rden de clasificacin',
 	'S_DISPLAYED_PARAMETERS_BIG'=>		'PARMETROS MOSTRADOS',
@@ -464,7 +499,7 @@
 	'S_STACKED'=>				'Apilado',
 	'S_NORMAL'=>				'Normal',
 	'S_AGGREGATED'=>			'Aadido',
-	'S_AGGREGATED_PERIODS_COUNT'=>			'Contadores de perodos aadidos',
+	'S_AGGREGATED_PERIODS_COUNT'=>		'Contadores de perodos aadidos',
 
 //	graphs.php
 	'S_CONFIGURATION_OF_GRAPHS'=>		'Configuracin de los grficos',
@@ -477,6 +512,7 @@
 	'S_CANNOT_ADD_GRAPH'=>			'No es posible aadir el grfico',
 	'S_ID'=>				'Id',
 	'S_NO_GRAPHS_DEFINED'=>			'No se han definido grficos',
+	'S_NO_GRAPH_DEFINED'=>			'No se ha definido grfico',
 	'S_DELETE_GRAPH_Q'=>			'Eliminar el grfico?',
 	'S_YAXIS_TYPE'=>			'Tipo del eje Y',
 	'S_YAXIS_MIN_VALUE'=>			'Valor MIN del eje Y',
@@ -501,6 +537,7 @@
 	'S_TIMESTAMP'=>				'Feha y hora',
 	'S_LOCAL'=>				'Local',
 	'S_SOURCE'=>				'Orgen',
+	'S_SHOW_UNKNOWN'=>			'Mostrar desconocidos',
 	'S_SHOW_SELECTED'=>			'Mostrar seleccionados',
 	'S_HIDE_SELECTED'=>			'Ocultar seleccionados',
 	'S_MARK_SELECTED'=>			'Marcar seleccionados',
@@ -516,8 +553,8 @@
 	'S_CREATE_APPLICATION'=>		'Crear aplicacin',	
 	'S_DELETE_SELECTED_APPLICATIONS_Q'=>	'Eliminar aplicaciones seleccionadas?',
 	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>'Desactivar los elementos de las aplicaciones seleccionadas?',
-	'S_ACTIVATE_ITEMS'=>			'Activar Elementos',
-	'S_DISABLE_ITEMS'=>			'Desactivar Elementos',
+	'S_ACTIVATE_ITEMS'=>			'Activar',
+	'S_DISABLE_ITEMS'=>			'Desactivar',
 	'S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>'Activar los elementos de las aplicaciones seleccionadas?',
 	'S_APPLICATION_UPDATED'=>		'Aplicacin actualizada',
 	'S_CANNOT_UPDATE_APPLICATION'=>		'No es posible actualizar la aplicacin',
@@ -527,13 +564,13 @@
 	'S_CANNOT_DELETE_APPLICATION'=>		'No es posible eliminar la aplicacin',
 	'S_NO_APPLICATIONS_DEFINED'=>		'No se han definido aplicaciones',
 	'S_HOSTS'=>				'Equipos',
-	'S_ITEMS'=>				'Elementos',
-	'S_ITEMS_BIG'=>				'ELEMENTOS',
+	'S_ITEMS'=>				'Monitores',
+	'S_ITEMS_BIG'=>				'MONITORES',
 	'S_TRIGGERS'=>				'Iniciadores',
 	'S_GRAPHS'=>				'Grficos',
 	'S_HOST_ADDED'=>			'Equipo aadido',
 	'S_CANNOT_ADD_HOST'=>			'No es posible aadir el equipo',
-	'S_ITEMS_ADDED'=>			'Elementos aadidos',
+	'S_ITEMS_ADDED'=>			'Monitores aadidos',
 	'S_CANNOT_ADD_ITEMS'=>			'No es posible aadir elementos',
 	'S_HOST_UPDATED'=>			'Equipo actualizado',
 	'S_CANNOT_UPDATE_HOST'=>		'No es posible actualizar el equipo',
@@ -547,7 +584,7 @@
 	'S_CANNOT_UPDATE_TEMPLATE_LINKAGE'=>	'No es posible actualizar la plantilla vinculada',
 	'S_TEMPLATE_LINKAGE_DELETED'=>		'Plantilla vinculada eliminada',
 	'S_CANNOT_DELETE_TEMPLATE_LINKAGE'=>	'No es posible eliminar la plantilla vinculada',
-	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>'CONFIGURACIN DE EQUIPOS, GRUPOS Y PLANTILLAS',
+	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>'CONFIGURACIN DE EQUIPOS, PLANTILLAS, GRUPOS Y APLICACIONES',
 	'S_HOST_GROUPS_BIG'=>			'GRUPOS DE EQUIPOS',
 	'S_START'=>				'Iniciar',
 	'S_STOP'=>				'Detener',
@@ -556,7 +593,7 @@
 	'S_NO_HOSTS_DEFINED'=>			'No se han definido equipos',
 	'S_NO_TEMPLATES_DEFINED'=>		'No se han definido plantillas',
 	'S_HOSTS_BIG'=>				'EQUIPOS',
-	'S_HOST'=>				'Equipo',
+	'S_HOST'=>				'Equipo/Plantilla',
 	'S_HOST_BIG'=>				'EQUIPO',
 	'S_CONNECT_TO'=>			'Conectado a',
 	'S_DNS'=>				'DNS',
@@ -564,7 +601,7 @@
 	'S_PORT'=>				'Puerto',
 	'S_MONITORED'=>				'Monitorizado',
 	'S_NOT_MONITORED'=>			'No monitorizado',
-	'S_UNREACHABLE'=>			'Inalcanzable',
+	'S_UNREACHABLE'=>			'Inaccesible',
 	'S_TEMPLATE'=>				'Plantilla',
 	'S_TEMPLATE_SMALL'=>			'plantilla',
 	'S_DELETED'=>				'Eliminado',
@@ -627,31 +664,32 @@
 	'S_CLEANED_SMALL'=>			'eliminado',
 
 //	items.php
-	'S_NO_ITEMS_DEFINED'=>			'No se han definido elementos',
+	'S_NO_ITEMS_DEFINED'=>			'No se han definido monitores',
+	'S_NO_ITEM_DEFINED'=>			'No se ha definido monitor',
 	'S_HISTORY_CLEANED'=>			'Histrico eliminado',
-	'S_CLEAN_HISTORY_SELECTED_ITEMS'=>	'Eliminar histrico de los elementos seleccionados',
+	'S_CLEAN_HISTORY_SELECTED_ITEMS'=>	'Eliminar histrico del monitor seleccionado',
 	'S_CLEAN_HISTORY'=>			'Eliminar histrico',
 	'S_CANNOT_CLEAN_HISTORY'=>		'No es posible eliminar el histrico',
-	'S_CONFIGURATION_OF_ITEMS'=>		'Configuracin de elementos',
-	'S_CONFIGURATION_OF_ITEMS_BIG'=>	'CONFIGURACIN DE ELEMENTOS',
-	'S_CANNOT_UPDATE_ITEM'=>		'No es posible actualizar el elemento',
+	'S_CONFIGURATION_OF_ITEMS'=>		'Configuracin de monitores',
+	'S_CONFIGURATION_OF_ITEMS_BIG'=>	'CONFIGURACIN DE MONITORES',
+	'S_CANNOT_UPDATE_ITEM'=>		'No es posible actualizar el monitor',
 	'S_STATUS_UPDATED'=>			'Estado actualizado',
 	'S_CANNOT_UPDATE_STATUS'=>		'No es posible actualizar el estado',
-	'S_CANNOT_ADD_ITEM'=>			'No es posible aadir el elemento',
-	'S_ITEM_DELETED'=>			'Elemento eliminado',
-	'S_CANNOT_DELETE_ITEM'=>		'No es posible eliminar el elemento',
-	'S_ITEMS_DELETED'=>			'Elementos eliminados',
-	'S_CANNOT_DELETE_ITEMS'=>		'No es posible eliminar los elementos',
-	'S_ITEMS_ACTIVATED'=>			'Elementos activados',
-	'S_CANNOT_ACTIVATE_ITEMS'=>		'No es posible activar los elementos',
-	'S_ITEMS_DISABLED'=>			'Elementos desactivados',
-	'S_CANNOT_DISABLE_ITEMS'=>		'No es posible desactivar los elementos',
+	'S_CANNOT_ADD_ITEM'=>			'No es posible aadir el monitor',
+	'S_ITEM_DELETED'=>			'Monitor eliminado',
+	'S_CANNOT_DELETE_ITEM'=>		'No es posible eliminar el monitor',
+	'S_ITEMS_DELETED'=>			'Monitores eliminados',
+	'S_CANNOT_DELETE_ITEMS'=>		'No es posible eliminar los monitores',
+	'S_ITEMS_ACTIVATED'=>			'Monitores activados',
+	'S_CANNOT_ACTIVATE_ITEMS'=>		'No es posible activar los monitores',
+	'S_ITEMS_DISABLED'=>			'Monitores desactivados',
+	'S_CANNOT_DISABLE_ITEMS'=>		'No es posible desactivar los monitores',
 	'S_SERVERNAME'=>			'Nombre del Servidor',
-	'S_KEY'=>				'Clave',
-	'S_DESCRIPTION'=>			'Descripcin',
-	'S_UPDATE_INTERVAL'=>			'Actualizar intervalo',
-	'S_HISTORY'=>				'Histrico',
-	'S_TRENDS'=>				'Tendencias',
+	'S_KEY'=>				'Monitor',
+	'S_DESCRIPTION'=>			'Nombre descriptivo',
+	'S_UPDATE_INTERVAL'=>			'Refrescar cada (s)',
+	'S_HISTORY'=>				'Histrico (das)',
+	'S_TRENDS'=>				'Tendencias (das)',
 	'S_SHORT_NAME'=>			'Nombre corto',
 	'S_ZABBIX_AGENT'=>			'Agente ZABBIX',
 	'S_ZABBIX_AGENT_ACTIVE'=>		'Agente ZABBIX (activo)',
@@ -665,19 +703,19 @@
 	'S_EXTERNAL_CHECK'=>			'Comprobacin externa',
 	'S_WEB_MONITORING'=>			'Monitorizacin Web',
 	'S_ZABBIX_UNKNOWN'=>			'Desconocido',
-	'S_ACTIVE'=>				'Activo',
+	'S_ACTIVE'=>				'Activado',
 	'S_NOT_ACTIVE'=>			'No activo',
 	'S_NOT_SUPPORTED'=>			'No soportado',
-	'S_ACTIVATE_SELECTED_ITEMS_Q'=>		'Activar los elementos seleccionados?',
-	'S_DISABLE_SELECTED_ITEMS_Q'=>		'Desctivar los elementos seleccionados?',
-	'S_DELETE_SELECTED_ITEMS_Q'=>		'Eliminar los elementos seleccionados?',
+	'S_ACTIVATE_SELECTED_ITEMS_Q'=>		'Activar los monitores seleccionados?',
+	'S_DISABLE_SELECTED_ITEMS_Q'=>		'Desactivar los monitores seleccionados?',
+	'S_DELETE_SELECTED_ITEMS_Q'=>		'Eliminar los monitores seleccionados?',
 	'S_EMAIL'=>				'Email',
 	'S_JABBER'=>				'Jabber',
 	'S_JABBER_IDENTIFIER'=>			'Identificador Jabber',
 	'S_SMS'=>				'SMS',
 	'S_SCRIPT'=>				'Script',
 	'S_GSM_MODEM'=>				'Modem GSM',
-	'S_UNITS'=>				'Unidades',
+	'S_UNITS'=>				'Unidad',
 	'S_MULTIPLIER'=>			'Multiplicador',
 	'S_UPDATE_INTERVAL_IN_SEC'=>		'Intervalo de actualizacin (en segundos)',
 	'S_KEEP_HISTORY_IN_DAYS'=>		'Conservar el histrico durante (en das)',
@@ -690,10 +728,10 @@
 	'S_CHARACTER'=>				'Carcter',
 	'S_LOG'=>				'Registro',
 	'S_TEXT'=>				'Texto',
-	'S_AS_IS'=>				'Como es',
+	'S_AS_IS'=>				'Como sea',
 	'S_DELTA_SPEED_PER_SECOND'=>		'Delta (velocidad por segundo)',
 	'S_DELTA_SIMPLE_CHANGE'=>		'Delta (cambio sencillo)',
-	'S_ITEM'=>				'Elemento',
+	'S_ITEM'=>				'Monitor',
 	'S_SNMP_COMMUNITY'=>			'Comunidad SNMP',
 	'S_SNMP_OID'=>				'SNMP OID',
 	'S_SNMP_PORT'=>				'Puerto SNMP',
@@ -707,26 +745,26 @@
 	'S_USE_MULTIPLIER'=>			'Utilizar multiplicador',
 	'S_SELECT_HOST_DOT_DOT_DOT'=>		'Seleccionar equipo...',
 	'S_LOG_TIME_FORMAT'=>			'Formato de fecha para el registro',
-	'S_CREATE_ITEM'=>			'Crear elemento',
-	'S_ADD_ITEM'=>				'Aadir elemento',
+	'S_CREATE_ITEM'=>			'Crear monitor',
+	'S_ADD_ITEM'=>				'Aadir monitor',
 	'S_X_ELEMENTS_COPY_TO_DOT_DOT_DOT'=>	'Elementos copiados a...',
 	'S_MODE'=>				'Modo',
 	'S_TARGET'=>				'Destino',
 	'S_TARGET_TYPE'=>			'Tipo de destino',
-	'S_SKIP_EXISTING_ITEMS'=>		'Saltar elementos existentes',
-	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>	'Actualizar elementos no vinculados',
+	'S_SKIP_EXISTING_ITEMS'=>		'Saltar monitores existentes',
+	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>	'Actualizar monitores no vinculados',
 	'S_COPY'=>				'Copiar',
-	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>	'Mostrar elementos cuya descripcin sea',
-	'S_SHOW_DISABLED_ITEMS'=>		'Mostrar elementos desactivados',
-	'S_HIDE_DISABLED_ITEMS'=>		'Ocultar elementos desactivados',
-	'S_HISTORY_CLEANING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q' => 'Eliminar el histrico puede llevarse tiempo. Desea continuar?',
-	'S_ITEM_SELECTION'=>			'Seleccin del elemento',
-	'S_SELECTION_MODE'=>			'Modo de seleccin',
+	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>	'Mostrar monitores cuya descripcin sea',
+	'S_SHOW_DISABLED_ITEMS'=>		'Mostrar monitores desactivados',
+	'S_HIDE_DISABLED_ITEMS'=>		'Ocultar monitores desactivados',
+	'S_HISTORY_CLEANING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q' => 'Eliminar el histrico puede llevarse tiempo. Continuar?',
+	'S_ITEM_SELECTION'=>			'Bsqueda avanzada de monitores',
+	'S_SELECTION_MODE'=>			'Cambiar el modo de bsqueda a',
 	'S_ADVANCED'=>				'Avanzado',
 	'S_SIMPLE'=>				'Sencillo',
-	'S_MASS_UPDATE'=>			'Actualizacin masiva',
-	'S_SEARCH'=>				'Bsqueda',
-	'S_EXTERNAL_FILTER'=>			'Filtro externo',
+	'S_MASS_UPDATE'=>			'Actualizar masivamente',
+	'S_SEARCH'=>				'Buscar',
+	'S_EXTERNAL_FILTER'=>			'Bsqueda avanzada',
 	'S_ORIGINAL'=>				'Original',
 	'S_NEW_FLEXIBLE_INTERVAL'=>		'Nuevo intervalo flexible',
 	'S_FLEXIBLE_INTERVALS'=>		'Intervalos flexibles (sec)',
@@ -746,12 +784,12 @@
 	'S_LABEL'=>				'Etiqueta',
 	'S_X'=>					'X',
 	'S_Y'=>					'Y',
-	'S_ICON_ON'=>				'Icono (on)',
-	'S_ICON_OFF'=>				'Icono (off)',
+	'S_ICON_ON'=>				'Icono (correcto)',
+	'S_ICON_OFF'=>				'Icono (problema)',
 	'S_ICON_UNKNOWN'=>			'Icono (desconocido)',
-	'S_ELEMENT_1'=>				'Elemento 1',
-	'S_ELEMENT_2'=>				'Elemento 2',
-	'S_LINK_STATUS_INDICATOR'=>		'Vincular el indicador de estado',
+	'S_ELEMENT_1'=>				'Primer elemento',
+	'S_ELEMENT_2'=>				'Segundo elemento',
+	'S_LINK_STATUS_INDICATOR'=>		'Vincular con el estado del iniciador',
 	'S_CONFIGURATION_OF_NETWORK_MAPS'=>	'Configuracin de los mapas de la red',
 
 //	sysmaps.php
@@ -760,8 +798,8 @@
 	'S_CONFIGURATION_OF_NETWORK_MAPS'=>	'CONFIGURACIN DE LOS MAPAS DE LA RED',
 	'S_CREATE_MAP'=>			'Crear Mapa',
 	'S_ICON_LABEL_LOCATION'=>		'Localizacin de la etiqueta del icono',
-	'S_BOTTOM'=>				'Final',
-	'S_TOP'=>				'Principio',
+	'S_BOTTOM'=>				'Debajo',
+	'S_TOP'=>				'Encima',
 
 //	map.php
 	'S_OK_BIG'=>				'OK',
@@ -777,7 +815,7 @@
 	'S_BACKGROUND_IMAGE'=>			'Imagen de fondo',
 	'S_ICON_LABEL_TYPE'=>			'Tipo de etiqueta para el icono',
 	'S_LABEL'=>				'Etiqueta',
-	'S_LABEL_LOCATION'=>			'Localizacin de la etiqueta',
+	'S_LABEL_LOCATION'=>			'Posicin de la etiqueta',
 	'S_ELEMENT_NAME'=>			'Nombre del elemento',
 	'S_STATUS_ONLY'=>			'Slo el estado',
 	'S_NOTHING'=>				'Nada',
@@ -800,7 +838,7 @@
 	'S_WHEN_ACTIVE'=>			'Cuando se active',
 	'S_NO_MEDIA_DEFINED'=>			'No se han definido medios',
 	'S_NEW_MEDIA'=>				'Nuevo medio',
-	'S_USE_IF_SEVERITY'=>			'Utilizar si la severidad',
+	'S_USE_IF_SEVERITY'=>			'Utilizar si la gravedad es',
 	'S_DELETE_SELECTED_MEDIA_Q'=>		'Eliminar el medio seleccionado?',
 	'S_CREATE_MEDIA'=>			'Crear Medio',
 	'S_SAVE'=>				'Guardar',
@@ -823,16 +861,16 @@
 	'S_MENU_CONFIG'=>			'CONFIGURACIN',
 	'S_MENU_USERS'=>			'USUARIOS',
 	'S_MENU_HOSTS'=>			'EQUIPOS',
-	'S_MENU_ITEMS'=>				'ELEMENTO',
+	'S_MENU_ITEMS'=>			'ELEMENTO',
 	'S_MENU_AUDIT'=>			'AUDITORA',
-	'S_SWITCH_NODE'=>			'Switch node',
+	'S_SWITCH_NODE'=>			'Nodo switch',
 
 //	overview.php
 	'S_SELECT_GROUP_DOT_DOT_DOT'=>		'Seleccionar grupo ...',
 	'S_OVERVIEW'=>				'Vistazo general',
 	'S_OVERVIEW_BIG'=>			'VISTAZO GENERAL',
 	'S_EXCL'=>				'!',
-	'S_DATA'=>				'Datos',
+	'S_DATA'=>				'Monitores',
 	'S_SHOW_GRAPH_OF_ITEM'=>		'Mostrar grficos del elemento',
 	'S_SHOW_VALUES_OF_ITEM'=>		'Mostrar valores del elemento',
 	'S_VALUES'=>				'Valores',
@@ -841,7 +879,7 @@
 
 //	queue.php
 	'S_QUEUE_BIG'=>				'COLA',
-	'S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG'=>	'COLA DE ELEMENTOS PARA SER ACTUALIZADOS',
+	'S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG'=>	'COLA DE MONITORES PARA SER ACTUALIZADOS',
 	'S_NEXT_CHECK'=>			'Prxima comprobacin',
 	'S_THE_QUEUE_IS_EMPTY'=>		'La cola est vaca',
 	'S_TOTAL'=>				'Total',
@@ -856,21 +894,21 @@
 //	report1.php
 	'S_STATUS_OF_ZABBIX'=>			'Estado de ZABBIX',
 	'S_STATUS_OF_ZABBIX_BIG'=>		'ESTADO DE ZABBIX',
-	'S_VALUE'=>				'Valor',
-	'S_ZABBIX_SERVER_IS_RUNNING'=>		'El servidor de ZABBIX est ejecutndose',
+	'S_VALUE'=>				'Estado',
+	'S_ZABBIX_SERVER_IS_RUNNING'=>		'Servidor ZABBIX operativo',
 	'S_NUMBER_OF_VALUES_STORED'=>		'Nmero de valores almacenados',
 	'S_VALUES_STORED'=>			'Valores almacenados',
 	'S_NUMBER_OF_TRENDS_STORED'=>		'Nmero de tendencias almacenadas',
 	'S_TRENDS_STORED'=>			'Tendencias almacenadas',
 	'S_NUMBER_OF_EVENTS'=>			'Nmero de eventos',
 	'S_NUMBER_OF_ALERTS'=>			'Nmero de alertas',
-	'S_NUMBER_OF_TRIGGERS'=>		'Nmero de iniciadores (activo/inactivo)[verdadero/desconocido/falso]',
-	'S_NUMBER_OF_TRIGGERS_SHORT'=>		'Iniciadores (a/i)[v/d/f]',
-	'S_NUMBER_OF_ITEMS'=>			'Nmero de elementos (monitorizado/inactivo/no soportado)[trapper]',
-	'S_NUMBER_OF_ITEMS_SHORT'=>		'Elementos (m/d/n)[t]',
+	'S_NUMBER_OF_TRIGGERS'=>		'Nmero de iniciadores (activos/inactivos)[problemas/desconocidos/correctos]',
+	'S_NUMBER_OF_TRIGGERS_SHORT'=>		'Iniciadores (a/i)[p/d/c]',
+	'S_NUMBER_OF_ITEMS'=>			'Nmero de monitores (monitorizados/inactivos/no soportados)[trapper]',
+	'S_NUMBER_OF_ITEMS_SHORT'=>		'Monitores(m/d/n)[t]',
 	'S_NUMBER_OF_USERS'=>			'Nmero de usuarios(en lnea)',
 	'S_NUMBER_OF_USERS_SHORT'=>		'Usuarios (en lnea)',
-	'S_NUMBER_OF_HOSTS'=>			'Nmero de equipos (monitorizado/no monitorizado/plantilla/eliminado)',
+	'S_NUMBER_OF_HOSTS'=>			'Nmero de equipos/plantillas (monitorizados/no monitorizados/plantillas/eliminados)',
 	'S_NUMBER_OF_HOSTS_SHORT'=>		'Equipos (m/n/p/e)',
 	'S_YES'=>				'Si',
 	'S_NO'=>				'No',
@@ -908,8 +946,8 @@
 	'S_IT_NOTIFICATIONS'=>			'Informe de notificaciones',
 
 //	report5.php
-	'S_TRIGGERS_TOP_100'=>			'Los 100 iniciadores ms ocupados',
-	'S_TRIGGERS_TOP_100_BIG'=>		'LOS 100 INICIADORES MS OCUPADOS',
+	'S_TRIGGERS_TOP_100'=>			'Los 100 iniciadores ms voltiles',
+	'S_TRIGGERS_TOP_100_BIG'=>		'LOS 100 INICIADORES MS VOLTILES',
 	'S_NUMBER_OF_STATUS_CHANGES'=>		'Nmero de cambios de estado',
 	'S_WEEK'=>				'Semana',
 	'S_LAST'=>				'ltimo',
@@ -979,9 +1017,9 @@
 	'S_CENTER'=>				'Centro',
 	'S_RIGHT'=>				'Derecha',
 	'S_VERTICAL_ALIGN'=>			'Alineacin vertical',
-	'S_TOP'=>				'Principio',
+	'S_TOP'=>				'Encima',
 	'S_MIDDLE'=>				'Medio',
-	'S_BOTTOM'=>				'Final',
+	'S_BOTTOM'=>				'Debajo',
 
 //	screens.php
 	'S_CUSTOM_SCREENS'=>			'Personalizar pantallas',
@@ -1003,6 +1041,7 @@
 	'S_IT_SERVICE'=>			'Servicio TI',
 	'S_IT_SERVICES'=>			'Servicios TI',
 	'S_SERVICE_UPDATED'=>			'Servicio actualizado',
+	'S_NO_IT_SERVICE_DEFINED'=>		'No IT service defined',
 	'S_CANNOT_UPDATE_SERVICE'=>		'No es posible actualizar el servicio',
 	'S_SERVICE_ADDED'=>			'Servicio aadido',
 	'S_CANNOT_ADD_SERVICE'=>		'No es posible aadir el servicio',
@@ -1017,8 +1056,8 @@
 	'S_NONE'=>				'Ninguno',
 	'S_MAX_OF_CHILDS'=>			'MAX nmero de hijos',
 	'S_MIN_OF_CHILDS'=>			'MIN nmero de hijos',
-	'S_SERVICE_1'=>				'Servicio 1',
-	'S_SERVICE_2'=>				'Servicio 2',
+	'S_SERVICE_1'=>				'Primer servicio',
+	'S_SERVICE_2'=>				'Segundo servicio',
 	'S_SOFT_HARD_LINK'=>			'Vnculo blando/duro',
 	'S_SOFT'=>				'Blando',
 	'S_HARD'=>				'Duro',
@@ -1033,11 +1072,11 @@
 	'S_LINK_TO'=>				'Vincular a',
 	'S_SOFT_LINK_Q'=>			'Vnculo blando?',
 	'S_ADD_SERVER_DETAILS'=>		'Aadir detalles al servidor',
-	'S_TRIGGER'=>				'Iniciador',
+	'S_TRIGGER'=>				'Iniciadores',
 	'S_SERVER'=>				'Servidor',
 	'S_DELETE'=>				'Eliminar',
 	'S_CLONE'=>				'Clonar',
-	'S_DELETE_SELECTED'=>			'Eliminar seleccionado',
+	'S_DELETE_SELECTED'=>			'Eliminar',
 	'S_DELETE_SELECTED_SERVICES'=>		'Eliminar servicios seleccionados?',
 	'S_DELETE_SELECTED_LINKS'=>		'Eliminar vnculos seleccionados?',
 	'S_SERVICES_DELETED'=>			'Servicios eliminados',
@@ -1049,6 +1088,9 @@
 	'S_SERVICE_TIMES'=>			'Tiempos del servicio',
 	'S_NEW_SERVICE_TIME'=>			'Nuevo tiempo del servicio',
 	'S_NOTE'=>				'Nota',
+	'S_SOFT_LINK'=>				'Enlance blando',
+	'S_REMOVE'=>				'Eliminar',
+	'S_DEPENDS_ON'=>			'Depende de',
 	'S_SUNDAY'=>				'Domingo',
 	'S_MONDAY'=>				'Lunes',
 	'S_TUESDAY'=>				'Martes',
@@ -1063,14 +1105,15 @@
 	'S_SERVICES'=>				'Servicios',
 	'S_REASON'=>				'Causa',
 	'S_SLA_LAST_7_DAYS'=>			'SLA (ltimos 7 das)',
-	'S_PLANNED_CURRENT_SLA'=>		'SLA Previsto/SLA Actual',
+	'S_PLANNED_CURRENT_SLA'=>		'SLA Previsto / SLA Actual',
 	'S_TRIGGER_BIG'=>			'INICIADOR',
 
 //	triggers.php
 	'S_NO_TRIGGER'=>			'Sin iniciadores',
 	'S_NO_TRIGGERS_DEFINED'=>		'No se han definido iniciadores',
-	'S_CONFIGURATION_OF_TRIGGERS'=>		'Configuracin de iniciadores',
-	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>	'CONFIGURACION DE INICIADORES',
+	'S_NO_TRIGGER_DEFINED'=>		'No se ha definido iniciador',
+	'S_CONFIGURATION_OF_TRIGGERS'=>		'Configuracin del iniciador',
+	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>	'CONFIGURACIN DEL INICIADOR',
 	'S_DEPENDENCY_ADDED'=>			'Dependencia aadida',
 	'S_CANNOT_ADD_DEPENDENCY'=>		'No es posible aadir la dependencia',
 	'S_TRIGGERS_UPDATED'=>			'Iniciadores actualizados',
@@ -1080,20 +1123,20 @@
 	'S_TRIGGERS_DELETED'=>			'Iniciadores eliminados',
 	'S_CANNOT_DELETE_TRIGGERS'=>		'No es posible eliminar los iniciadores',
 	'S_TRIGGER_DELETED'=>			'Iniciador eliminado',
-	'S_CANNOT_DELETE_TRIGGER'=>		'No es posible eliminar el iniciador',
+	'S_CANNOT_DELETE_TRIGGER'=>		'No es posible eliminar los iniciadores',
 	'S_INVALID_TRIGGER_EXPRESSION'=>	'Expresin del iniciador no vlida',
 	'S_TRIGGER_ADDED'=>			'Iniciador aadido',
 	'S_CANNOT_ADD_TRIGGER'=>		'No es posible aadir el iniciador',
-	'S_SEVERITY'=>				'Severidad',
+	'S_SEVERITY'=>				'Gravedad',
 	'S_EXPRESSION'=>			'Expresin',
 	'S_DISABLED'=>				'Desactivado',
 	'S_ENABLED'=>				'Activado',
-	'S_DISABLE_SELECTED'=>			'Desactivar los seleccionados',
-	'S_ENABLE_SELECTED'=>			'Activar los seleccionados',
+	'S_DISABLE_SELECTED'=>			'Desactivar',
+	'S_ENABLE_SELECTED'=>			'Activar',
 	'S_ENABLE_SELECTED_TRIGGERS_Q'=>	'Activar los iniciadores seleccionados?',
 	'S_DISABLE_SELECTED_TRIGGERS_Q'=>	'Desactivar los iniciadores seleccionados?',
 	'S_DELETE_SELECTED_TRIGGERS_Q'=>	'Eliminar los iniciadores seleccionados?',
-	'S_CHANGE'=>				'Cambiar',
+	'S_CHANGE'=>				'Variacin con valor anterior',
 	'S_TRIGGER_UPDATED'=>			'Iniciador actualizado',
 	'S_CANNOT_UPDATE_TRIGGER'=>		'No es posible actualizar el iniciador',
 	'S_DEPENDS_ON'=>			'Depende de',
@@ -1110,7 +1153,7 @@
 	'S_HIDE_DISABLED_TRIGGERS'=>		'Ocultar iniciadores desactivados',
 
 //	tr_comments.php
-	'S_TRIGGER_COMMENTS'=>			'Comentario del iniciador',
+	'S_TRIGGER_COMMENTS'=>			'Comentarios del iniciador',
 	'S_TRIGGER_COMMENTS_BIG'=>		'COMENTARIOS DEL INICIADOR',
 	'S_COMMENT_UPDATED'=>			'Comentario actualizado',
 	'S_CANNOT_UPDATE_COMMENT'=>		'No es posible actualizar el comentario',
@@ -1119,22 +1162,23 @@
 //	tr_status.php
 	'S_STATUS_OF_TRIGGERS'=>		'Estado de los iniciadores',
 	'S_STATUS_OF_TRIGGERS_BIG'=>		'ESTADO DE LOS INICIADORES',
-	'S_SHOW_ONLY_TRUE'=>			'Mostrar slo verdaderos',
+	'S_SHOW_ONLY_TRUE'=>			'Mostrar slo con problemas',
 	'S_HIDE_ACTIONS'=>			'Ocultar las acciones',
 	'S_SHOW_ACTIONS'=>			'Mostrar las acciones',
 	'S_SHOW_ALL_TRIGGERS'=>			'Mostrar todos los iniciadores',
 	'S_HIDE_DETAILS'=>			'Ocultar detalles',
 	'S_SHOW_DETAILS'=>			'Mostrar detalles',
-	'S_SELECT'=>				'Seleccionar',
+	'S_SELECT'=>				'Seleccionar / Examinar...',
 	'S_HIDE_SELECT'=>			'Ocultar seleccionados',
 	'S_TRIGGERS_BIG'=>			'INICIADORES',
 	'S_NAME_BIG'=>				'NOMBRE',
-	'S_SEVERITY_BIG'=>			'SEVERIDAD',
+	'S_SEVERITY_BIG'=>			'GRAVEDAD',
 	'S_LAST_CHANGE_BIG'=>			'LTIMO CAMBIO',
 	'S_LAST_CHANGE'=>			'ltimo cambio',
 	'S_COMMENTS'=>				'Comentarios',
-	'S_ACKNOWLEDGED'=>			'Aceptados',
-	'S_ACK'=>				'Acep',
+	'S_ACKNOWLEDGED'=>			'Aceptada',
+	'S_ACK'=>				'Aceptar',
+	'S_NEVER'=>				'Nunca',
 
 //	users.php
 	'S_ZABBIX_USER'=>			'Usuario ZABBIX',
@@ -1162,12 +1206,12 @@
 	'S_GROUP_DELETED'=>			'Grupo eliminado',
 	'S_CANNOT_DELETE_GROUP'=>		'No es posible eliminar el grupo',
 	'S_CONFIGURATION_OF_USERS_AND_USER_GROUPS'=>'CONFIGURACION DE USUARIOS Y DE GRUPOS DE USUARIOS',
-	'S_USER_GROUPS_BIG'=>			'GRUPOS DE USUARIO',
+	'S_USER_GROUPS_BIG'=>			'GRUPOS DE USUARIOS',
 	'S_USERS_BIG'=>				'USUARIOS',
 	'S_USER_GROUPS'=>			'Grupos de usuarios',
 	'S_MEMBERS'=>				'Miembros',
 	'S_TEMPLATES'=>				'Plantillas',
-	'S_HOSTS_TEMPLATES_LINKAGE'=>		'Vnculos de Equipos/Plantillas',
+	'S_HOSTS_TEMPLATES_LINKAGE'=>		'Vnculos de Equipos / Plantillas',
 	'S_CONFIGURATION_OF_TEMPLATES_LINKAGE'=>'CONFIGURACION DE VNCULOS DE PLANTILLAS',
 	'S_LINKED_TEMPLATES_BIG'=>		'PLANTILLAS VINCULADAS',
 	'S_NO_USER_GROUPS_DEFINED'=>		'No se han definio grupos de usuarios',
@@ -1211,11 +1255,10 @@
 	'S_UNKNOWN_RESOURCE'=>			'Recurso desconocido',
 
 //	profile.php
-	'S_USER_PROFILE_BIG'=>			'PERFIL DE USUARIO',
 	'S_USER_PROFILE_BIG'=>			'PERFIL DE USUARIO',
 	'S_USER_PROFILE'=>			'Perfil de usuario',
 	'S_LANGUAGE'=>				'Idioma',
-	'S_ENGLISH_GB'=>			'Ingles (GB)',
+	'S_ENGLISH_GB'=>			'Ingls (GB)',
 	'S_FRENCH_FR'=>				'Francs (FR)',
 	'S_GERMAN_DE'=>				'Alemn(DE)',
 	'S_ITALIAN_IT'=>			'Italiano (IT)',
@@ -1230,19 +1273,19 @@
 //	index.php
 	'S_ZABBIX_BIG'=>			'ZABBIX',
 
-
 //	hostprofiles.php
 	'S_HOST_PROFILES'=>			'Perfiles del equipo',
 	'S_HOST_PROFILES_BIG'=>			'PERFILES DEL EQUIPO',
 
 //	popup.php
 	'S_EMPTY'=>				'Sin contenido',
-	'S_STANDARD_ITEMS_BIG'=>		'INICIADORES CONVENCIONALES',
-	'S_NO_ITEMS'=>				'Sin iniciadores',
+	'S_STANDARD_ITEMS_BIG'=>		'ALERTAS CONVENCIONALES',
+	'S_NO_ITEMS'=>				'Sin alertas',
 
 //	Menu
 	'S_HELP'=>				'Ayuda',
 	'S_PROFILE'=>				'Perfiles',
+	'S_GET_SUPPORT'=>			'Obtener soporte',
 	'S_MONITORING'=>			'Monitorizacin',
 	'S_INVENTORY'=>				'Inventario',
 	'S_QUEUE'=>				'Cola',
@@ -1250,13 +1293,14 @@
 	'S_EVENTS_BIG'=>			'EVENTOS',
 	'S_MAPS'=>				'Mapas',
 	'S_REPORTS'=>				'Informes',
-	'S_GENERAL'=>				'General',
+	'S_GENERAL'=>				'Zabbix',
 	'S_AUDIT'=>				'Auditora',
 	'S_LOGIN'=>				'Iniciar sesin',
-	'S_LOGOUT'=>				'Terminar sesin',
+	'S_LOGOUT'=>				'Finalizar sesin',
 	'S_LATEST_DATA'=>			'ltima fecha',
 
 //	Errors
-	'S_INCORRECT_DESCRIPTION'=>		'Descripcin incorrecta'
+	'S_INCORRECT_DESCRIPTION'=>		'Descripcin incorrecta',
+	'S_CANT_FORMAT_TREE'=>			'No es posible dar formato al rbol'
 	);
 ?>
