@@ -57,10 +57,10 @@
         {
 		switch($drawtype)
 		{
-			case MAP_LINK_DRAWTYPE_LINE:		$drawtype = "Line";		break;
-			case MAP_LINK_DRAWTYPE_BOLD_LINE:	$drawtype = "Bold line";	break;
-			case MAP_LINK_DRAWTYPE_DOT:		$drawtype = "Dot";		break;
-			case MAP_LINK_DRAWTYPE_DASHED_LINE:	$drawtype = "Dashed line";	break;
+			case MAP_LINK_DRAWTYPE_LINE:		$drawtype = S_LINE;		break;
+			case MAP_LINK_DRAWTYPE_BOLD_LINE:	$drawtype = S_BOLD_LINE;	break;
+			case MAP_LINK_DRAWTYPE_DOT:		$drawtype = S_DOT;		break;
+			case MAP_LINK_DRAWTYPE_DASHED_LINE:	$drawtype = S_DASHED_LINE;	break;
 			default: $drawtype = S_UNKNOWN;		break;
 		}
 		return $drawtype;
@@ -96,7 +96,7 @@
 				switch($se_data['elementtype'])
 				{
 					case SYSMAP_ELEMENT_TYPE_HOST:
-						if(in_array($se_data['elementid'],explode(',',$denyed_hosts)))
+						if(uint_in_array($se_data['elementid'],explode(',',$denyed_hosts)))
 						{
 							$result = false;
 						}
@@ -116,7 +116,7 @@
 						break;
 					case SYSMAP_ELEMENT_TYPE_HOST_GROUP:
 						if( DBfetch(DBselect('select groupid from groups where groupid='.$se_data['elementid'])) &&
-						    in_array($se_data['elementid'],
+						    uint_in_array($se_data['elementid'],
 							get_accessible_groups_by_user($USER_DETAILS,PERM_READ_ONLY, PERM_MODE_LT, PERM_RES_IDS_ARRAY)))
 						{
 							$result = false;
@@ -250,7 +250,7 @@
 	{
 		if($elementtype!=SYSMAP_ELEMENT_TYPE_MAP)	return FALSE;
 
-		if($sysmapid == $elementid)	return TRUE;
+		if(bccomp($sysmapid ,$elementid)==0)	return TRUE;
 
 		$db_elements = DBselect("select elementid, elementtype from sysmaps_elements".
 			" where sysmapid=$elementid");
@@ -413,19 +413,19 @@
 		$el_type =& $db_element["elementtype"];
 
 		$sql = array(
-			SYSMAP_ELEMENT_TYPE_TRIGGER => 'select distinct t.triggerid, t.priority, t.value, t.description, h.host '.
+			SYSMAP_ELEMENT_TYPE_TRIGGER => 'select distinct t.triggerid, t.priority, t.value, t.description, t.expression, h.host '.
 				'from triggers t, items i, functions f, hosts h where t.triggerid='.$db_element['elementid'].
 				' and h.hostid=i.hostid and i.itemid=f.itemid and f.triggerid=t.triggerid '.
 				' and h.status='.HOST_STATUS_MONITORED.' and i.status='.ITEM_STATUS_ACTIVE,
 			SYSMAP_ELEMENT_TYPE_HOST_GROUP => 'select distinct t.triggerid, t.priority, t.value,'.
-				' t.description, h.host, g.name as el_name '.
+				' t.description, t.expression, h.host, g.name as el_name '.
 				' from items i,functions f,triggers t,hosts h,hosts_groups hg,groups g '.
 				' where h.hostid=i.hostid and hg.groupid=g.groupid and g.groupid='.$db_element['elementid'].
 				' and hg.hostid=h.hostid and i.itemid=f.itemid'.
 				' and f.triggerid=t.triggerid and t.status='.TRIGGER_STATUS_ENABLED.
 				' and h.status='.HOST_STATUS_MONITORED.' and i.status='.ITEM_STATUS_ACTIVE,
 			SYSMAP_ELEMENT_TYPE_HOST => 'select distinct t.triggerid, t.priority, t.value,'.
-				' t.description, h.host, h.host as el_name'.
+				' t.description, t.expression, h.host, h.host as el_name'.
 				' from items i,functions f,triggers t,hosts h where h.hostid=i.hostid'.
 				' and i.hostid='.$db_element['elementid'].' and i.itemid=f.itemid'.
 				' and f.triggerid=t.triggerid and t.status='.TRIGGER_STATUS_ENABLED.
