@@ -147,32 +147,34 @@ COpt::profiling_start("page");
 				"default_page_id"	=> 0,
 				"forse_disable_subnodes"=> true,
 				"pages"=>array(
-					array("url"=>"config.php"	,"label"=>S_GENERAL		,
+					array("url"=>"config.php"	,"label"=>S_GENERAL,
 						"sub_pages"=>array("image.php")
 						),
-					array("url"=>"httpconf.php"	,"label"=>S_WEB			,
+					array("url"=>"httpconf.php"	,"label"=>S_WEB,
 						"sub_pages"=>array("popup_httpstep.php")
 						),
-					array("url"=>"hosts.php"	,"label"=>S_HOSTS		),
-					array("url"=>"items.php"	,"label"=>S_ITEMS		),
-					array("url"=>"triggers.php"	,"label"=>S_TRIGGERS		,
+					array("url"=>"hosts.php"	,"label"=>S_HOSTS),
+					array("url"=>"items.php"	,"label"=>S_ITEMS,
+						"sub_pages"=>array("tr_logform.php")		
+						),
+					array("url"=>"triggers.php"	,"label"=>S_TRIGGERS,
 						"sub_pages"=>array("popup_trexpr.php")
 						),
-					array("url"=>"actionconf.php"	,"label"=>S_ACTIONS		),
-					array("url"=>"sysmaps.php"	,"label"=>S_MAPS		,
+					array("url"=>"actionconf.php"	,"label"=>S_ACTIONS),
+					array("url"=>"sysmaps.php"	,"label"=>S_MAPS,
 						"sub_pages"=>array("sysmap.php")
 						),
-					array("url"=>"graphs.php"	,"label"=>S_GRAPHS		,
+					array("url"=>"graphs.php"	,"label"=>S_GRAPHS,
 						"sub_pages"=>array("popup_gitem.php")
 						),
-					array("url"=>"screenconf.php"	,"label"=>S_SCREENS		,
+					array("url"=>"screenconf.php"	,"label"=>S_SCREENS,
 						"sub_pages"=>array("screenedit.php")
 						),
-					array("url"=>"services.php"	,"label"=>S_IT_SERVICES	,
+					array("url"=>"services.php"	,"label"=>S_IT_SERVICES,
 						"sub_pages"=>array("services_form.php")	
 						),
-					array('url'=>'discoveryconf.php','label'=>S_DISCOVERY		),
-					array("url"=>"exp_imp.php"	,"label"=>S_EXPORT_IMPORT	),
+					array('url'=>'discoveryconf.php','label'=>S_DISCOVERY),
+					array("url"=>"exp_imp.php"	,"label"=>S_EXPORT_IMPORT),
 					array("url"=>"popup.php")
 					)
 				),
@@ -277,7 +279,7 @@ COpt::profiling_start("page");
 			}
 			else if(isset($sub_pages['sub_pages']))
 			{
-				if(in_array($page['file'], $sub_pages['sub_pages']))
+				if(str_in_array($page['file'], $sub_pages['sub_pages']))
 				{
 					if(isset($sub_pages['label']))
 					{
@@ -356,6 +358,7 @@ COpt::profiling_start("page");
     <meta http-equiv="refresh" content="<?php echo $USER_DETAILS["refresh"]; ?>">
 <?php } ?>
     <link rel="stylesheet" href="css.css">
+    <link rel="shortcut icon" href="images/general/zabbix.ico">
     <meta name="Author" content="ZABBIX SIA">
     <script type="text/javascript" src="js/common.js"></script>
   </head>
@@ -399,7 +402,7 @@ COpt::compare_files_with_menu($ZBX_MENU);
 
 		if(ZBX_DISTRIBUTED)
 		{
-			$lst_nodes = new CComboBox('switch_node', get_current_nodeid(false));
+			$lst_nodes = new CComboBox('switch_node', get_current_nodeid(false), "submit()");
 			$db_nodes = DBselect(
 					'select * from nodes '.
 					' where nodeid in ('.
@@ -422,14 +425,15 @@ COpt::compare_files_with_menu($ZBX_MENU);
 				{
 					global $ZBX_WITH_SUBNODES;
 
-					$cmd_show_subnodes = new CComboBox('show_subnodes', !empty($ZBX_WITH_SUBNODES) ? 1 : 0);
+					$cmd_show_subnodes = new CComboBox('show_subnodes', !empty($ZBX_WITH_SUBNODES) ? 1 : 0, "submit()");
 					$cmd_show_subnodes->AddItem(0, S_CURRENT_NODE_ONLY);
 					$cmd_show_subnodes->AddItem(1, S_WITH_SUBNODES);
 
 					$node_form->AddItem(array(SPACE, S_SHOW, $cmd_show_subnodes));
 				}
 
-				$node_form->AddItem(new CButton('submit',S_SWITCH_NODE));
+// No need for the button anymore
+//				$node_form->AddItem(new CButton('submit',S_SWITCH_NODE));
 			}
 		}
 		
