@@ -19,8 +19,6 @@
 **/
 ?>
 <?php
-	require_once "include/db.inc.php";
-
 	function	permission2str($group_permission)
 	{
 		$str_perm[PERM_READ_WRITE]	= S_READ_WRITE;
@@ -131,8 +129,9 @@
 		return $perm_mode;
 	}
 
-	function	get_accessible_hosts_by_user(&$user_data,$perm,$perm_mode=null,$perm_res=null,$nodeid=null,$hostid=null)
-	{
+	function	get_accessible_hosts_by_user(&$user_data,$perm,$perm_mode=null,$perm_res=null,$nodeid=null,$hostid=null){
+		global $DB_TYPE;
+		
 		if(is_null($perm_res))		$perm_res	= PERM_RES_STRING_LINE;
 		if($perm == PERM_READ_LIST)	$perm		= PERM_READ_ONLY;
 
@@ -162,32 +161,33 @@ COpt::counter_up('perm');
 		if(count($where)) 	$where = ' where '.implode(' and ',$where);
 		else			$where = '';
 	
-		$db_hosts = DBselect('select distinct n.nodeid,n.name as node_name,h.hostid,h.host, min(r.permission) as permission,ug.userid '.
-			' from hosts h left join hosts_groups hg on hg.hostid=h.hostid '.
-			' left join groups g on g.groupid=hg.groupid '.
-			' left join rights r on r.id=g.groupid and r.type='.RESOURCE_TYPE_GROUP.
-			' left join users_groups ug on ug.usrgrpid=r.groupid and ug.userid='.$userid.
-			' left join nodes n on '.DBid2nodeid('h.hostid').'=n.nodeid '.
-			$where.' group by h.hostid,n.nodeid,n.name,h.host,ug.userid '.
-			' order by n.name,n.nodeid, h.host, permission desc, userid desc');
+		$sortorder = (isset($DB_TYPE) && (($DB_TYPE == 'MYSQL') || ($DB_TYPE == 'SQLITE3')))?' DESC ':'';
+		
+		$sql = 'select distinct n.nodeid,n.name as node_name,h.hostid,h.host, min(r.permission) as permission,ug.userid '.
+			' from hosts h '.
+				' left join hosts_groups hg on hg.hostid=h.hostid '.
+				' left join groups g on g.groupid=hg.groupid '.
+				' left join rights r on r.id=g.groupid and r.type='.RESOURCE_TYPE_GROUP.
+				' left join users_groups ug on ug.usrgrpid=r.groupid and ug.userid='.$userid.
+				' left join nodes n on '.DBid2nodeid('h.hostid').'=n.nodeid '.
+			$where.
+			' group by h.hostid,n.nodeid,n.name,h.host,ug.userid '.
+			' order by n.name,n.nodeid, h.host, permission '.$sortorder.', userid '.$sortorder;
+
+		$db_hosts = DBselect($sql);
 
 		$processed = array();
-		while($host_data = DBfetch($db_hosts))
-		{
-			$host_data += DBfetch(DBselect('select * from hosts where hostid='.$host_data['hostid']));
-
+		while($host_data = DBfetch($db_hosts)){
+		
 			if(is_null($host_data['nodeid'])) $host_data['nodeid'] = id2nodeid($host_data['hostid']);
 
 			/* if no rights defined used node rights */
-			if( (is_null($host_data['permission']) || is_null($host_data['userid'])) )
-			{
-				if( isset($processed[$host_data['hostid']]) )
+			if( (is_null($host_data['permission']) || is_null($host_data['userid'])) ){
+				if(($user_type != USER_TYPE_SUPER_ADMIN) && (isset($processed[$host_data['hostid']]) || is_null($host_data['userid'])))
 					continue;
 
-				if(!isset($nodes))
-				{
-					$nodes = get_accessible_nodes_by_user($user_data,
-						PERM_DENY,PERM_MODE_GE,PERM_RES_DATA_ARRAY);
+				if(!isset($nodes)){
+					$nodes = get_accessible_nodes_by_user($user_data,PERM_DENY,PERM_MODE_GE,PERM_RES_DATA_ARRAY);
 				}
 				if( !isset($nodes[$host_data['nodeid']]) || $user_type==USER_TYPE_ZABBIX_USER )
 					$host_data['permission'] = PERM_DENY;
@@ -205,8 +205,7 @@ COpt::counter_up('perm');
 
 		unset($processed, $host_data, $db_hosts);
 
-		if($perm_res == PERM_RES_STRING_LINE) 
-		{
+		if($perm_res == PERM_RES_STRING_LINE) {
 			if(count($result) == 0) 
 				$result = '-1';
 			else
@@ -218,7 +217,7 @@ COpt::counter_up('perm');
 
 	function	get_accessible_groups_by_user($user_data,$perm,$perm_mode=null,$perm_res=null,$nodeid=null)
 	{
-		global $ZBX_LOCALNODEID;
+		global $ZBX_LOCALNODEID, $DB_TYPE;
 
 		if(is_null($perm_mode))		$perm_mode	= PERM_MODE_GE;
 		if(is_null($perm_res))		$perm_res	= PERM_RES_STRING_LINE;
@@ -244,21 +243,27 @@ COpt::counter_up('perm');
 	
 		if(count($where)) 	$where = ' where '.implode(' and ',$where);
 		else			$where = '';
-	
-		/* if no rights defined used node rights */
-		$db_groups = DBselect('select n.nodeid as nodeid,n.name as node_name,hg.groupid,hg.name,min(r.permission) as permission,g.userid'.
-			' from groups hg left join rights r on r.id=hg.groupid and r.type='.RESOURCE_TYPE_GROUP.
-			' left join users_groups g on r.groupid=g.usrgrpid and g.userid='.$userid.
-			' left join nodes n on '.DBid2nodeid('hg.groupid').'=n.nodeid '.
-			$where.' group by n.nodeid, n.name, hg.groupid, hg.name, g.userid, g.userid '.
-			' order by n.name, hg.name, permission desc');
+
+		$sortorder = (isset($DB_TYPE) && (($DB_TYPE == 'MYSQL') || ($DB_TYPE == 'SQLITE3')))?' DESC ':'';	
+		
+		$sql = 'SELECT n.nodeid as nodeid,n.name as node_name,hg.groupid,hg.name,min(r.permission) as permission,g.userid'.
+			' FROM groups hg '.
+				' LEFT JOIN rights r ON r.id=hg.groupid and r.type='.RESOURCE_TYPE_GROUP.
+				' LEFT JOIN users_groups g ON r.groupid=g.usrgrpid and g.userid='.$userid.
+				' LEFT JOIN nodes n ON '.DBid2nodeid('hg.groupid').'=n.nodeid '.
+			$where.
+			' GROUP BY n.nodeid, n.name, hg.groupid, hg.name, g.userid, g.userid '.
+			' ORDER BY n.name, hg.name, permission '.$sortorder;
+
+/* if no rights defined used node rights */
+		$db_groups = DBselect($sql);
 
 		$processed = array();
 		while($group_data = DBfetch($db_groups))
 		{
 			if(is_null($group_data['nodeid'])) $group_data['nodeid'] = id2nodeid($group_data['groupid']);
 
-			/* deny if no rights defined */
+/* deny if no rights defined */
 			if( is_null($group_data['permission']) || is_null($group_data['userid']) )
 			{
 				if(isset($processed[$group_data['groupid']]))
@@ -352,8 +357,10 @@ COpt::counter_up('perm');
 
 					$do_break = true;
 
-					if(is_array($nodeid) && !in_array($node_data['nodeid'],$nodeid))	continue;
-					else if(isset($nodeid) and $node_data['nodeid'] != $nodeid)		continue;
+					if(isset($nodeid) && is_array($nodeid)){
+						if(!uint_in_array($node_data['nodeid'],$nodeid))	continue;
+					}
+					else if(isset($nodeid) && (bccomp($node_data['nodeid'] ,$nodeid) != 0))	continue;
 				}
 				else
 				{
@@ -370,7 +377,7 @@ COpt::counter_up('perm');
 					$node_data['permission'] = PERM_READ_WRITE;
 				else
 					$node_data['permission'] = 
-						($node_data['nodeid'] == $ZBX_LOCALNODEID) ? PERM_READ_WRITE : PERM_DENY;
+						(bccomp($node_data['nodeid'] ,$ZBX_LOCALNODEID)==0) ? PERM_READ_WRITE : PERM_DENY;
 			}
 
 			/* special processing for PERM_READ_LIST*/
@@ -617,8 +624,8 @@ COpt::counter_up('perm');
 
 					$do_break = true;
 
-					if(is_array($nodeid) && !in_array($node_data['nodeid'],$nodeid))	continue;
-					else if(isset($nodeid) and $node_data['nodeid'] != $nodeid)		continue;
+					if(is_array($nodeid) && !uint_in_array($node_data['nodeid'],$nodeid))	continue;
+					else if(isset($nodeid) and (bccomp($node_data['nodeid'] ,$nodeid) != 0))		continue;
 				}
 				else
 				{
@@ -628,7 +635,7 @@ COpt::counter_up('perm');
 
 			if(isset($node_perm[$node_data['nodeid']]))
 				$node_data['permission'] = $node_perm[$node_data['nodeid']];
-			elseif($node_data['nodeid'] == $ZBX_LOCALNODEID || $user_type == USER_TYPE_SUPER_ADMIN)
+			elseif((bccomp($node_data['nodeid'], $ZBX_LOCALNODEID)==0) || $user_type == USER_TYPE_SUPER_ADMIN)
 			/* for local node or superuser default permission is READ_WRITE */
 					$node_data['permission'] = PERM_READ_WRITE;
 
