@@ -164,7 +164,7 @@
 
 	function	check_screen_recursion($mother_screenid, $child_screenid)
 	{
-			if($mother_screenid == $child_screenid)	return TRUE;
+			if((bccomp($mother_screenid , $child_screenid)==0))	return TRUE;
 
 			$db_scr_items = DBselect("select resourceid from screens_items where".
 				" screenid=$child_screenid and resourcetype=".SCREEN_RESOURCE_SCREEN);
@@ -211,7 +211,7 @@
 			$slide_data['delay'] = $slide_data['ss_delay'];
 		}
 
-		Redirect('screens.php?config=1&fullscreen=2&elementid='.$slideshowid.'&step='.($curr_step + 1).
+		simple_js_redirect('screens.php?config=1&fullscreen=2&elementid='.$slideshowid.'&step='.($curr_step + 1).
 				'&period='.$effectiveperiod.url_param('stime').url_param('from'),
 				$slide_data['delay']);
 
@@ -319,7 +319,7 @@
 					$item = get_screen_item_form();
 				}
 				elseif($editmode == 1 && isset($_REQUEST["form"]) &&
-					isset($_REQUEST["screenitemid"]) && $_REQUEST["screenitemid"]==$screenitemid)
+					isset($_REQUEST["screenitemid"]) && (bccomp($_REQUEST["screenitemid"], $screenitemid)==0))
 				{ // click on element
 					$item = get_screen_item_form();
 				}
