@@ -22,7 +22,7 @@
 	function	add_service($name,$triggerid,$algorithm,$showsla,$goodsla,$sortorder,$service_times=array(),$parentid,$childs){
 	
 		foreach($childs as $id => $child){		//add childs
-			if($parentid == $child['serviceid']){
+			if((bccomp($parentid , $child['serviceid'])==0)){
 				error('Service can\'t be parent and child in onetime.');
 				return FALSE;
 			}
@@ -70,7 +70,7 @@
 
 	function	update_service($serviceid,$name,$triggerid,$algorithm,$showsla,$goodsla,$sortorder,$service_times=array(),$parentid,$childs){
 		foreach($childs as $id => $child){		//add childs
-			if($parentid == $child['serviceid']){
+			if((bccomp($parentid , $child['serviceid'])==0)){
 				error('Service can\'t be parent and child in onetime.');
 				return FALSE;
 			}
@@ -107,7 +107,7 @@
 	}
 	
 	function	add_host_to_services($hostid, $serviceid){
-		$result = DBselect('SELECT distinct h.host,t.triggerid,t.description '.
+		$result = DBselect('SELECT distinct h.host,t.triggerid,t.description,t.expression '.
 							' FROM triggers t,hosts h,items i,functions f '.
 							' WHERE h.hostid='.$hostid.
 								' AND h.hostid=i.hostid '.
@@ -247,7 +247,7 @@
 		{
 			return	FALSE;
 		}
-		if($serviceid==$serviceid2)
+		if((bccomp($serviceid, $serviceid2)==0))
 		{
 			if($service["status"]>0)
 			{
@@ -293,7 +293,7 @@
 			return	false;
 		}
 
-		if($servicedownid==$serviceupid){
+		if((bccomp($servicedownid, $serviceupid)==0)){
 			error("cannot link service to itself.");
 			return	false;
 		}
@@ -314,7 +314,7 @@
 			return	false;
 		}
 
-		if($servicedownid==$serviceupid){
+		if((bccomp($servicedownid, $serviceupid)==0)){
 			error("cannot link service to itself.");
 			return	false;
 		}
@@ -363,7 +363,7 @@
 		)
 	{
 			/* calculate period FROM '-1 week' to know period name for  $period_start */
-			for($curr = ($period_start - (7*24*36000)); $curr<=$period_end; $curr += 6*3600)
+			for($curr = ($period_start - (7*24*3600)); $curr<=$period_end; $curr += 6*3600)
 			{
 				$curr_date = getdate($curr);
 				$from_date = getdate($ts_from);
@@ -720,11 +720,7 @@ $dt = 0;
 		}
 	return ;
 	}
-	
-	function closeform(){
-		zbx_add_post_js('closeform();');
-	}
-	
+		
 	function del_empty_nodes($services){
 		do{
 			unset($retry);
@@ -749,7 +745,7 @@ $dt = 0;
  *                                                                            *
  * Return value:                                                              *
  *                                                                            *
- * Author: Alexei Vladishev   (PHP ver. by Artem Suharev)                     *
+ * Author: Alexei Vladishev   (PHP ver. by Aly)                     *
  *                                                                            *
  * Comments: recursive function   !!! Don't forget sync code with C !!!       *
  *                                                                            *
@@ -802,7 +798,7 @@ function update_services_rec($serviceid){
  *                                                                            *
  * Return value:                                                              *
  *                                                                            *
- * Author: Alexei Vladishev   (PHP ver. by Artem Suharev)                     *
+ * Author: Alexei Vladishev   (PHP ver. by Aly)                     *
  *                                                                            *
  * Comments: !!! Don't forget sync code with C !!!                            *
  *                                                                            *
@@ -827,7 +823,7 @@ function update_services($triggerid, $status){
  *     Cleaning parent nodes from triggers, updating ALL services status.
  *     
  * Author: 
- *     Artem Suharev
+ *     Aly
  *
  * Comments: !!! Don't forget sync code with C !!!
  *
