@@ -358,29 +358,13 @@
 	 * Comments:
 	 *
 	 */
-	function	&get_triggers_by_hostid($hostid, $show_mixed = "yes")
-	{
-		$db_triggers = DBselect("select distinct t.* from triggers t, functions f, items i".
-			" where i.hostid=$hostid and f.itemid=i.itemid and f.triggerid=t.triggerid");
-
-		if($show_mixed == "yes")
-			return $db_triggers;
-
-		$triggers = array();
-		while($db_trigger = DBfetch($db_triggers))
-		{
-			$db_hosts = get_hosts_by_triggerid($db_trigger["triggerid"]);
-			if(DBfetch($db_hosts))
-			{
-				array_push($triggers,$db_trigger["triggerid"]);
-			}
-		}
-		$sql = "select distinct * from triggers where triggerid=0";
-		foreach($triggers as $triggerid)
-		{
-			$sql .= " or triggerid=$triggerid";
-		}
-		return DBselect($sql);
+	function	&get_triggers_by_hostid($hostid){
+		$db_triggers = DBselect('SELECT DISTINCT t.* '.
+								' FROM triggers t, functions f, items i '.
+								' WHERE i.hostid='.$hostid.
+									' AND f.itemid=i.itemid '.
+									' AND f.triggerid=t.triggerid');
+	return $db_triggers;
 	}
 
 	function	&get_triggers_by_templateid($triggerid)
@@ -593,7 +577,7 @@
 				$fnc_valid = &$ZBX_TR_EXPR_ALLOWED_FUNCTIONS[$function];
 
 				if ( is_array($fnc_valid['item_types']) &&
-					!in_array($item['value_type'], $fnc_valid['item_types']))
+					!uint_in_array($item['value_type'], $fnc_valid['item_types']))
 				{
 					$allowed_types = array();
 					foreach($fnc_valid['item_types'] as $type)
@@ -676,11 +660,12 @@
 		$expression, $description, $priority, $status,
 		$comments, $url, $deps=array(), $templateid=0)
 	{
+		
 		if( !validate_expression($expression) )
 			return false;
 
 		$triggerid=get_dbid("triggers","triggerid");
-
+		
 		$result=DBexecute("insert into triggers".
 			"  (triggerid,description,priority,status,comments,url,value,error,templateid)".
 			" values ($triggerid,".zbx_dbstr($description).",$priority,$status,".zbx_dbstr($comments).",".
@@ -711,6 +696,7 @@
 
 		$trig_hosts = get_hosts_by_triggerid($triggerid);
 		$trig_host = DBfetch($trig_hosts);
+		
 		if($result)
 		{
 			$msg = "Added trigger '".$description."'";
@@ -747,7 +733,7 @@
 	 * Comments: !!! Don't forget sync code with C !!!                            *
 	 *                                                                            *
 	 ******************************************************************************/
-	function	get_trigger_dependences_by_triggerid($triggerid)
+	function	get_trigger_dependencies_by_triggerid($triggerid)
 	{
 		$result = array();
 
@@ -763,7 +749,7 @@
 	 * Comments: !!! Don't forget sync code with C !!!                            *
 	 *                                                                            *
 	 ******************************************************************************/
-	function	replace_template_dependences($deps, $hostid)
+	function	replace_template_dependencies($deps, $hostid)
 	{
 		foreach($deps as $id => $val)
 		{
@@ -784,17 +770,27 @@
 	{
 		$trigger = get_trigger_by_triggerid($triggerid);
 
-		$deps = replace_template_dependences(
-				get_trigger_dependences_by_triggerid($triggerid),
+		$deps = replace_template_dependencies(
+				get_trigger_dependencies_by_triggerid($triggerid),
 				$hostid);
 
-		$host_triggers = get_triggers_by_hostid($hostid, "no");
-		while($host_trigger = DBfetch($host_triggers))
-		{
-			if($host_trigger["templateid"] != 0)				continue;
-			if(cmp_triggers($triggerid, $host_trigger["triggerid"]))	continue;
-
+		$sql='SELECT t2.triggerid, t2.expression '.
+				' FROM triggers t2, functions f1, functions f2, items i1, items i2 '.
+				' WHERE f1.triggerid='.$triggerid.
+					' AND i1.itemid=f1.itemid '.
+					' AND f2.function=f1.function '.
+					' AND f2.parameter=f1.parameter '.
+					' AND i2.itemid=f2.itemid '.
+					' AND i2.key_=i1.key_ '.
+					' AND i2.hostid='.$hostid.
+					' AND t2.triggerid=f2.triggerid '.
+					' AND t2.templateid=0 ';
+		
+		$host_triggers = DBSelect($sql);
+		while($host_trigger = DBfetch($host_triggers)){
+			if(cmp_triggers_exressions($triggerid, $host_trigger["triggerid"]))	continue;
 			// link not linked trigger with same expression
+			
 			return update_trigger(
 				$host_trigger["triggerid"],
 				NULL,	// expression
@@ -807,14 +803,13 @@
 				$copy_mode ? 0 : $triggerid);
 		}
 
-		$newtriggerid=get_dbid("triggers","triggerid");
+		$newtriggerid=get_dbid('triggers','triggerid');
 
-		$result = DBexecute("insert into triggers".
-			" (triggerid,description,priority,status,comments,url,value,expression,templateid)".
-			" values ($newtriggerid,".zbx_dbstr($trigger["description"]).",".$trigger["priority"].",".
-			$trigger["status"].",".zbx_dbstr($trigger["comments"]).",".
-			zbx_dbstr($trigger["url"]).",2,'{???:???}',".
-			($copy_mode ? 0 : $triggerid).")");
+		$result = DBexecute('INSERT INTO triggers'.
+					' (triggerid,description,priority,status,comments,url,value,expression,templateid)'.
+				' VALUES ('.$newtriggerid.','.zbx_dbstr($trigger['description']).','.$trigger['priority'].','.
+					$trigger["status"].','.zbx_dbstr($trigger["comments"]).','.
+					zbx_dbstr($trigger["url"]).",2,'0',".($copy_mode ? 0 : $triggerid).')');
 
 		if(!$result)
 			return $result;
@@ -852,7 +847,7 @@
 
 		DBexecute("update triggers set expression=".zbx_dbstr($newexpression).
 			" where triggerid=$newtriggerid");
-// copy dependences
+// copy dependencies
 		delete_dependencies_by_triggerid($newtriggerid);
 		foreach($deps as $dep_id)
 		{
@@ -917,10 +912,9 @@
 					}
 					else
 					{
-						$link = new CLink($function_data["host"].":".$function_data["key_"],
-							'history.php?action='.( $function_data["value_type"] ==0 ? 'showvalues' : 'showgraph').
-							'&itemid='.$function_data['itemid']);
-					
+						$link = new CLink($function_data['host'].':'.$function_data['key_'],
+							'history.php?action='.( (($function_data['value_type'] == ITEM_VALUE_TYPE_FLOAT) || ($function_data['value_type'] == ITEM_VALUE_TYPE_UINT64))?'showgraph':'showvalues').'&itemid='.$function_data['itemid']);
+												
 						$exp .= '{'.$link->ToString().'.'.bold($function_data["function"].'(').$function_data["parameter"].bold(')').'}';
 					}
 				}
@@ -979,10 +973,15 @@
 				$function	= &$arr[ZBX_EXPRESSION_SIMPLE_EXPRESSION_ID + ZBX_SIMPLE_EXPRESSION_FUNCTION_NAME_ID];
 				$parameter	= &$arr[ZBX_EXPRESSION_SIMPLE_EXPRESSION_ID + ZBX_SIMPLE_EXPRESSION_FUNCTION_PARAM_ID];
 
-				$item = DBfetch(DBselect('select i.itemid from items i,hosts h'.
+				$item_res = DBselect('select i.itemid from items i,hosts h'.
 					' where i.key_='.zbx_dbstr($key).
 					' and h.host='.zbx_dbstr($host).
-					' and h.hostid=i.hostid'));
+					' and h.hostid=i.hostid');
+
+				while(($item = DBfetch($item_res)) && (!in_node($item['itemid']))){
+				}
+				
+				if(!$item) return null;
 
 				$item = $item["itemid"];
 
@@ -1025,13 +1024,194 @@
 		return	DBexecute("update triggers set status=$status where triggerid=$triggerid");
 	}
 
-	# "Processor load on {HOSTNAME} is 5" to "Processor load on www.sf.net is 5"
-	function	expand_trigger_description_by_data($row)
+	/*
+	 * Function: extract_numbers
+	 *
+	 * Description: 
+	 *     Extract from string numbers with prefixes (A-Z)
+	 *     
+	 * Author: 
+	 *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
+	 *
+	 * Comments: !!! Don't forget sync code with C !!!
+	 *
+	 */
+	function	extract_numbers($str)
+	{
+		$numbers = array();
+		while ( ereg(ZBX_EREG_NUMBER.'([[:print:]]*)', $str, $arr) ) {
+			$numbers[] = $arr[1];
+			$str = $arr[2];
+		}
+		return $numbers;
+	}
+
+	/*
+	 * Function: expand_trigger_description_constants
+	 *
+	 * Description: 
+	 *     substitute simple macros in data string with real values
+	 *     
+	 * Author: 
+	 *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
+	 *
+	 * Comments: !!! Don't forget sync code with C !!!
+	 *           replcae $1-9 macros
+	 *
+	 */
+	function	expand_trigger_description_constants($description, $row)
+	{
+		if($row && isset($row['expression']))
+		{
+			$numbers = extract_numbers(ereg_replace('(\{[0-9]+\})', 'function', $row['expression']));
+			$description = $row["description"];
+
+			for ( $i = 0; $i < 9; $i++ )
+			{
+				$description = 
+					str_replace(
+						'$'.($i+1),
+						isset($numbers[$i]) ? 
+							$numbers[$i] : 
+							'', 
+						$description
+						);
+			}
+		}
+
+		return $description;
+	}
+	/*
+	 * Function: expand_trigger_description_by_data
+	 *
+	 * Description: 
+	 *     substitute simple macros in data string with real values
+	 *     
+	 * Author: 
+	 *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
+	 *
+	 * Comments: !!! Don't forget sync code with C !!!
+	 *
+	 */
+	function	expand_trigger_description_by_data($row, $flag = ZBX_FLAG_TRIGGER)
 	{
 		if($row)
 		{
+			$description = expand_trigger_description_constants($row['description'], $row);
+
 			if(is_null($row["host"])) $row["host"] = "{HOSTNAME}";
-			$description = str_replace("{HOSTNAME}", $row["host"],$row["description"]);
+			$description = str_replace("{HOSTNAME}", $row["host"],$description);
+
+			if(strstr($description,"{ITEM.LASTVALUE}"))
+			{
+				$row2=DBfetch(DBselect('select i.lastvalue,i.itemid,i.value_type from items i, triggers t, functions f '.
+					' where i.itemid=f.itemid and f.triggerid=t.triggerid and '.
+					' t.triggerid='.$row["triggerid"]));
+
+				if($row2["value_type"]!=ITEM_VALUE_TYPE_LOG)
+				{
+					$description = str_replace("{ITEM.LASTVALUE}", $row2["lastvalue"],$description);
+				}
+				else
+				{
+					$row3=DBfetch(DBselect("select max(clock) as max from history_log where itemid=".$row2["itemid"]));
+					if($row3 && !is_null($row3["max"]))
+					{
+						$row4=DBfetch(DBselect("select value from history_log where itemid=".$row2["itemid"]." and clock=".$row3["max"]));
+						$description = str_replace("{ITEM.LASTVALUE}", $row4["value"],$description);
+					}
+				}
+			}
+			if(strstr($description,'{ITEM.VALUE}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,1,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,1,$row['clock']);
+				$description = str_replace("{ITEM.VALUE}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE1}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,1,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,1,$row['clock']);
+				$description = str_replace("{ITEM.VALUE1}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE2}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,2,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,2,$row['clock']);
+				$description = str_replace("{ITEM.VALUE2}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE3}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,3,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,3,$row['clock']);
+				$description = str_replace("{ITEM.VALUE3}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE4}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,4,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,4,$row['clock']);
+				$description = str_replace("{ITEM.VALUE4}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE5}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,5,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,5,$row['clock']);
+				$description = str_replace("{ITEM.VALUE5}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE6}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,6,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,6,$row['clock']);
+				$description = str_replace("{ITEM.VALUE6}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE7}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,7,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,7,$row['clock']);
+				$description = str_replace("{ITEM.VALUE7}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE8}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,8,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,8,$row['clock']);
+				$description = str_replace("{ITEM.VALUE8}",
+						$value,
+						$description);
+			}
+			if(strstr($description,'{ITEM.VALUE9}'))
+			{
+				$value=($flag==ZBX_FLAG_TRIGGER)?
+						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,9,1):
+						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,9,$row['clock']);
+				$description = str_replace("{ITEM.VALUE9}",
+						$value,
+						$description);
+			}
 		}
 		else
 		{
@@ -1044,7 +1224,7 @@
 	{
 		return expand_trigger_description_by_data(
 			DBfetch(
-				DBselect("select distinct t.description,h.host".
+				DBselect("select distinct t.description,h.host,t.expression,t.triggerid ".
 					" from triggers t left join functions f on t.triggerid=f.triggerid ".
 					" left join items i on f.itemid=i.itemid ".
 					" left join hosts h on i.hostid=h.hostid ".
@@ -1056,7 +1236,7 @@
 	function	expand_trigger_description($triggerid)
 	{
 		$description=expand_trigger_description_simple($triggerid);
-		$description=stripslashes(htmlspecialchars($description));
+		$description=htmlspecialchars($description);
 
 		return $description;
 	}
@@ -1098,7 +1278,7 @@
 				' values('.$eventid.','.EVENT_SOURCE_TRIGGERS.','.EVENT_OBJECT_TRIGGER.','.$triggerid.','.$time.','.$value.')');
 		if($value == TRIGGER_VALUE_FALSE || $value == TRIGGER_VALUE_TRUE)
 		{
-			DBexesute('update alerts set retries=3,error=\'Trigger changed its status. WIll not send repeats.\''.
+			DBexecute('update alerts set retries=3,error=\'Trigger changed its status. WIll not send repeats.\''.
 				' where triggerid='.$triggerid.' and repeats>0 and status='.ALERT_STATUS_NOT_SENT);
 		}
 		return true;
@@ -1157,15 +1337,15 @@
 		DBexecute("update sysmaps_links set triggerid=NULL where triggerid=$triggerid");
 		
 	// disable actions
-		$db_actions = DBselect("select distinct actionid from conditions ".
-			" where conditiontype=".CONDITION_TYPE_TRIGGER." and value=".$triggerid);
+		$db_actions = DBselect('select distinct actionid from conditions '.
+			" where conditiontype=".CONDITION_TYPE_TRIGGER." and value=".zbx_dbstr($triggerid));
 		while($db_action = DBfetch($db_actions))
 		{
 			DBexecute("update actions set status=".ACTION_STATUS_DISABLED.
 				" where actionid=".$db_action["actionid"]);
 		}
 	// delete action conditions
-		DBexecute('delete from conditions where conditiontype='.CONDITION_TYPE_TRIGGER.' and value='.$triggerid);
+		DBexecute('delete from conditions where conditiontype='.CONDITION_TYPE_TRIGGER.' and value='.zbx_dbstr($triggerid));
 
 		$trigger = get_trigger_by_triggerid($triggerid);
 
@@ -1198,16 +1378,21 @@
 		$trig_hosts	= get_hosts_by_triggerid($triggerid);
 		$trig_host	= DBfetch($trig_hosts);
 
-		if(is_null($expression))
-		{
+		$event_to_unknown = false;		
+
+		if(is_null($expression)){
 			/* Restore expression */
 			$expression = explode_exp($trigger["expression"],0);
+		} 
+		else if($expression != explode_exp($trigger["expression"],0)){
+			$event_to_unknown = true;
 		}
-
+		
 		if ( !validate_expression($expression) )
 			return false;
 
 		$exp_hosts 	= get_hosts_by_expression($expression);
+		
 		if( $exp_hosts )
 		{
 			$chd_hosts	= get_hosts_by_templateid($trig_host["hostid"]);
@@ -1215,6 +1400,7 @@
 			if(DBfetch($chd_hosts))
 			{
 				$exp_host = DBfetch($exp_hosts);
+
 				$db_chd_triggers = get_triggers_by_templateid($triggerid);
 				while($db_chd_trigger = DBfetch($db_chd_triggers))
 				{
@@ -1225,6 +1411,7 @@
 						"{".$exp_host["host"].":",
 						"{".$chd_trig_host["host"].":",
 						$expression);
+
 				// recursion
 					update_trigger(
 						$db_chd_trigger["triggerid"],
@@ -1234,7 +1421,7 @@
 						NULL,		// status
 						$comments,
 						$url,
-						replace_template_dependences($deps, $chd_trig_host['hostid']),
+						replace_template_dependencies($deps, $chd_trig_host['hostid']),
 						$triggerid);
 				}
 			}
@@ -1248,7 +1435,7 @@
 
 		$expression = implode_exp($expression,$triggerid); /* errors can be ignored cose function must return NULL */
 
-		add_event($triggerid,TRIGGER_VALUE_UNKNOWN);
+		if($event_to_unknown) add_event($triggerid,TRIGGER_VALUE_UNKNOWN);
 		reset_items_nextcheck($triggerid);
 
 		$sql="update triggers set";
@@ -1304,7 +1491,7 @@
                 $db_hosts = get_hosts_by_expression($expression);
 		while($host_data = DBfetch($db_hosts))
 		{
-			if(!in_array($host_data['hostid'], $accessible_hosts)) return false;
+			if(!uint_in_array($host_data['hostid'], $accessible_hosts)) return false;
 		}
 
 		return true;
@@ -1410,12 +1597,44 @@
 		}
 		return	TRUE;
 	}
+	
+	/*
+	 * Function: cmp_triggers_exressions
+	 *
+	 * Description: 
+	 * 		Warning: function compares ONLY expressions,there is no check on functions and items
+	 *     
+	 * Author: 
+	 *     Aly
+	 *
+	 * Comments: 
+	 *
+	 */
+	function	cmp_triggers_exressions($triggerid1, $triggerid2)	// compare EXPRESSION !!!
+	{
+		$trig1 = get_trigger_by_triggerid($triggerid1);
+		$trig2 = get_trigger_by_triggerid($triggerid2);
+
+		$trig_fnc1 = get_functions_by_triggerid($triggerid1);
+		$expr1 = $trig1["expression"];
+		while($fnc1 = DBfetch($trig_fnc1)){
+			$trig_fnc2 = get_functions_by_triggerid($triggerid2);
+			while($fnc2 = DBfetch($trig_fnc2)){
+				$expr1 = str_replace(
+					"{".$fnc1["functionid"]."}",
+					"{".$fnc2["functionid"]."}",
+					$expr1);
+				break;
+			}
+		}
+		return strcmp($expr1,$trig2["expression"]);
+	}
 
 	/*
 	 * Function: cmp_triggers
 	 *
 	 * Description: 
-	 *     compate triggers by expression
+	 *     compare triggers by expression
 	 *     
 	 * Author: 
 	 *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
@@ -1480,7 +1699,7 @@
                                 $db_tmp_hosts = get_hosts_by_triggerid($trigger["templateid"]);
 				$tmp_host = DBfetch($db_tmp_hosts);
 
-				if( !in_array($tmp_host["hostid"], $templateid) )
+				if( !uint_in_array($tmp_host["hostid"], $templateid) )
 					continue;
                         }
 
@@ -1532,11 +1751,11 @@
 			copy_trigger_to_host($trigger["triggerid"], $hostid, $copy_mode);
 		}
 
-		update_template_dependences_for_host($hostid);
+		update_template_dependencies_for_host($hostid);
 	}
 
 	/*
-	 * Function: update_template_dependences_for_host
+	 * Function: update_template_dependencies_for_host
 	 *
 	 * Description: 
 	 *     Update template triggers
@@ -1547,7 +1766,7 @@
 	 * Comments: !!! Don't forget sync code with C !!!
 	 *
 	 */
-	function	update_template_dependences_for_host($hostid)
+	function	update_template_dependencies_for_host($hostid)
 	{
 		$db_triggers = get_triggers_by_hostid($hostid);
 		while($trigger_data = DBfetch($db_triggers))
@@ -1561,8 +1780,8 @@
 					/*$status*/		NULL,
 					/*$comments*/		NULL,
 					/*$url*/		NULL,
-					replace_template_dependences(
-						get_trigger_dependences_by_triggerid($trigger_data['triggerid']),
+					replace_template_dependencies(
+						get_trigger_dependencies_by_triggerid($trigger_data['triggerid']),
 						$hostid),
 					$trigger_data['triggerid']);
 
@@ -1581,65 +1800,77 @@
 	 * Comments: !!! Don't forget sync code with C !!!
 	 *
 	 */
-	function	get_triggers_overview($groupid)
-	{
+	function	get_triggers_overview($groupid){
 		global $USER_DETAILS;
 
 		$table = new CTableInfo(S_NO_TRIGGERS_DEFINED);
-		if($groupid > 0)
-		{
-			$group_where = ',hosts_groups hg where hg.groupid='.$groupid.' and hg.hostid=h.hostid and';
-		} else {
-			$group_where = ' where';
-		}
 
-		$result=DBselect('select distinct t.triggerid,t.description,t.value,t.priority,t.lastchange,h.hostid,h.host'.
-			' from hosts h,items i,triggers t, functions f '.$group_where.
-			' h.status='.HOST_STATUS_MONITORED.' and h.hostid=i.hostid and i.itemid=f.itemid and f.triggerid=t.triggerid'.
-			' and h.hostid in ('.get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY, null, null, get_current_nodeid()).') '.
-			' and t.status='.TRIGGER_STATUS_ENABLED.' and i.status='.ITEM_STATUS_ACTIVE.
-			' order by t.description');
+		$group_where=($groupid>0)?',hosts_groups hg WHERE hg.groupid='.$groupid.' and hg.hostid=h.hostid and':' WHERE ';
+
+		$result=DBselect('SELECT DISTINCT t.triggerid,t.description,t.expression,t.value,t.priority,t.lastchange,h.hostid,h.host'.
+						' FROM hosts h,items i,triggers t, functions f '.
+						$group_where.' h.status='.HOST_STATUS_MONITORED.
+							' AND h.hostid=i.hostid '.
+							' AND i.itemid=f.itemid '.
+							' AND f.triggerid=t.triggerid'.
+							' AND h.hostid in ('.get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY, null, null, get_current_nodeid()).') '.
+							' AND t.status='.TRIGGER_STATUS_ENABLED.
+							' AND i.status='.ITEM_STATUS_ACTIVE.
+						' ORDER BY t.description');
 		unset($triggers);
 		unset($hosts);
-		while($row = DBfetch($result))
-		{
-			$row['host'] = get_node_name_by_elid($row['hostid']).$row['host'];
 
-			$hosts[$row['host']] = $row['host'];
-			$triggers[$row['description']][$row['host']] = array(
-				'hostid'	=> $row['hostid'], 
-				'triggerid'	=> $row['triggerid'], 
-				'value'		=> $row['value'], 
-				'lastchange'	=> $row['lastchange'],
-				'priority'	=> $row['priority']);
+		$triggers = array();
+
+		while($row = DBfetch($result)){
+			$row['host'] = get_node_name_by_elid($row['hostid']).$row['host'];
+			$row['description'] = expand_trigger_description_constants($row['description'], $row);
+
+			$hosts[strtolower($row['host'])] = $row['host'];
+
+			// A little tricky check for attempt to overwrite active trigger (value=1) with
+			// inactive or active trigger with lower priority.
+			if(!isset($triggers[$row['description']][$row['host']]) ||
+				(
+					(($triggers[$row['description']][$row['host']]['value'] == TRIGGER_VALUE_FALSE) && ($row['value'] == TRIGGER_VALUE_TRUE)) ||
+					(
+						(($triggers[$row['description']][$row['host']]['value'] == TRIGGER_VALUE_FALSE) || ($row['value'] == TRIGGER_VALUE_TRUE)) &&
+						($row['priority'] > $triggers[$row['description']][$row['host']]['priority']) 
+					)
+				)
+			)
+			{
+				$triggers[$row['description']][$row['host']] = array(
+					'hostid'	=> $row['hostid'],
+					'triggerid'	=> $row['triggerid'],
+					'value'		=> $row['value'],
+					'lastchange'	=> $row['lastchange'],
+					'priority'	=> $row['priority']);
+			}
 		}
-		if(!isset($hosts))
-		{
+		
+		if(!isset($hosts)){
 			return $table;
 		}
-		sort($hosts);
+		ksort($hosts);
 
 		$header=array(new CCol(S_TRIGGERS,'center'));
-		foreach($hosts as $hostname)
-		{
+		foreach($hosts as $hostname){
 			$header=array_merge($header,array(new CImg('vtext.php?text='.$hostname)));
 		}
 		$table->SetHeader($header,'vertical_header');
 
-		foreach($triggers as $descr => $trhosts)
-		{
+		foreach($triggers as $descr => $trhosts){
 			$table_row = array(nbsp($descr));
-			foreach($hosts as $hostname)
-			{
+			foreach($hosts as $hostname){
 				$css_class = NULL;
 
 				unset($tr_ov_menu);
 				$ack = null;
-				if(isset($trhosts[$hostname]))
-				{
+				unset($style);
+				if(isset($trhosts[$hostname])){
 					unset($ack_menu);
-					switch($trhosts[$hostname]['value'])
-					{
+					switch($trhosts[$hostname]['value']){
 						case TRIGGER_VALUE_TRUE:
 							$css_class = get_severity_style($trhosts[$hostname]['priority']);
 							if( ($ack = get_last_event_by_triggerid($trhosts[$hostname]['triggerid'])) )
@@ -1663,11 +1894,11 @@
 					if((time(NULL)-$trhosts[$hostname]['lastchange'])<300)
 						$style .= 'background-image: url(images/gradients/blink1.gif); '.
 							'background-position: top left; '.
-							'background-repeat: repeate;';
+							'background-repeat: repeat;';
 					elseif((time(NULL)-$trhosts[$hostname]['lastchange'])<900)
 						$style .= 'background-image: url(images/gradients/blink2.gif); '.
 							'background-position: top left; '.
-							'background-repeat: repeate;';
+							'background-repeat: repeat;';
 
 					unset($item_menu);
 					$tr_ov_menu = array(
@@ -1798,7 +2029,7 @@
 		}
 
 		$result=DBselect('select clock,value from events where objectid='.$triggerid.' and object='.EVENT_OBJECT_TRIGGER
-			.' and clock>='.$min.' and clock<='.$max);
+			.' and clock>='.$min.' and clock<='.$max.' order by clock asc');
 
 		$state		= -1;
 		$true_time	= 0;
@@ -1896,4 +2127,124 @@
 		return $ret;
 	}
 
+	/*
+	 * Function: trigger_depenent_rec
+	 *
+	 * Description: 
+	 *     check if trigger depends on other triggers having status TRUE
+	 *     
+	 * Author: 
+	 *     Alexei Vladishev
+	 *
+	 * Comments: Recursive function
+	 *
+	 */
+	function	trigger_dependent_rec($triggerid,&$level)
+	{
+		$ret = FALSE;
+	
+		$level++;
+
+		/* Check for recursive loop */
+		if($level > 32)	return $ret;
+
+		$result = DBselect("select t.triggerid, t.value from trigger_depends d,triggers t where d.triggerid_down=$triggerid and d.triggerid_up=t.triggerid");
+		while($row = DBfetch($result))
+		{
+                	$triggerid_tmp = $row["triggerid"];
+                	$value_tmp = $row["value"];
+			if(TRIGGER_VALUE_TRUE == $value_tmp || trigger_dependent_rec($triggerid_tmp, $level))
+			{
+				$ret = TRUE;
+				break;
+			}
+		}
+
+		return $ret;
+	}
+
+	/*
+	 * Function: trigger_depenent 
+	 *
+	 * Description: 
+	 *     check if trigger depends on other triggers having status TRUE
+	 *     
+	 * Author: 
+	 *     Alexei Vladishev
+	 *
+	 * Comments:
+	 *
+	 */
+	function	trigger_dependent($triggerid)
+	{
+		$level = 0;
+		return trigger_dependent_rec($triggerid, $level);
+	}
+
+	/*
+	 * Function: trigger_get_N_functionid 
+	 *
+	 * Description: 
+	 *     get functionid of Nth function of trigger expression
+	 *     
+	 * Author: 
+	 *     Alexei Vladishev
+	 *
+	 * Comments:
+	 *
+	 */
+	function	trigger_get_N_functionid($expression, $function)
+	{
+		$result = NULL;
+
+		$arr=split('[\{\}]',$expression);
+		$num=1;
+		foreach($arr as $id)
+		{
+			if(is_numeric($id))
+			{
+				if($num == $function)
+				{
+					$result = $id;
+					break;
+				}
+				$num++;
+			}
+		}
+		return $result;
+	}
+
+	/*
+	 * Function: trigger_get_func_value 
+	 *
+	 * Description: 
+	 *     get historical value of Nth function of trigger expression
+	 *     flag:  ZBX_FLAG_EVENT - get value by clock, ZBX_FLAG_TRIGGR - get value by index
+	 *     ZBX_FLAG_TRIGGER, param: 0 - last value, 1 - prev, 2 - prev prev, etc     
+	 *     ZBX_FLAG_EVENT, param: event timestamp
+	 *     
+	 * Author: 
+	 *     Alexei Vladishev
+	 *
+	 * Comments:
+	 *
+	 */
+	function	trigger_get_func_value($expression, $flag, $function, $param)
+	{
+		$result = NULL;
+
+		$functionid=trigger_get_N_functionid($expression,$function);
+		if(isset($functionid))
+		{
+			$row=DBfetch(DBselect('select i.* from items i, functions f '.
+				' where i.itemid=f.itemid and f.functionid='.$functionid));
+			if($row)
+			{
+				$result=($flag == ZBX_FLAG_TRIGGER)?
+					item_get_history($row, $param):
+					item_get_history($row, 0, $param);
+			}
+		}
+		return $result;
+	}
 ?>
