@@ -87,17 +87,17 @@ include_once "include/page_header.php";
 		"groupid"=>	array(T_ZBX_INT, O_OPT,	 P_SYS,	DB_ID,null),
 		"hostid"=>	array(T_ZBX_INT, O_OPT,  P_SYS,	DB_ID,'isset({save})'),
 
-		"add_groupid"=>	array(T_ZBX_INT, O_OPT,	 P_SYS,	DB_ID,'{register}=="go"'),
-		"action"=>	array(T_ZBX_STR, O_OPT,	 P_SYS,	NOT_EMPTY,'{register}=="go"'),
+		"add_groupid"=>	array(T_ZBX_INT, O_OPT,	 P_SYS,	DB_ID,		'(isset({register})&&({register}=="go"))'),
+		"action"=>	array(T_ZBX_STR, O_OPT,	 P_SYS,	NOT_EMPTY,		'(isset({register})&&({register}=="go"))'),
 
-		"copy_type"	=>array(T_ZBX_INT, O_OPT,	 P_SYS,	IN("0,1"),'isset({copy})'),
+		"copy_type"	=>array(T_ZBX_INT, O_OPT,	 P_SYS,	IN("0,1"),	'isset({copy})'),
 		"copy_mode"	=>array(T_ZBX_INT, O_OPT,	 P_SYS,	IN("0"),null),
 
-		"itemid"=>	array(T_ZBX_INT, O_NO,	 P_SYS,	DB_ID,'{form}=="update"'),
-		"description"=>	array(T_ZBX_STR, O_OPT,  null,	NOT_EMPTY,'isset({save})'),
-		"key"=>		array(T_ZBX_STR, O_OPT,  null,  NOT_EMPTY,'isset({save})'),
-		"delay"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,86400),'isset({save})&&{type}!=2'),
-		"new_delay_flex"=>	array(T_ZBX_STR, O_OPT,  NOT_EMPTY,  "",'isset({add_delay_flex})&&{type}!=2'),
+		"itemid"=>	array(T_ZBX_INT, O_NO,	 P_SYS,	DB_ID,			'(isset({form})&&({form}=="update"))'),
+		"description"=>	array(T_ZBX_STR, O_OPT,  null,	NOT_EMPTY,	'isset({save})'),
+		"key"=>		array(T_ZBX_STR, O_OPT,  null,  NOT_EMPTY,		'isset({save})'),
+		"delay"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,86400),'isset({save})&&(isset({type})&&({type}!=2))'),
+		"new_delay_flex"=>	array(T_ZBX_STR, O_OPT,  NOT_EMPTY,  "",'isset({add_delay_flex})&&(isset({type})&&({type}!=2))'),
 		"rem_delay_flex"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,86400),null),
 		"delay_flex"=>	array(T_ZBX_STR, O_OPT,  null,  "",null),
 		"history"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,65535),'isset({save})'),
@@ -106,30 +106,30 @@ include_once "include/page_header.php";
 				IN(array(-1,ITEM_TYPE_ZABBIX,ITEM_TYPE_SNMPV1,ITEM_TYPE_TRAPPER,ITEM_TYPE_SIMPLE,
 					ITEM_TYPE_SNMPV2C,ITEM_TYPE_INTERNAL,ITEM_TYPE_SNMPV3,ITEM_TYPE_ZABBIX_ACTIVE,
 					ITEM_TYPE_AGGREGATE,ITEM_TYPE_HTTPTEST,ITEM_TYPE_EXTERNAL)),'isset({save})'),
-		"trends"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,65535),'isset({save})'),
-		"value_type"=>	array(T_ZBX_INT, O_OPT,  null,  IN("0,1,2,3,4"),'isset({save})'),
-		"valuemapid"=>	array(T_ZBX_INT, O_OPT,	 null,	DB_ID,'isset({save})'),
+		"trends"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,65535),		'isset({save})'),
+		"value_type"=>	array(T_ZBX_INT, O_OPT,  null,  IN("0,1,2,3,4"),	'isset({save})'),
+		"valuemapid"=>	array(T_ZBX_INT, O_OPT,	 null,	DB_ID,				'isset({save})'),
 
-		"snmp_community"=>array(T_ZBX_STR, O_OPT,  null,  NOT_EMPTY,'isset({save})&&'.IN("1,4","type")),
-		"snmp_oid"=>	array(T_ZBX_STR, O_OPT,  null,  NOT_EMPTY,'isset({save})&&'.IN("1,4,6","type")),
-		"snmp_port"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,65535),'isset({save})&&'.IN("1,4,6","type")),
+		"snmp_community"=>array(T_ZBX_STR, O_OPT,  null,  NOT_EMPTY,		'isset({save})&&isset({type})&&'.IN("1,4","type")),
+		"snmp_oid"=>	array(T_ZBX_STR, O_OPT,  null,  NOT_EMPTY,			'isset({save})&&isset({type})&&'.IN("1,4,6","type")),
+		"snmp_port"=>	array(T_ZBX_INT, O_OPT,  null,  BETWEEN(0,65535),	'isset({save})&&isset({type})&&'.IN("1,4,6","type")),
 
-		"snmpv3_securitylevel"=>array(T_ZBX_INT, O_OPT,  null,  IN("0,1,2"),'isset({save})&&{type}==6'),
-		"snmpv3_securityname"=>array(T_ZBX_STR, O_OPT,  null,  null,'isset({save})&&{type}==6'),
-		"snmpv3_authpassphrase"=>array(T_ZBX_STR, O_OPT,  null,  null,'isset({save})&&{type}==6'),
-		"snmpv3_privpassphrase"=>array(T_ZBX_STR, O_OPT,  null,  null,'isset({save})&&{type}==6'),
+		"snmpv3_securitylevel"=>array(T_ZBX_INT, O_OPT,  null,  IN("0,1,2"),	'isset({save})&&(isset({type})&&({type}==6))'),
+		"snmpv3_securityname"=>array(T_ZBX_STR, O_OPT,  null,  null,			'isset({save})&&(isset({type})&&({type}==6))'),
+		"snmpv3_authpassphrase"=>array(T_ZBX_STR, O_OPT,  null,  null,			'isset({save})&&(isset({type})&&({type}==6))'),
+		"snmpv3_privpassphrase"=>array(T_ZBX_STR, O_OPT,  null,  null,			'isset({save})&&(isset({type})&&({type}==6))'),
 
-		"trapper_hosts"=>array(T_ZBX_STR, O_OPT,  null,  null,'isset({save})&&{type}==2'),
-		"units"=>	array(T_ZBX_STR, O_OPT,  null,  null,'isset({save})&&'.IN("0,3","type")),
-		"multiplier"=>	array(T_ZBX_INT, O_OPT,  null,  IN("0,1"),'isset({save})&&'.IN("0,3","type")),
-		"delta"=>	array(T_ZBX_INT, O_OPT,  null,  IN("0,1,2"),'isset({save})&&'.IN("0,3","type")),
+		"trapper_hosts"=>array(T_ZBX_STR, O_OPT,  null,  null,		'isset({save})&&isset({type})&&({type}==2)'),
+		"units"=>	array(T_ZBX_STR, O_OPT,  null,  null,			'isset({save})&&isset({type})&&'.IN("0,3","type")),
+		"multiplier"=>	array(T_ZBX_INT, O_OPT,  null,  IN("0,1"),	'isset({save})&&isset({type})&&'.IN("0,3","type")),
+		"delta"=>	array(T_ZBX_INT, O_OPT,  null,  IN("0,1,2"),	'isset({save})&&isset({type})&&'.IN("0,3","type")),
 
-		"formula"=>	array(T_ZBX_DBL, O_OPT,  null,  null,'isset({save})&&{multiplier}==1'),
-		"logtimefmt"=>	array(T_ZBX_STR, O_OPT,  null,  null,'isset({save})&&{value_type}==2'),
+		"formula"=>	array(T_ZBX_DBL, O_OPT,  null,  null,			'isset({save})&&(isset({multiplier})&&({multiplier}==1))'),
+		"logtimefmt"=>	array(T_ZBX_STR, O_OPT,  null,  null,		'isset({save})&&(isset({value_type})&&({value_type}==2))'),
                  
 		"group_itemid"=>	array(T_ZBX_INT, O_OPT,	null,	DB_ID, null),
 		"copy_targetid"=>	array(T_ZBX_INT, O_OPT,	null,	DB_ID, null),
-		"filter_groupid"=>	array(T_ZBX_INT, O_OPT, P_SYS,	DB_ID, 'isset({copy})&&{copy_type}==0'),
+		"filter_groupid"=>	array(T_ZBX_INT, O_OPT, P_SYS,	DB_ID, 'isset({copy})&&(isset({copy_type})&&({copy_type}==0))'),
 		"applications"=>	array(T_ZBX_INT, O_OPT,	null,	DB_ID, null),
 
 		"showdisabled"=>	array(T_ZBX_INT, O_OPT,	P_SYS,	IN("0,1"),	null),
@@ -161,7 +161,7 @@ include_once "include/page_header.php";
 	
 	$accessible_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,null,null,get_current_nodeid());
 
-	if(isset($_REQUEST['hostid']) && !in_array($_REQUEST['hostid'], explode(',',$accessible_hosts)))
+	if(isset($_REQUEST['hostid']) && !uint_in_array($_REQUEST['hostid'], explode(',',$accessible_hosts)))
 	{
 		unset($_REQUEST['hostid']);
 	}
@@ -512,6 +512,7 @@ include_once "include/page_header.php";
 <?php
 
 	$form = new CForm();
+	$form->SetMethod('get');
 	$form->SetName('hdrform');
 
 	$form->AddVar("hostid",$_REQUEST["hostid"]);
@@ -529,11 +530,12 @@ include_once "include/page_header.php";
 	{
 		echo BR;
 		insert_copy_elements_to_forms("group_itemid");
-	} elseif (!isset($_REQUEST["form"]) ||  !in_array($_REQUEST["form"],array(S_CREATE_ITEM,"update","clone"))) {
+	} elseif (!isset($_REQUEST["form"]) ||  !str_in_array($_REQUEST["form"],array(S_CREATE_ITEM,"update","clone"))) {
 		echo BR;
 // Table HEADER
 		$form = new CForm();
-
+		$form->SetMethod('get');
+		
 		$where_case = array();
 		$from_tables['h'] = 'hosts h';
 		$where_case[] = 'i.hostid=h.hostid';
@@ -699,7 +701,7 @@ include_once "include/page_header.php";
 				$cmbHosts->AddItem($row["hostid"],$row["host"]);
 
 				if($_REQUEST["hostid"]!=0){
-					if($_REQUEST["hostid"]==$row["hostid"])
+					if(bccomp($_REQUEST["hostid"], $row["hostid"]) == 0)
 						$correct_hostid = 'ok';
 				}
 				if($first_hostid <= 0)
@@ -730,7 +732,6 @@ include_once "include/page_header.php";
 // TABLE
 		$form = new CForm();
 		$form->SetName('items');
-		$form->SetMethod('POST');
 
 		$table  = new CTableInfo();
 		$table->SetHeader(array(
@@ -747,8 +748,10 @@ include_once "include/page_header.php";
 
 		$db_items = DBselect('select distinct th.host as template_host,th.hostid as template_hostid, h.host, i.* '.
 			' from '.implode(',', $from_tables).
-			' left join items ti on i.templateid=ti.itemid left join hosts th on ti.hostid=th.hostid '.
-			' where '.implode(' and ', $where_case).' order by h.host,i.description,i.key_,i.itemid');
+				' left join items ti on i.templateid=ti.itemid '.
+				' left join hosts th on ti.hostid=th.hostid '.
+			' where '.implode(' and ', $where_case).
+			' order by h.host,i.description,i.key_,i.itemid');
 		while($db_item = DBfetch($db_items))
 		{
 			$description = array();
@@ -778,9 +781,9 @@ include_once "include/page_header.php";
 					"&group_task=".($db_item["status"] ? "Activate+selected" : "Disable+selected"),
 					item_status2style($db_item["status"])));
 	
-			if($db_item["error"] == "")
+			if($db_item["error"] == '')
 			{
-				$error=new CCol(SPACE,"off");
+				$error=new CCol('-',"off");
 			}
 			else
 			{
@@ -788,7 +791,7 @@ include_once "include/page_header.php";
 			}
 
 			$applications = $show_applications ? implode(', ', get_applications_by_itemid($db_item["itemid"], 'name')) : null;
-
+			
 			$chkBox = new CCheckBox("group_itemid[]",null,null,$db_item["itemid"]);
 			//if($db_item["templateid"] > 0) $chkBox->SetEnabled(false);
 			$table->AddRow(array(
@@ -800,7 +803,7 @@ include_once "include/page_header.php";
 				$db_item["trends"],
 				item_type2str($db_item['type']),
 				$status,
-				$applications,
+				('' == $applications)?'-':$applications,
 				$error
 				));
 		}
@@ -825,7 +828,7 @@ include_once "include/page_header.php";
 
 	}
 
-	if(isset($_REQUEST["form"]) && (in_array($_REQUEST["form"],array(S_CREATE_ITEM,"update","clone")) ||
+	if(isset($_REQUEST["form"]) && (str_in_array($_REQUEST["form"],array(S_CREATE_ITEM,"update","clone")) ||
 		($_REQUEST["form"]=="mass_update" && isset($_REQUEST['group_itemid']))))
 	{
 // FORM
