@@ -19,30 +19,43 @@
 **/
 ?>
 <?php
-	include "include/config.inc.php";
-	include_once "include/locales/en_gb.inc.php";
+	require_once "include/config.inc.php";
+	require_once "include/maps.inc.php";
 
-	process_locales();
+	$page["title"] = "S_MAP";
+	$page["file"] = "map.php";
+	$page["type"] = PAGE_TYPE_IMAGE;
 
-#	PARAMETERS:
+include_once "include/page_header.php";
 
-#	sysmapid
-#	noedit
+?>
+<?php
+//		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
+	$fields=array(
+		"sysmapid"=>	array(T_ZBX_INT, O_MAND,P_SYS,	DB_ID,		NULL),
+		"noedit"=>	array(T_ZBX_INT, O_OPT,	NULL,	IN('0,1'),	NULL),
+		"border"=>	array(T_ZBX_INT, O_OPT,	NULL,	IN("0,1"),	NULL)
+	);
 
-	$grid=50;
-
-	$map	= get_sysmap_by_sysmapid($_REQUEST["sysmapid"]);
+	check_fields($fields);
+?>
+<?php
+	if(!sysmap_accessiable($_REQUEST["sysmapid"],PERM_READ_ONLY))
+	{
+		access_deny();
+	}
+	
+	if(!($map = get_sysmap_by_sysmapid($_REQUEST["sysmapid"])))
+	{
+		include_once "include/page_footer.php";
+	}
 
 	$name		= $map["name"];
 	$width		= $map["width"];
 	$height		= $map["height"];
-	$background	= $map["background"];
+	$backgroundid	= $map["backgroundid"];
 	$label_type	= $map["label_type"];
 
-	set_image_header();
-
-	check_authorisation();
-
 	if(function_exists("imagecreatetruecolor")&&@imagecreatetruecolor(1,1))
 	{
 		$im = imagecreatetruecolor($width,$height);
@@ -81,41 +94,26 @@
 	$y=imagesy($im);
   
 	ImageFilledRectangle($im,0,0,$width,$height,$white);
-	if($background!="")
+
+	if(($db_image = get_image_by_imageid($backgroundid)))
 	{
-		$db_image = get_image_by_name($background, 2);
-		if($db_image)
-		{
-			$back = ImageCreateFromString($db_image["image"]);
-			ImageCopy($im,$back,0,0,0,0,imagesx($back),imagesy($back));
-		}
-		else
-		{
-			$x=imagesx($im)/2-ImageFontWidth(4)*strlen($name)/2;
-			ImageString($im, 4,$x,1, $name , $darkred);
-		}
+		$back = ImageCreateFromString($db_image["image"]);
+		ImageCopy($im,$back,0,0,0,0,imagesx($back),imagesy($back));
 	}
 	else
 	{
 		$x=imagesx($im)/2-ImageFontWidth(4)*strlen($name)/2;
-		ImageString($im, 4,$x,1, $name , $colors["Dark Red"]);
+		ImageString($im, 4,$x,1, $name , $darkred);
 	}
-
-//	$x=imagesx($im)/2-ImageFontWidth(4)*strlen($name)/2;
-//	ImageString($im, 4,$x,1, $name , $colors["Dark Red"]);
+	unset($db_image);
 
 	$str=date("m.d.Y H:i:s",time(NULL));
 	ImageString($im, 0,imagesx($im)-120,imagesy($im)-12,"$str", $gray);
 
-	if(!check_right("Network map","R",$_REQUEST["sysmapid"]))
-	{
-		ImageOut($im); 
-		ImageDestroy($im); 
-		exit();
-	}
-
 	if(!isset($_REQUEST["noedit"]))
 	{
+		$grid = 50;
+
 		for($x=$grid;$x<$width;$x+=$grid)
 		{
 			MyDrawLine($im,$x,0,$x,$height,$black,GRAPH_DRAW_TYPE_DASHEDLINE);
@@ -144,7 +142,8 @@
 		if(!is_null($link["triggerid"]))
 		{
 			$trigger=get_trigger_by_triggerid($link["triggerid"]);
-			if($trigger["value"] == TRIGGER_VALUE_TRUE)
+//			if($trigger["value"] == TRIGGER_VALUE_TRUE)
+			if($trigger["status"] == TRIGGER_STATUS_ENABLED && $trigger["value"] == TRIGGER_VALUE_TRUE)
 			{
 				$drawtype = $link["drawtype_on"];
 				$color = $colors[$link["color_on"]];
@@ -159,10 +158,10 @@
 
 	while($db_element = DBfetch($db_elements))
 	{
-		$img = get_png_by_selementid($db_element["selementid"]);
-
-		if($img)
+		if( ($img = get_png_by_selementid($db_element["selementid"])) )
+		{
 			ImageCopy($im,$img,$db_element["x"],$db_element["y"],0,0,ImageSX($img),ImageSY($img));
+		}
 
 		if($label_type==MAP_LABEL_TYPE_NOTHING)	continue;
 
@@ -174,45 +173,32 @@
 
 		$label_line = $db_element["label"];
 
+		$el_info = get_info_by_selementid($db_element["selementid"]);
+
+		$info_line	= $el_info['info'];
+		$color		= $el_info['color'];
+
 		if($label_type==MAP_LABEL_TYPE_STATUS)
+		{
 			$label_line = "";
+		}
+		else if($label_type==MAP_LABEL_TYPE_NAME)
+		{
+			$label_line = $el_info['name'];
+		}
+
+		unset($el_info);
 
 		if($db_element["elementtype"] == SYSMAP_ELEMENT_TYPE_HOST)
 		{
 			$host = get_host_by_hostid($db_element["elementid"]);
-
-			if($label_type==MAP_LABEL_TYPE_NAME)
-			{
-				$label_line=$host["host"];
-			}
-			else if($label_type==MAP_LABEL_TYPE_IP)
-			{
+			
+			if( $label_type==MAP_LABEL_TYPE_IP )
 				$label_line=$host["ip"];
-			}
 
-			if($host["status"] == HOST_STATUS_NOT_MONITORED)
-			{
+			if( $host["status"] == HOST_STATUS_NOT_MONITORED )
 				$label_color=$darkred;
-			}
 		}
-		elseif($db_element["elementtype"] == SYSMAP_ELEMENT_TYPE_MAP)
-		{
-			$map = get_sysmap_by_sysmapid($db_element["elementid"]);
-			if($label_type==MAP_LABEL_TYPE_NAME)
-			{
-				$label_line=$map["name"];
-			}
-
-		}
-		elseif($db_element["elementtype"] == SYSMAP_ELEMENT_TYPE_IMAGE && $db_element["elementid"]>0)
-		{
-			if($label_type==MAP_LABEL_TYPE_NAME)
-			{
-				$label_line = expand_trigger_description_simple($db_element["elementid"]);
-			}
-		}
-
-		get_info_by_selementid($db_element["selementid"],$info_line, $color);
 
 		if($label_line=="" && $info_line=="")	continue;
 
@@ -282,9 +268,12 @@
 		ImageRectangle($im,0,0,$width-1,$height-1,$colors["Black"]);
 	}
 
-	
-	if(MAP_OUTPUT_FORMAT == "JPG")	ImageJPEG($im);
-	else				ImageOut($im); #default
+	ImageOut($im);
 
 	ImageDestroy($im);
 ?>
+<?php
+
+include_once "include/page_footer.php";
+
+?>
