@@ -35,26 +35,26 @@ include_once "include/page_header.php";
 
 // media form
 		"mediatypeid"=>		array(T_ZBX_INT, O_NO,	P_SYS,	DB_ID,
-						'{form}=="update"'),
+						'(isset({form})&&({form}=="update"))'),
 		"type"=>		array(T_ZBX_INT, O_OPT,	NULL,	IN(implode(',',
 						array(ALERT_TYPE_EMAIL,ALERT_TYPE_EXEC,ALERT_TYPE_SMS,ALERT_TYPE_JABBER))),
 						'(isset({save}))'),
 		"description"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,
 						'(isset({save}))'),
 		"smtp_server"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,
-						'({type}=='.ALERT_TYPE_EMAIL.')&&isset({save})'),
+						'isset({type})&&({type}=='.ALERT_TYPE_EMAIL.')&&isset({save})'),
 		"smtp_helo"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,
-						'({type}=='.ALERT_TYPE_EMAIL.')&&isset({save})'),
+						'isset({type})&&({type}=='.ALERT_TYPE_EMAIL.')&&isset({save})'),
 		"smtp_email"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,
-						'({type}=='.ALERT_TYPE_EMAIL.')&&isset({save})'),
+						'isset({type})&&({type}=='.ALERT_TYPE_EMAIL.')&&isset({save})'),
 		"exec_path"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,
-						'({type}=='.ALERT_TYPE_EXEC.')&&isset({save})'),
+						'isset({type})&&({type}=='.ALERT_TYPE_EXEC.')&&isset({save})'),
 		"gsm_modem"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,
-						'({type}=='.ALERT_TYPE_SMS.')&&isset({save})'),
+						'isset({type})&&({type}=='.ALERT_TYPE_SMS.')&&isset({save})'),
 		"username"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,
-						'({type}=='.ALERT_TYPE_JABBER.')&&isset({save})'),
+						'(isset({type})&&{type}=='.ALERT_TYPE_JABBER.')&&isset({save})'),
 		"password"=>		array(T_ZBX_STR, O_OPT,	NULL,	NOT_EMPTY,
-						'({type}=='.ALERT_TYPE_JABBER.')&&isset({save})'),
+						'isset({type})&&({type}=='.ALERT_TYPE_JABBER.')&&isset({save})'),
 /* actions */
 		"save"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
 		"delete"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
@@ -119,6 +119,8 @@ include_once "include/page_header.php";
 <?php
 
 	$form = new CForm();
+	$form->SetMethod('get');
+	
 	$form->AddItem(new CButton("form",S_CREATE_MEDIA_TYPE));
 	show_table_header(S_CONFIGURATION_OF_MEDIA_TYPES_BIG, $form);
 ?>
