@@ -40,6 +40,7 @@ include_once "include/page_header.php";
 	$_REQUEST["period"] = get_request("period", "day");
 
 	$form = new CForm();
+	$form->SetMethod('get');
 	
 	$cmbPeriod = new CComboBox("period",$_REQUEST["period"],"submit()");
 	$cmbPeriod->AddItem("day",S_DAY);
@@ -71,26 +72,31 @@ include_once "include/page_header.php";
 	}
 
 	$accessible_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY);
-	
-        $result=DBselect("select h.host, t.triggerid, t.description, t.priority, count(distinct e.eventid) as count ".
-		" from hosts h, triggers t, functions f, items i, events e where ".
-		" h.hostid = i.hostid and i.itemid = f.itemid and t.triggerid=f.triggerid and ".
-		' t.triggerid=e.objectid and e.object='.EVENT_OBJECT_TRIGGER.' and e.clock>'.(time()-$time_dif).
-		' and h.hostid in ('.$accessible_hosts.') and '.DBin_node('t.triggerid').
-		" group by h.host,t.triggerid,t.description,t.priority ".
-		" order by count desc, h.host, t.description, t.triggerid", 100);
 
-        while($row=DBfetch($result))
-        {
-		if(!check_right_on_trigger_by_triggerid(null, $row['triggerid'], $accessible_hosts))
-			continue;
+		$sql = "select h.host, t.triggerid, t.description, t.priority, t.expression, count(distinct e.eventid) as cnt_event ".
+			' FROM hosts h, triggers t, functions f, items i, events e '.
+			' WHERE h.hostid = i.hostid '.
+				' and i.itemid = f.itemid '.
+				' and t.triggerid=f.triggerid '.
+				' and t.triggerid=e.objectid '.
+				' and e.object='.EVENT_OBJECT_TRIGGER.
+				' and e.clock>'.(time()-$time_dif).
+				' and h.hostid in ('.$accessible_hosts.') '.
+				' and '.DBin_node('t.triggerid').
+			" group by h.host,t.triggerid,t.description,t.expression,t.priority ".
+			" order by cnt_event desc, h.host, t.description, t.triggerid";
+        $result=DBselect($sql, 100);
 
-            	$table->addRow(array(
-			get_node_name_by_elid($row['triggerid']),
-			$row["host"],
-			expand_trigger_description_by_data($row),
-			new CCol(get_severity_description($row["priority"]),get_severity_style($row["priority"])),
-			$row["count"],
+        while($row=DBfetch($result)){
+			if(!check_right_on_trigger_by_triggerid(null, $row['triggerid'], $accessible_hosts))
+				continue;
+
+           	$table->addRow(array(
+				get_node_name_by_elid($row['triggerid']),
+				$row["host"],
+				expand_trigger_description_by_data($row),
+				new CCol(get_severity_description($row["priority"]),get_severity_style($row["priority"])),
+				$row["cnt_event"],
 			));
 	}
 	$table->show();
