@@ -92,6 +92,8 @@ include_once "include/page_header.php";
 	if($elementid <= 0) $elementid = null;
 
 	$form = new CForm();
+	$form->SetMethod('get');
+	
 	$form->AddVar("fullscreen",$_REQUEST["fullscreen"]);
 
 	$cmbConfig = new CComboBox('config', $config, 'submit()');
@@ -120,7 +122,7 @@ include_once "include/page_header.php";
 					$row['elementid'],
 					get_node_name_by_elid($row['elementid']).$row["name"]
 					);
-			if($elementid == $row["elementid"]) $element_correct = 1;
+			if((bccomp($elementid , $row["elementid"]) == 0)) $element_correct = 1;
 			if(!isset($first_element)) $first_element = $row["elementid"];
 		}
 	}
@@ -140,7 +142,7 @@ include_once "include/page_header.php";
 					$row['elementid'],
 					get_node_name_by_elid($row['elementid']).$row['name']
 					);
-			if($elementid == $row["elementid"]) $element_correct = 1;
+			if((bccomp($elementid , $row["elementid"]) == 0)) $element_correct = 1;
 			if(!isset($first_element)) $first_element = $row["elementid"];
 		}
 	}
@@ -194,6 +196,9 @@ include_once "include/page_header.php";
 		else
 		{
 			$element = get_slideshow($elementid, get_request('step', null), $effectiveperiod);
+			zbx_add_post_js('if(isset(parent)) parent.resizeiframe("iframe");
+							else resizeiframe("iframe");
+							');
 		}
 		if($element) $element->Show();
 		
