@@ -155,7 +155,7 @@ if(isset($_REQUEST['saction'])){
 		show_messages($result, S_TRIGGER_ADDED, S_CANNOT_ADD_TRIGGER);
 	}
 	if($result){
-		closeform();
+		zbx_add_post_js('closeform("services.php");');
 		include_once "include/page_footer.php";
 	}
 }
@@ -207,7 +207,8 @@ if(isset($_REQUEST['pservices'])){
 					' LEFT JOIN services_links sl ON s.serviceid=sl.servicedownid '.
 				' WHERE (i.hostid IS null OR i.hostid NOT IN ('.$denyed_hosts.')) '.
 					' AND '.DBin_node('s.serviceid').
-					' AND s.serviceid NOT IN ('.$childs_str.$service['serviceid'].') order by s.sortorder,s.name';
+					' AND s.serviceid NOT IN ('.$childs_str.$service['serviceid'].') '.
+				' ORDER BY s.sortorder,s.name';
 	} else {
 		$query = 'SELECT DISTINCT s.* '.
 			' FROM services s '.
@@ -284,8 +285,8 @@ if(isset($_REQUEST['cservices'])){
 					' LEFT JOIN items i on f.itemid=i.itemid '.
 					' LEFT JOIN services_links sl on s.serviceid=sl.servicedownid '.
 				' WHERE (i.hostid is null or i.hostid not in ('.$denyed_hosts.')) '.
-				' AND '.DBin_node('s.serviceid').
-				' AND s.serviceid NOT IN ('.$childs_str.$service['serviceid'].') '.
+					' AND '.DBin_node('s.serviceid').
+					' AND s.serviceid NOT IN ('.$childs_str.$service['serviceid'].') '.
 				' ORDER BY s.sortorder,s.name';
 		
 	} else {
@@ -296,7 +297,7 @@ if(isset($_REQUEST['cservices'])){
 					' LEFT JOIN items i on f.itemid=i.itemid '.
 					' LEFT JOIN services_links sl on s.serviceid=sl.servicedownid '.
 				' WHERE (i.hostid is null or i.hostid not in ('.$denyed_hosts.')) '.
-				' AND '.DBin_node('s.serviceid').
+					' AND '.DBin_node('s.serviceid').
 				' ORDER BY s.sortorder,s.name';
 	}
 	
@@ -361,7 +362,7 @@ if(isset($_REQUEST['sform'])){
 		while($new_service_time['to'] && ($new_service_time['to'] <= $new_service_time['from'])) $new_service_time['to'] += 7*24*3600;
 
 
-		if($new_service_time['to'] && !in_array($_REQUEST['service_times'], $new_service_time))
+		if($new_service_time['to'] && !str_in_array($_REQUEST['service_times'], $new_service_time))
 			array_push($_REQUEST['service_times'],$new_service_time);
 	} elseif(isset($_REQUEST["del_service_times"]) && isset($_REQUEST["rem_service_times"])){
 		$_REQUEST["service_times"] = get_request("service_times",array());
@@ -396,20 +397,20 @@ if(isset($_REQUEST['sform'])){
 				'to'=>		$db_stime['ts_to'],
 				'note'=>	$db_stime['note']
 				);
-			if(in_array($stime, $service_times)){
+			if(str_in_array($stime, $service_times)){
 				continue;
 			}
 			array_push($service_times, $stime);
 		}
 //links
-		$query = 'SELECT DISTINCT 
-					sl.linkid, sl.soft, sl.serviceupid, sl.servicedownid, 
-					s1.name as serviceupname, s2.name as servicedownname 
-				FROM services s1, services s2, services_links sl 
-				WHERE sl.serviceupid=s1.serviceid 
-					AND sl.servicedownid=s2.serviceid 
-					AND NOT(sl.soft=1)
-					AND sl.servicedownid='.$service['serviceid'];
+		$query = 'SELECT DISTINCT '.
+					' sl.linkid, sl.soft, sl.serviceupid, sl.servicedownid, '.
+					' s1.name as serviceupname, s2.name as servicedownname '.
+				' FROM services s1, services s2, services_links sl '.
+				' WHERE sl.serviceupid=s1.serviceid '.
+					' AND sl.servicedownid=s2.serviceid '.
+					' AND NOT(sl.soft=1) '.
+					' AND sl.servicedownid='.$service['serviceid'];
 
 		if($link=DBFetch(DBSelect($query))){
 			$parentid = $link["serviceupid"];
@@ -441,7 +442,7 @@ if(isset($_REQUEST['sform'])){
 				'triggerid' => $db_service_data["triggerid"],
 				'soft' => $db_service_data['soft']
 			);
-			if(in_array($child,	$childs)){
+			if(str_in_array($child,	$childs)){
 				continue;
 			}
 			array_push($childs,$child);
@@ -480,7 +481,7 @@ if(isset($_REQUEST['sform'])){
 
 	$cb = new CButton('select_parent',S_CHANGE);
 	$cb->SetType('button');
-	$cb->SetAction("javascript: openWinCentered('services_form.php?pservices=1".url_param('serviceid')."','ZBX_Services_List',720,420,'toolbar=0, menubar=0, resizable=0');");
+	$cb->SetAction("javascript: openWinCentered('services_form.php?pservices=1".url_param('serviceid')."','ZBX_Services_List',740,420,'scrollbars=1, toolbar=0, menubar=0, resizable=1, dialog=0');");
 
 	$frmService->AddRow('Parent Service',array($ctb,$cb));
 //----------							
@@ -534,7 +535,7 @@ if(isset($_REQUEST['sform'])){
 
 	$cb = new CButton('add_child_service',S_ADD);
 	$cb->SetType('button');
-	$cb->SetAction("javascript: openWinCentered('services_form.php?cservices=1".url_param('serviceid')."','ZBX_Services_List',620,520,'toolbar=0, menubar=0, resizable=0');");
+	$cb->SetAction("javascript: openWinCentered('services_form.php?cservices=1".url_param('serviceid')."','ZBX_Services_List',640,520,'scrollbars=1, toolbar=0, menubar=0, resizable=0');");
 	
 	$cb2 = new CButton('del_child_service',S_REMOVE);
 	$cb2->SetType('button');
