@@ -71,7 +71,7 @@ include_once "include/page_header.php";
 	} else {
 	
 		$query = 'SELECT DISTINCT s.serviceid, sl.servicedownid, sl_p.serviceupid as serviceupid, s.triggerid, '.
-				' s.name as caption, s.algorithm, t.description, s.sortorder, sl.linkid, s.showsla, s.goodsla, s.status '.
+				' s.name as caption, s.algorithm, t.description, t.expression, s.sortorder, sl.linkid, s.showsla, s.goodsla, s.status '.
 			' FROM services s '.
 				' LEFT JOIN triggers t ON s.triggerid = t.triggerid '.
 				' LEFT JOIN services_links sl ON  s.serviceid = sl.serviceupid and NOT(sl.soft=0) '.
@@ -88,7 +88,7 @@ include_once "include/page_header.php";
 		$row = array(
 						'0' => 0,'serviceid' => 0,
 						'1' => 0,'serviceupid' => 0,
-						'2' => '','caption' => 'root',
+						'2' => '','caption' => S_ROOT_SMALL,
 						'3' => '','status' => SPACE,
 						'4' => '','reason' => SPACE,
 						'5' => '','sla' => SPACE,
@@ -113,7 +113,7 @@ include_once "include/page_header.php";
 
 			}
 			
-			if($row["status"]==0 || (isset($service) && $service["serviceid"] == $row["serviceid"])){
+			if($row["status"]==0 || (isset($service) && (bccomp($service["serviceid"] , $row["serviceid"]) == 0))){
 				$row['reason']="-";
 			} else {
 				$row['reason'] = new CList(null,"itservices");
