@@ -43,7 +43,6 @@ include_once "include/page_header.php";
 	
 	check_fields($fields);
 	
-//	$show_unknown = get_profile('web.events.show_unknown',0);
 	$show_unknown = get_request('show_unknown',get_profile('web.events.show_unknown',0));
 	update_profile('web.events.show_unknown',$show_unknown);
 		
@@ -136,8 +135,12 @@ include_once "include/page_header.php";
 			$dissum=$dissum+$leng;
 			$sum=$dissum;
 		}
-	
-		$proc=(100*$sum)/($falsesum+$truesum+$dissum);
+
+		$total = $falsesum + $truesum + $dissum;
+		if ($total == 0)
+			$proc = 0;
+		else
+			$proc = (100*$sum)/$total;
 		$proc=round($proc*100)/100;
 		$proc="$proc%";
  
