@@ -41,16 +41,16 @@ include_once "include/page_header.php";
 		"config"=>	array(T_ZBX_INT, O_OPT,	null,	IN("0,1"),	null),
 		"perm_details"=>array(T_ZBX_INT, O_OPT,	null,	IN("0,1"),	null),
 /* user */
-		"userid"=>	array(T_ZBX_INT, O_NO,	P_SYS,	DB_ID,'{config}==0&&{form}=="update"'),
+		"userid"=>	array(T_ZBX_INT, O_NO,	P_SYS,	DB_ID,'(isset({config})&&({config}==0))&&(isset({form})&&({form}=="update"))'),
 		"group_userid"=>array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,		null),
 
-		"alias"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'{config}==0&&isset({save})'),
-		"name"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'{config}==0&&isset({save})'),
-		"surname"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'{config}==0&&isset({save})'),
-		"password1"=>	array(T_ZBX_STR, O_OPT,	null,	null,		'{config}==0&&isset({save})&&{form}!="update"&&isset({change_password})'),
-		"password2"=>	array(T_ZBX_STR, O_OPT,	null,	null,		'{config}==0&&isset({save})&&{form}!="update"&&isset({change_password})'),
-		"user_type"=>	array(T_ZBX_INT, O_OPT,	null,	IN('1,2,3'),	'{config}==0&&isset({save})'),
-		"user_groups"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'{config}==0&&isset({save})'),
+		"alias"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'(isset({config})&&({config}==0))&&isset({save})'),
+		"name"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'(isset({config})&&({config}==0))&&isset({save})'),
+		"surname"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'(isset({config})&&({config}==0))&&isset({save})'),
+		"password1"=>	array(T_ZBX_STR, O_OPT,	null,	null,		'(isset({config})&&({config}==0))&&isset({save})&&(isset({form})&&({form}!="update"))&&isset({change_password})'),
+		"password2"=>	array(T_ZBX_STR, O_OPT,	null,	null,		'(isset({config})&&({config}==0))&&isset({save})&&(isset({form})&&({form}!="update"))&&isset({change_password})'),
+		"user_type"=>	array(T_ZBX_INT, O_OPT,	null,	IN('1,2,3'),	'(isset({config})&&({config}==0))&&isset({save})'),
+		"user_groups"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'(isset({config})&&({config}==0))&&isset({save})'),
 		"user_groups_to_del"=>	array(T_ZBX_INT, O_OPT,	null,	DB_ID,	null),
 		"user_medias"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	null),
 		"user_medias_to_del"=>	array(T_ZBX_STR, O_OPT,	null,	DB_ID,	null),
@@ -58,24 +58,24 @@ include_once "include/page_header.php";
 		"new_media"=>	array(T_ZBX_STR, O_OPT,	null,	null,	null),
 		"enable_media"=>array(T_ZBX_INT, O_OPT,	null,	null,		null),
 		"disable_media"=>array(T_ZBX_INT, O_OPT,null,	null,		null),
-		"lang"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'{config}==0&&isset({save})'),
-		"autologout"=>	array(T_ZBX_INT, O_OPT,	null,	BETWEEN(0,3600),'{config}==0&&isset({save})'),
-		"url"=>		array(T_ZBX_STR, O_OPT,	null,	null,		'{config}==0&&isset({save})'),
-		"refresh"=>	array(T_ZBX_INT, O_OPT,	null,	BETWEEN(0,3600),'{config}==0&&isset({save})'),
+		"lang"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'(isset({config})&&({config}==0))&&isset({save})'),
+		"autologout"=>	array(T_ZBX_INT, O_OPT,	null,	BETWEEN(0,3600),'(isset({config})&&({config}==0))&&isset({save})'),
+		"url"=>		array(T_ZBX_STR, O_OPT,	null,	null,		'(isset({config})&&({config}==0))&&isset({save})'),
+		"refresh"=>	array(T_ZBX_INT, O_OPT,	null,	BETWEEN(0,3600),'(isset({config})&&({config}==0))&&isset({save})'),
 
 		"right"=>	array(T_ZBX_STR, O_NO,	null,	NOT_EMPTY,
-					'{register}=="add permission"&&isset({userid})'),
+					'(isset({register})&&({register}=="add permission"))&&isset({userid})'),
 		"permission"=>	array(T_ZBX_STR, O_NO,	null,	NOT_EMPTY,
-					'{register}=="add permission"&&isset({userid})'),
+					'(isset({register})&&({register}=="add permission"))&&isset({userid})'),
 		"id"=>		array(T_ZBX_INT, O_NO,	null,	DB_ID,
-					'{register}=="add permission"&&isset({userid})'),
+					'(isset({register})&&({register}=="add permission"))&&isset({userid})'),
 		"rightid"=>	array(T_ZBX_INT, O_NO,  null,   DB_ID,
-                                        '{register}=="delete permission"&&isset({userid})'),
+                                        '(isset({register})&&({register}=="delete permission"))&&isset({userid})'),
 /* group */
-		"usrgrpid"=>	array(T_ZBX_INT, O_NO,	P_SYS,	DB_ID,'{config}==1&&{form}=="update"'),
+		"usrgrpid"=>	array(T_ZBX_INT, O_NO,	P_SYS,	DB_ID,'(isset({config})&&({config}==1))&&(isset({form})&&({form}=="update"))'),
 		"group_groupid"=>array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,		null),
 
-		"gname"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'{config}==1&&isset({save})'),
+		"gname"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'(isset({config})&&({config}==1))&&isset({save})'),
 		"users"=>	array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,	null),
 		"new_right"=>	array(T_ZBX_STR, O_OPT,	null,	null,	null),
 		"new_user"=>	array(T_ZBX_STR, O_OPT,	null,	null,	null),
@@ -349,7 +349,8 @@ include_once "include/page_header.php";
 ?>
 <?php
 	$frmForm = new CForm();
-
+	$frmForm->SetMethod('get');
+	
 	$cmbConf = new CComboBox("config",$_REQUEST["config"],"submit()");
 	$cmbConf->AddItem(0,S_USERS);
 	$cmbConf->AddItem(1,S_USER_GROUPS);
