@@ -121,11 +121,17 @@
 #define OFF	0
 
 #define	APPLICATION_NAME	"ZABBIX Agent"
-#define	ZABBIX_REVDATE		"20 August 2007"
-#define	ZABBIX_VERSION		"1.4.2"
+#define	ZABBIX_REVDATE		"23 July 2008"
+#define	ZABBIX_VERSION		"1.4.6"
+
+#if defined(_WINDOWS)
+extern char ZABBIX_SERVICE_NAME[64];
+extern char ZABBIX_EVENT_SOURCE[64];
+#endif /* _WINDOWS */
 
 #if defined(_WINDOWS)
 /*#	pragma warning (disable: 4100)*/
+#	pragma warning (disable: 4996) /* warning C4996: <function> was declared deprecated */
 #endif /* _WINDOWS */
 
 #ifndef HAVE_GETOPT_LONG
@@ -457,7 +463,7 @@ typedef enum
 #define	AGENT_TIMEOUT	3
 
 #define	SENDER_TIMEOUT		5
-#define	TRAPPER_TIMEOUT		5
+#define	ZABBIX_TRAPPER_TIMEOUT	300
 #define	SNMPTRAPPER_TIMEOUT	5
 
 #ifndef MAX
@@ -517,6 +523,16 @@ typedef enum
 	ZBX_TASK_CHANGE_NODEID
 } zbx_task_t;
 
+#define ZBX_TASK_FLAG_MULTIPLE_AGENTS 0x01
+
+#define ZBX_TASK_EX struct zbx_task_ex
+ZBX_TASK_EX
+{
+	zbx_task_t	task;
+	int		flags;
+};
+
+
 char *string_replace(char *str, char *sub_str1, char *sub_str2);
 
 void	del_zeroes(char *s);
@@ -535,6 +551,14 @@ int	get_param(const char *param, int num, char *buf, int maxlen);
 int	num_param(const char *param);
 int	calculate_item_nextcheck(zbx_uint64_t itemid, int item_type, int delay, char *delay_flex, time_t now);
 int	check_time_period(const char *period, time_t now);
+void	zbx_binary2hex(const u_char *input, int ilen, char **output, int *olen);
+int     zbx_hex2binary(char *io);
+void	zbx_hex2octal(const char *input, char **output, int *olen);
+#ifdef HAVE_POSTGRESQL
+void	zbx_pg_escape_bytea(const u_char *input, int ilen, char **output, int *olen);
+int	zbx_pg_unescape_bytea(u_char *io);
+#endif
+char    *zbx_get_next_field(const char *line, char **output, int *olen, char separator);
 
 #ifdef HAVE___VA_ARGS__
 #	define zbx_setproctitle(fmt, ...) __zbx_zbx_setproctitle(ZBX_CONST_STRING(fmt), ##__VA_ARGS__)
@@ -627,7 +651,9 @@ int	get_nodeid_by_id(zbx_uint64_t id);
 int	int_in_list(char *list, int value);
 int	uint64_in_list(char *list, zbx_uint64_t value);
 int	ip_in_list(char *list, char *ip);
-
+#ifdef HAVE_IPV6
+int	expand_ipv6(const char *ip, char *str, size_t str_len );
+#endif /* HAVE_IPV6 */
 int MAIN_ZABBIX_ENTRY(void);
 
 zbx_uint64_t	zbx_letoh_uint64(
