@@ -504,7 +504,7 @@ static	ZBX_TABLE	tables[]={
 		{"imageid",	ZBX_TYPE_ID,	ZBX_SYNC},
 		{"imagetype",	ZBX_TYPE_INT,	ZBX_SYNC},
 		{"name",	ZBX_TYPE_CHAR,	ZBX_SYNC},
-		{"image",	ZBX_TYPE_BLOB,	0},
+		{"image",	ZBX_TYPE_BLOB,	ZBX_SYNC},
 		{0}
 		}
 	},
