@@ -112,29 +112,61 @@ static void __zbx_zbx_set_tcp_strerror(const char *fmt, ...)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: hostent or NULL - an error occured                           *
+ * Return value:                                                              *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-struct hostent	*zbx_gethost_by_ip(const char *ip)
+
+#if defined(HAVE_IPV6)
+void	zbx_gethost_by_ip(const char *ip, char *host, size_t hostlen)
+{
+	struct	addrinfo hints, *ai = NULL;
+	
+	assert(ip);
+
+	memset(&hints, 0, sizeof(hints));
+	hints.ai_family = PF_UNSPEC;
+	if(0 != getaddrinfo(ip, NULL, &hints, &ai))
+	{
+		host[0] = '\0';
+		goto out;
+	}
+	if(0 != getnameinfo(ai->ai_addr, ai->ai_addrlen, host, hostlen, NULL, 0, NI_NAMEREQD))
+	{
+		host[0] = '\0';
+		goto out;
+	}
+out:
+	if (NULL != ai)
+		freeaddrinfo(ai);
+}
+#else
+void	zbx_gethost_by_ip(const char *ip, char *host, size_t hostlen)
 {
 	struct in_addr	addr;
-	struct hostent*	host;
+	struct hostent  *hst;
 
 	assert(ip);
 
-	if(inet_aton(ip, &addr) != 0)
+	if(inet_aton(ip, &addr) == 0)
 	{
-		host = gethostbyaddr((char *)&addr, sizeof(addr), AF_INET);
-		if(host)	return host;
+		host[0] = '\0';
+		return;
 	}
 
-	return (struct hostent*) NULL;
+	if(NULL == (hst = gethostbyaddr((char *)&addr, sizeof(addr), AF_INET)))
+	{
+		host[0] = '\0';
+		return;
+	}
+
+	zbx_strlcpy(host, hst->h_name, hostlen);
 }
-#endif /* WINDOWS */
+#endif /*HAVE_IPV6*/
+#endif /* _WINDOWS */
 
 /******************************************************************************
  *                                                                            *
@@ -165,7 +197,7 @@ struct hostent	*zbx_gethost(const char *hostname)
 
 	host = gethostbyaddr((char *)&addr, 4, AF_INET);
 
-	if(host)        return host;
+	if(host)	return host;
 
 
 	zbx_set_tcp_strerror("gethost() failed for address '%s' [%s]", hostname, strerror_from_system(zbx_sock_last_error()));
@@ -198,7 +230,7 @@ static int	zbx_tcp_start(void)
 {
 	WSADATA sockInfo;
 
-	switch(WSAStartup(0x0002,&sockInfo))
+	switch(WSAStartup(MAKEWORD(2, 2),&sockInfo))
 	{
 		case WSASYSNOTREADY:
 			zbx_set_tcp_strerror("Underlying network subsystem is not ready for network communication.");
@@ -232,7 +264,7 @@ static int	zbx_tcp_start(void)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value:                                                              * 
+ * Return value:                                                              *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
  *                                                                            *
@@ -254,7 +286,7 @@ static void	zbx_tcp_clean(zbx_sock_t *s)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value:                                                              * 
+ * Return value:                                                              *
  *                                                                            *
  * Author: Eugene Grigorjev                                                   *
  *                                                                            *
@@ -275,7 +307,7 @@ void	zbx_tcp_init(zbx_sock_t *s, ZBX_SOCKET o)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: sockfd - open socket                                         * 
+ * Return value: sockfd - open socket                                         *
  *               FAIL - an error occured                                      *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
@@ -283,19 +315,77 @@ void	zbx_tcp_init(zbx_sock_t *s, ZBX_SOCKET o)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int     zbx_tcp_connect(zbx_sock_t *s, const char *ip, unsigned short port)
+#if defined(HAVE_IPV6)
+int	zbx_tcp_connect(zbx_sock_t *s,
+	const char	*ip, 
+	unsigned short	port,
+	int		timeout
+	)
 {
-	ZBX_SOCKADDR	myaddr_in;
-	ZBX_SOCKADDR	servaddr_in;
+	int	ret = FAIL;
+	struct	addrinfo *ai = NULL, hints;
+	char	service[MAX_STRING_LEN];
 
+	ZBX_TCP_START();
+
+	zbx_tcp_clean(s);
+
+	zbx_snprintf(service, sizeof(service), "%d", port);
+	memset(&hints, 0x00, sizeof(struct addrinfo));
+	hints.ai_family = PF_UNSPEC;
+	hints.ai_socktype = SOCK_STREAM;
+
+	if (0 != getaddrinfo(ip, service, &hints, &ai)) {
+		zbx_set_tcp_strerror("Cannot resolve [%s]", ip);
+		goto out;
+	}
+
+	if (ZBX_SOCK_ERROR == (s->socket = socket(ai->ai_family, ai->ai_socktype, ai->ai_protocol))) {
+		zbx_set_tcp_strerror("Cannot create socket [%s]:%d [%s]", ip, port ,strerror_from_system(zbx_sock_last_error()));
+		goto out;
+	}
+
+	if (0 != timeout) {
+		s->timeout = timeout;
+#if defined(_WINDOWS)
+		timeout *= 1000;
+		if (setsockopt(s->socket, SOL_SOCKET, SO_RCVTIMEO, (const char *)&timeout, sizeof(timeout)) == ZBX_TCP_ERROR)
+			zbx_set_tcp_strerror("setsockopt() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+
+		if (setsockopt(s->socket, SOL_SOCKET, SO_SNDTIMEO, (const char *)&timeout, sizeof(timeout)) == ZBX_TCP_ERROR)
+			zbx_set_tcp_strerror("setsockopt() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+#else
+		alarm(timeout);
+#endif
+	}
+
+	if (ZBX_TCP_ERROR == connect(s->socket, ai->ai_addr, ai->ai_addrlen)) {
+		zbx_set_tcp_strerror("*** Cannot connect to [%s]:%d [%s]", ip, port, strerror_from_system(zbx_sock_last_error()));
+		zbx_tcp_close(s);
+		goto out;
+	}
+
+	ret = SUCCEED;
+out:
+	if (NULL != ai)
+		freeaddrinfo(ai);
+	return ret;
+}
+#else
+int	zbx_tcp_connect(zbx_sock_t *s,
+	const char	*ip,
+	unsigned short	port,
+	int		timeout
+	)
+{
+	ZBX_SOCKADDR	servaddr_in;
 	struct	hostent *hp;
 
 	ZBX_TCP_START();
 
 	zbx_tcp_clean(s);
 
-	if(NULL == (hp = zbx_gethost(ip)))
-	{
+	if (NULL == (hp = zbx_gethost(ip))) {
 		zbx_set_tcp_strerror("Cannot resolve [%s]", ip);
 		return	FAIL;
 	}
@@ -304,18 +394,26 @@ int     zbx_tcp_connect(zbx_sock_t *s, const char *ip, unsigned short port)
 	servaddr_in.sin_addr.s_addr	= ((struct in_addr *)(hp->h_addr))->s_addr;
 	servaddr_in.sin_port		= htons(port);
 
-	if( ZBX_SOCK_ERROR == (s->socket = socket(AF_INET,SOCK_STREAM,0)) )
-	{
+	if (ZBX_SOCK_ERROR == (s->socket = socket(AF_INET,SOCK_STREAM,0))) {
 		zbx_set_tcp_strerror("Cannot create socket [%s:%d] [%s]", ip, port ,strerror_from_system(zbx_sock_last_error()));
 		return	FAIL;
 	}
 
-	myaddr_in.sin_family		= AF_INET;
-	myaddr_in.sin_port			= 0;
-	myaddr_in.sin_addr.s_addr	= INADDR_ANY;
+	if (0 != timeout) {
+		s->timeout = timeout;
+#if defined(_WINDOWS)
+		timeout *= 1000;
+		if (setsockopt(s->socket, SOL_SOCKET, SO_RCVTIMEO, (const char *)&timeout, sizeof(timeout)) == ZBX_TCP_ERROR)
+			zbx_set_tcp_strerror("setsockopt() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
 
-	if( ZBX_TCP_ERROR == connect(s->socket,(struct sockaddr *)&servaddr_in,sizeof(ZBX_SOCKADDR)) )
-	{
+		if (setsockopt(s->socket, SOL_SOCKET, SO_SNDTIMEO, (const char *)&timeout, sizeof(timeout)) == ZBX_TCP_ERROR)
+			zbx_set_tcp_strerror("setsockopt() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+#else
+		alarm(timeout);
+#endif
+	}
+
+	if (ZBX_TCP_ERROR == connect(s->socket,(struct sockaddr *)&servaddr_in,sizeof(ZBX_SOCKADDR))) {
 		zbx_set_tcp_strerror("Cannot connect to [%s:%d] [%s]", ip, port, strerror_from_system(zbx_sock_last_error()));
 		zbx_tcp_close(s);
 		return	FAIL;
@@ -323,7 +421,7 @@ int     zbx_tcp_connect(zbx_sock_t *s, const char *ip, unsigned short port)
 
 	return SUCCEED;
 }
-
+#endif /*HAVE_IPV6*/
 /******************************************************************************
  *                                                                            *
  * Function: zbx_tcp_send                                                     *
@@ -332,7 +430,7 @@ int     zbx_tcp_connect(zbx_sock_t *s, const char *ip, unsigned short port)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCEED - success                                            * 
+ * Return value: SUCCEED - success                                            *
  *               FAIL - an error occured                                      *
  *                                                                            *
  * Author: Eugene Grigorjev                                                   *
@@ -346,7 +444,7 @@ int     zbx_tcp_connect(zbx_sock_t *s, const char *ip, unsigned short port)
 #define ZBX_TCP_HEADER			ZBX_TCP_HEADER_DATA ZBX_TCP_HEADER_VERSION
 #define ZBX_TCP_HEADER_LEN		5
 
-int     zbx_tcp_send_ext(zbx_sock_t *s, const char *data, unsigned char flags)
+int	zbx_tcp_send_ext(zbx_sock_t *s, const char *data, unsigned char flags)
 {
 	zbx_uint64_t	len64;
 
@@ -377,7 +475,7 @@ int     zbx_tcp_send_ext(zbx_sock_t *s, const char *data, unsigned char flags)
 
 	while(written < (ssize_t)strlen(data))
 	{
-		if( ZBX_TCP_ERROR == (i = ZBX_TCP_WRITE(s->socket, data+written,strlen(data)-written)) )
+		if( ZBX_TCP_ERROR == (i = ZBX_TCP_WRITE(s->socket, data+written,(int)(strlen(data)-written))) )
 		{
 			zbx_set_tcp_strerror("ZBX_TCP_WRITE() failed [%s]", strerror_from_system(zbx_sock_last_error()));
 			return	FAIL;
@@ -403,12 +501,16 @@ int     zbx_tcp_send_ext(zbx_sock_t *s, const char *data, unsigned char flags)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-void    zbx_tcp_close(zbx_sock_t *s)
+void	zbx_tcp_close(zbx_sock_t *s)
 {
 	zbx_tcp_unaccept(s);
 	
 	zbx_tcp_free(s);
 
+#if !defined(_WINDOWS)
+	if (0 != s->timeout)
+		alarm(0);
+#endif
 	zbx_sock_close(s->socket);
 }
 
@@ -420,7 +522,7 @@ void    zbx_tcp_close(zbx_sock_t *s)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCEED - success                                            * 
+ * Return value: SUCCEED - success                                            *
  *               FAIL - an error occured                                      *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
@@ -428,23 +530,100 @@ void    zbx_tcp_close(zbx_sock_t *s)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
+#if defined(HAVE_IPV6)
 int zbx_tcp_listen(
-	zbx_sock_t		*s,
-	const char		*listen_ip,
+	zbx_sock_t	*s,
+	const char	*listen_ip,
 	unsigned short	listen_port
 	)
 {
-	ZBX_SOCKADDR serv_addr;
-	int	on;
+	struct		addrinfo hints, *ai = NULL, *current_ai;
+	char		port[MAX_STRING_LEN];
+	int		e, on, ret = FAIL;
 
 	ZBX_TCP_START();
 
 	zbx_tcp_clean(s);
 
-	if( ZBX_SOCK_ERROR == (s->socket = socket(AF_INET,SOCK_STREAM,0)) )
+	memset(&hints, 0, sizeof(hints));
+	hints.ai_family = PF_UNSPEC;
+	hints.ai_flags = AI_NUMERICHOST | AI_PASSIVE;
+	hints.ai_socktype = SOCK_STREAM;
+	zbx_snprintf(port, sizeof(port), "%d", listen_port);
+	if(0 != (e = getaddrinfo(listen_ip, port, &hints, &ai)))
 	{
-		zbx_set_tcp_strerror("Cannot create socket [%s:%u] [%s]", listen_ip, listen_port ,strerror_from_system(zbx_sock_last_error()));
-		return	FAIL;
+		zbx_set_tcp_strerror("Cannot resolve address [[%s]:%u], error %d: %s", listen_ip, listen_port, e, gai_strerror(e));
+		goto out;
+	}
+
+	for(s->num_socks = 0, current_ai = ai; current_ai != NULL; current_ai = current_ai->ai_next)
+	{
+		if(s->num_socks == FD_SETSIZE) {
+			break;
+		}
+		/* This example only supports PF_INET and PF_INET6. */
+		if((current_ai->ai_family != PF_INET) && (current_ai->ai_family != PF_INET6))
+			continue;
+
+		if((s->sockets[s->num_socks] = socket(current_ai->ai_family, current_ai->ai_socktype, current_ai->ai_protocol)) == ZBX_SOCK_ERROR) {
+			zbx_set_tcp_strerror("socket() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+			continue;
+		}
+
+		/* Enable address reuse */
+		/* This is to immediately use the address even if it is in TIME_WAIT state */
+		/* http://www-128.ibm.com/developerworks/linux/library/l-sockpit/index.html */
+		on = 1;
+		if(setsockopt(s->sockets[s->num_socks], SOL_SOCKET, SO_REUSEADDR, (void *)&on, sizeof(on)) == ZBX_TCP_ERROR)
+		{
+			zbx_set_tcp_strerror("setsockopt() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+		}
+
+		/* Create socket	Fill in local address structure */
+		if(bind(s->sockets[s->num_socks], current_ai->ai_addr, current_ai->ai_addrlen) == ZBX_TCP_ERROR) {
+			zbx_set_tcp_strerror("bind() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+			zbx_sock_close(s->sockets[s->num_socks]);
+			continue;
+		}
+
+		if(ZBX_SOCK_ERROR == listen(s->sockets[s->num_socks], SOMAXCONN) )
+		{
+			zbx_set_tcp_strerror("listen() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+			zbx_sock_close(s->sockets[s->num_socks]);
+			continue;
+		}
+
+		s->num_socks++;
+	}
+
+	if(s->num_socks == 0) {
+		zbx_set_tcp_strerror("zbx_tcp_listen() Fatal error: unable to serve on any address. [[%s]:%u]", listen_ip, listen_port);
+		goto out;
+	}
+	ret = SUCCEED;
+out:
+	if (NULL != ai)
+		freeaddrinfo(ai);
+	return ret;
+}
+#else
+int zbx_tcp_listen(
+	zbx_sock_t	*s,
+	const char	*listen_ip,
+	unsigned short	listen_port
+	)
+{
+	ZBX_SOCKADDR	serv_addr;
+	int		on, res = FAIL;
+
+	ZBX_TCP_START();
+
+	zbx_tcp_clean(s);
+
+	if(ZBX_SOCK_ERROR == (s->socket = socket(AF_INET,SOCK_STREAM,0)))
+	{
+		zbx_set_tcp_strerror("Cannot create socket [%s:%u] [%s]", listen_ip, listen_port, strerror_from_system(zbx_sock_last_error()));
+		goto out;
 	}
 
 	/* Enable address reuse */
@@ -461,7 +640,7 @@ int zbx_tcp_listen(
 
 	serv_addr.sin_family		= AF_INET;
 	serv_addr.sin_addr.s_addr	= listen_ip ? inet_addr(listen_ip) : htonl(INADDR_ANY);
-	serv_addr.sin_port			= htons((unsigned short)listen_port);
+	serv_addr.sin_port		= htons((unsigned short)listen_port);
 
 	/* Bind socket */
 	if (ZBX_SOCK_ERROR == bind(s->socket,(struct sockaddr *)&serv_addr,sizeof(ZBX_SOCKADDR)) )
@@ -471,17 +650,19 @@ int zbx_tcp_listen(
 				listen_ip ? listen_ip : "[ANY]",
 				strerror_from_system(zbx_sock_last_error()));
 
-		return	FAIL;
+		goto out;
 	}
 
 	if( ZBX_SOCK_ERROR == listen(s->socket, SOMAXCONN) )
 	{
 		zbx_set_tcp_strerror("Listen failed. [%s]", strerror_from_system(zbx_sock_last_error()));
-		return	FAIL;
+		goto out;
 	}
-	return SUCCEED;
+	res = SUCCEED;
+out:
+	return res;
 }
-
+#endif /*HAVE_IPV6*/
 /******************************************************************************
  *                                                                            *
  * Function: zbx_tcp_accept                                                   *
@@ -498,14 +679,73 @@ int zbx_tcp_listen(
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
+#if defined(HAVE_IPV6)
+int	zbx_tcp_accept(zbx_sock_t *s)
+{
+	struct sockaddr_storage	serv_addr;
+	fd_set			sock_set;
+	ZBX_SOCKET		accepted_socket;
+	socklen_t		nlen;
+	int			i, n = 0;
+
+	zbx_tcp_unaccept(s);
+
+	FD_ZERO(&sock_set);
+
+	/* For connection orientated protocols, we will handle the
+	   packets comprising a connection collectively.  For datagram
+	   protocols, we have to handle each datagram individually.
+
+	   Check to see if we have any sockets remaining to be served
+	   from previous time through this loop.  If not, call select()
+	   to wait for a connection request or a datagram to arrive. */
+
+	for(i = 0; i < s->num_socks; i++) {
+#if !defined(_WINDOWS)
+		if(s->sockets[i] > n)
+			n = s->sockets[i];
+#endif
+		if(FD_ISSET(s->sockets[i], &sock_set))
+			break;
+	}
+
+	if(i == s->num_socks) {
+		for (i = 0; i < s->num_socks; i++)
+			FD_SET(s->sockets[i], &sock_set);
+		if(select(n + 1, &sock_set, 0, 0, 0) == ZBX_TCP_ERROR) {
+			zbx_set_tcp_strerror("select() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+			return	FAIL;
+		}
+	}
+	for (i = 0; i < s->num_socks; i++) {
+		if (FD_ISSET(s->sockets[i], &sock_set)) {
+			FD_CLR(s->sockets[i], &sock_set);
+			break;
+		}
+	}
+
+	/* Since this socket was returned by the select(), we know we
+	   have a connection waiting and that this accept() won't block.*/
+	nlen = sizeof(serv_addr);
+	if((accepted_socket = (ZBX_SOCKET)accept(s->sockets[i], (struct sockaddr *)&serv_addr, &nlen)) == ZBX_SOCK_ERROR) {
+		zbx_set_tcp_strerror("accept() failed with error %d: %s", zbx_sock_last_error(), strerror_from_system(zbx_sock_last_error()));
+		return FAIL;
+	}
+
+	s->socket2	= s->socket;		/* remember main socket */
+	s->socket	= accepted_socket;	/* replace socket to accepted */
+	s->accepted	= 1;
+
+	return SUCCEED;
+}
+#else
 int	zbx_tcp_accept(zbx_sock_t *s)
 {
 	ZBX_SOCKADDR	serv_addr;
 	ZBX_SOCKET	accepted_socket;
-
 	socklen_t	nlen;
 
-	nlen = sizeof(ZBX_SOCKADDR);
+	nlen = sizeof(serv_addr);
 
 	zbx_tcp_unaccept(s);
 
@@ -517,11 +757,11 @@ int	zbx_tcp_accept(zbx_sock_t *s)
 
 	s->socket2	= s->socket;		/* remember main socket */
 	s->socket	= accepted_socket;	/* replace socket to accepted */
-	s->accepted = 1;
+	s->accepted	= 1;
 
 	return	SUCCEED;
 }
-
+#endif /* HAVE_IPV6 */
 /******************************************************************************
  *                                                                            *
  * Function: zbx_tcp_unaccept                                                 *
@@ -552,7 +792,7 @@ void	zbx_tcp_unaccept(zbx_sock_t *s)
 
 /******************************************************************************
  *                                                                            *
- * Function: zbx_tcp_close                                                    *
+ * Function: zbx_tcp_free                                                     *
  *                                                                            *
  * Purpose: close open socket                                                 *
  *                                                                            *
@@ -565,7 +805,7 @@ void	zbx_tcp_unaccept(zbx_sock_t *s)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-void    zbx_tcp_free(zbx_sock_t *s)
+void	zbx_tcp_free(zbx_sock_t *s)
 {
 	zbx_free(s->buf_dyn);
 }
@@ -578,7 +818,7 @@ void    zbx_tcp_free(zbx_sock_t *s)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCEED - success                                            * 
+ * Return value: SUCCEED - success                                            *
  *               FAIL - an error occured                                      *
  *                                                                            *
  * Author: Eugene Grigorjev                                                   *
@@ -722,16 +962,22 @@ int	zbx_tcp_check_security(
 	int allow_if_empty
 	)
 {
-	ZBX_SOCKADDR name;
+#if defined(HAVE_IPV6)
+	struct		sockaddr_storage name;
+	struct		addrinfo hints, *ai = NULL;
+#else
+	ZBX_SOCKADDR	name;
+	struct		hostent *hp;
+	char		*sip;
+	int		i[4], j[4];
+#endif
 	socklen_t	nlen;
 
-	struct  hostent *hp;
-
-	char
-		tmp[MAX_STRING_LEN], 
+	char	tmp[MAX_STRING_LEN], 
 		sname[MAX_STRING_LEN],
-		*sip, 
-		*host;
+		*start = NULL,
+		*end = NULL,
+		c = '\0';
 
 	zabbix_log( LOG_LEVEL_DEBUG, "In check_security()");
 
@@ -739,35 +985,102 @@ int	zbx_tcp_check_security(
 	{
 		return SUCCEED;
 	}
-	nlen = sizeof(ZBX_SOCKADDR);
-	if( ZBX_TCP_ERROR == getpeername(s->socket,  (struct sockaddr*)&name, &nlen))
+	nlen = sizeof(name);
+	if( ZBX_TCP_ERROR == getpeername(s->socket, (struct sockaddr*)&name, &nlen))
 	{
 		zbx_set_tcp_strerror("Connection rejected. Getpeername failed [%s]", strerror_from_system(zbx_sock_last_error()));
 		return FAIL;
 	}
 	else
 	{
+#if !defined(HAVE_IPV6)
 		strcpy(sname, inet_ntoa(name.sin_addr));
 
+		if(sscanf(sname, "%d.%d.%d.%d", &i[0], &i[1], &i[2], &i[3]) != 4)
+		{
+			return FAIL;
+		}
+#endif /*HAVE_IPV6*/
 		strscpy(tmp,ip_list);
 
-		host = (char *)strtok(tmp,",");
-
-		while( NULL != host )
+		for(start = tmp; start[0] != '\0';)
 		{
+			end = strchr(start, ',');
+
+			if(end != NULL)
+			{
+				c = end[0];
+				end[0] = '\0';
+			}
+
 			/* Allow IP addresses or DNS names for authorization */
-			if( 0 != (hp = zbx_gethost(host)))
+#if defined(HAVE_IPV6)
+			memset(&hints, 0, sizeof(hints));
+			hints.ai_family = PF_UNSPEC;
+			if(0 == getaddrinfo(start, NULL, &hints, &ai))
+			{
+				if(ai->ai_family == name.ss_family)
+				{
+					switch(ai->ai_family)
+					{
+						case AF_INET  :
+							if(((struct sockaddr_in*)&name)->sin_addr.s_addr == ((struct sockaddr_in*)ai->ai_addr)->sin_addr.s_addr)
+							{
+								freeaddrinfo(ai);
+								return SUCCEED;
+							}
+						case AF_INET6 :
+							if(0 == memcmp(((struct sockaddr_in6*)&name)->sin6_addr.s6_addr,
+									((struct sockaddr_in6*)ai->ai_addr)->sin6_addr.s6_addr,
+									sizeof(struct in6_addr)))
+							{
+								freeaddrinfo(ai);
+								return SUCCEED;
+							}
+					}
+				}
+				freeaddrinfo(ai);
+			}
+#else
+			if( 0 != (hp = zbx_gethost(start)))
 			{
 				sip = inet_ntoa(*((struct in_addr *)hp->h_addr));
-				if( 0 == strcmp(sname, sip))
+				if(sscanf(sip, "%d.%d.%d.%d", &j[0], &j[1], &j[2], &j[3]) == 4)
 				{
-					return	SUCCEED;
+					if(i[0] == j[0] && i[1] == j[1] && i[2] == j[2] && i[3] == j[3])
+					{
+						return SUCCEED;
+					}
 				}
 			}
-			host = (char *)strtok(NULL,",");
+#endif /*HAVE_IPV6*/
+			if(end != NULL)
+			{
+				end[0] = c;
+				start = end + 1;
+			}
+			else
+			{
+				break;
+			}
+		}
+
+		if(end != NULL)
+		{
+			end[0] = c;
 		}
 	}
+#if defined(HAVE_IPV6)
+	if(0 == getnameinfo((struct sockaddr*)&name, sizeof(name), sname, sizeof(sname), NULL, 0, NI_NUMERICHOST))
+	{
+		zbx_set_tcp_strerror("Connection from [%s] rejected. Allowed server is [%s] ",sname, ip_list);
+	}
+	else
+	{
+		zbx_set_tcp_strerror("Connection rejected. Allowed server is [%s] ", ip_list);
+	}
+#else
 	zbx_set_tcp_strerror("Connection from [%s] rejected. Allowed server is [%s] ",sname, ip_list);
+#endif /*HAVE_IPV6*/
 	return	FAIL;
 }
-
