@@ -36,6 +36,7 @@
 
 #ifdef	HAVE_POSTGRESQL
 	PGconn	*conn = NULL;
+	int     ZBX_PG_BYTEAOID = 0;
 #endif
 
 #ifdef	HAVE_ORACLE
@@ -53,13 +54,14 @@ void	zbx_db_close(void)
 	conn = NULL;
 #endif
 #ifdef	HAVE_ORACLE
-	sqlo_finish(oracle);
+	if (SQLO_SUCCESS != sqlo_finish(oracle))
+		zabbix_log(LOG_LEVEL_ERR, "Cannot finish ORACLE session");
 #endif
 #ifdef	HAVE_SQLITE3
 	sqlite_transaction_started = 0;
 	sqlite3_close(conn);
 	conn = NULL;
-	php_sem_remove(&sqlite_access);
+/*	php_sem_remove(&sqlite_access);*/
 #endif
 }
 
@@ -126,7 +128,9 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 	return ret;
 #endif
 #ifdef	HAVE_POSTGRESQL
-	char *cport = NULL;
+	char		*cport = NULL;
+	DB_RESULT	result;
+	DB_ROW		row;
 
 	if( port )	cport = zbx_dsprintf(cport, "%i", port);
 
@@ -141,30 +145,49 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 		ret = ZBX_DB_FAIL;
 	}
 
+	result = DBselect("select oid from pg_type where typname = 'bytea'" );
+	row = DBfetch(result);
+	if(row)
+	{
+		ZBX_PG_BYTEAOID = atoi(row[0]);
+	}
+	DBfree_result(result);
+
 	return ret;
 #endif
 #ifdef	HAVE_ORACLE
-	char    connect = NULL;
+	char	connect[MAX_STRING_LEN];
 
-	if (SQLO_SUCCESS != sqlo_init(SQLO_OFF, 1, 100))
-	{
+	if (SQLO_SUCCESS != sqlo_init(SQLO_OFF, 1, 100)) {
 		zabbix_log(LOG_LEVEL_ERR, "Failed to init libsqlora8");
-		exit(FAIL);
+
+		ret = ZBX_DB_FAIL;
 	}
 
-	/* login */ /* TODO: how to use port??? */
-	connect = zbx_dsprintf(connect, "%s/%s@%s", user, password, dbname);
+	if (ZBX_DB_OK == ret) {
+		zbx_strlcpy(connect, user, sizeof(connect));
 
-	if (SQLO_SUCCESS != sqlo_connect(&oracle, connect))
-	{
-		printf("Cannot login with %s\n", connect);
-		zabbix_log(LOG_LEVEL_ERR, "Cannot login with %s", connect);
-		exit(FAIL);
+		if (password && *password) {
+			zbx_strlcat(connect, "/", sizeof(connect));
+			zbx_strlcat(connect, password, sizeof(connect));
+
+			if (dbname && *dbname) {
+				zbx_strlcat(connect, "@", sizeof(connect));
+				zbx_strlcat(connect, dbname, sizeof(connect));
+			}
+		}
+
+		/* login */ /* TODO: how to use port??? */
+		if (SQLO_SUCCESS != sqlo_connect(&oracle, connect)) {
+			zabbix_log(LOG_LEVEL_ERR, "Cannot login with %s",
+					connect);
+
+			ret = ZBX_DB_FAIL;
+		}
 	}
 
-	zbx_free(connect);
-
-	sqlo_autocommit_on(oracle);
+	if (ZBX_DB_OK == ret)
+		sqlo_autocommit_on(oracle);
 
 	return ret;
 #endif
@@ -182,11 +205,11 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 	/* Do not return SQLITE_BUSY immediately, wait for N ms */
 	sqlite3_busy_timeout(conn, 60*1000);
 
-	if(ZBX_MUTEX_ERROR == php_sem_get(&sqlite_access, dbname))
+/*	if(ZBX_MUTEX_ERROR == php_sem_get(&sqlite_access, dbname))
 	{
 		zbx_error("Unable to create mutex for sqlite");
 		exit(FAIL);
-	}
+	}*/
 
 	sqlite_transaction_started = 0;
 
@@ -449,14 +472,19 @@ lbl_exec:
 	{
 		if(ret == SQLITE_BUSY) goto lbl_exec; /* attention deadlock!!! */
 		
-		zabbix_log( LOG_LEVEL_ERR, "Query::%s",sql);
+		zabbix_log(LOG_LEVEL_ERR, "Query::%s",sql);
 		zabbix_log(LOG_LEVEL_ERR, "Query failed [%i]:%s", ret, error);
 		sqlite3_free(error);
-		if(!sqlite_transaction_started)
+/*		if(!sqlite_transaction_started)
 		{
 			php_sem_release(&sqlite_access);
-		}
-		ret = FAIL;
+		}*/
+		ret = ZBX_DB_FAIL;
+	}
+
+	if(ret == ZBX_DB_OK)
+	{
+		ret = sqlite3_changes(conn);
 	}
 
 	if(!sqlite_transaction_started)
@@ -479,7 +507,7 @@ int	zbx_db_is_null(char *field)
 	int ret = FAIL;
 
 	if(field == NULL)	ret = SUCCEED;
-#ifdef	HAVE_ORACLE
+#ifdef HAVE_ORACLE
 	else if(field[0] == 0)	ret = SUCCEED;
 #endif
 	return ret;
@@ -550,7 +578,16 @@ DB_ROW	zbx_db_fetch(DB_RESULT result)
 		result->values = zbx_malloc(result->values, sizeof(char*) * result->fld_num);
 		for(i = 0; i < result->fld_num; i++)
 		{
-			 result->values[i] = PQgetvalue(result->pg_result, result->cursor, i);
+			if(PQgetisnull(result->pg_result, result->cursor, i))
+			{
+				result->values[i] = NULL;
+			}
+			else
+			{
+				result->values[i] = PQgetvalue(result->pg_result, result->cursor, i);
+				if(PQftype(result->pg_result,i) == ZBX_PG_BYTEAOID) /* binary data type BYTEAOID */
+					zbx_pg_unescape_bytea((u_char *)result->values[i]);
+			}
 		}
 	}
 
@@ -561,9 +598,6 @@ DB_ROW	zbx_db_fetch(DB_RESULT result)
 #ifdef	HAVE_ORACLE
 	int res;
 
-	/* EOF */
-	if(!result)	return NULL;
-
 	res = sqlo_fetch(result, 1);
 
 	if(SQLO_SUCCESS == res)
@@ -773,7 +807,7 @@ zbx_uint64_t	zbx_db_insert_id(int exec_result, const char *table, const char *fi
 
 	zbx_snprintf(sql, sizeof(sql), "select %s_%s.currval from dual", table, field);
 
-	result=DBselect(sql);
+	result=DBselect("%s", sql);
 	
 	row = DBfetch(result);
 
