@@ -24,7 +24,38 @@
 
 int	SYSTEM_CPU_NUM(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-	return SYSINFO_RET_FAIL;
+#ifdef HAVE_FUNCTION_SYSCTL_HW_NCPU
+	size_t	len;
+	int	mib[2], ncpu;
+	char	mode[MAX_STRING_LEN];
+
+	assert(result);
+
+	init_result(result);
+
+	if (num_param(param) > 1)
+		return SYSINFO_RET_FAIL;
+
+	if (0 == get_param(param, 1, mode, sizeof(mode))) {
+		if (*mode != '\0') {
+			if (0 != strcmp(mode, "online"))
+				return SYSINFO_RET_FAIL;
+		}
+	}
+
+	mib[0] = CTL_HW;
+	mib[1] = HW_NCPU;
+
+	len = sizeof(ncpu);
+	if (-1 == sysctl(mib, 2, &ncpu, &len, NULL, 0))
+		return SYSINFO_RET_FAIL;
+
+	SET_UI64_RESULT(result, ncpu);
+
+	return SYSINFO_RET_OK;
+#else
+ 	return SYSINFO_RET_FAIL;
+#endif /*HAVE_FUNCTION_SYSCTL_HW_NCPU*/
 }
 
 int	SYSTEM_CPU_UTIL(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
