@@ -22,11 +22,66 @@
 #include "sysinfo.h"
 #include "stats.h"
 
+int	SYSTEM_CPU_NUM(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
+{
+#if defined(HAVE_SYS_PSTAT_H)
+
+	char	mode[128];
+	int	sysinfo_name = -1;
+	long	ncpu = 0;
+	struct pst_dynamic psd;
+
+#endif /* HAVE_SYS_PSTAT_H */
+	
+        assert(result);
+
+        init_result(result);
+	
+#if defined(HAVE_SYS_PSTAT_H)
+
+        if(num_param(param) > 1)
+        {
+                return SYSINFO_RET_FAIL;
+        }
+
+        if(get_param(param, 1, mode, sizeof(mode)) != 0)
+        {
+                mode[0] = '\0';
+        }
+        if(mode[0] == '\0')
+	{
+		/* default parameter */
+		zbx_snprintf(mode, sizeof(mode), "online");
+	}
+
+	if(0 != strncmp(mode, "online", sizeof(mode)))
+	{
+		return SYSINFO_RET_FAIL;
+	}
+
+
+	if ( -1 == pstat_getdynamic(&psd, sizeof(struct pst_dynamic), 1, 0) )
+	{
+		return SYSINFO_RET_FAIL;
+	}
+
+	SET_UI64_RESULT(result, psd.psd_proc_cnt);
+	
+	return SYSINFO_RET_OK;
+#else /* HAVE_SYS_PSTAT_H */
+
+	return SYSINFO_RET_FAIL;
+
+#endif /* HAVE_SYS_PSTAT_H */
+}
+
 int	SYSTEM_CPU_UTIL(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
 	char cpuname[MAX_STRING_LEN];
 	char type[MAX_STRING_LEN];
 	char mode[MAX_STRING_LEN];
+
+	int cpu_num = 0;
 	
         assert(result);
 
@@ -39,22 +94,20 @@ int	SYSTEM_CPU_UTIL(const char *cmd, const char *param, unsigned flags, AGENT_RE
 
         if(get_param(param, 1, cpuname, sizeof(cpuname)) != 0)
         {
-                return SYSINFO_RET_FAIL;
+                cpuname[0] = '\0';
         }
+
 	if(cpuname[0] == '\0')
 	{
 		/* default parameter */
 		zbx_snprintf(cpuname, sizeof(cpuname), "all");
 	}
-	if(strncmp(cpuname, "all", sizeof(cpuname)))
-	{
-		return SYSINFO_RET_FAIL;
-	}
-	
+
 	if(get_param(param, 2, type, sizeof(type)) != 0)
         {
                 type[0] = '\0';
         }
+
         if(type[0] == '\0')
 	{
 		/* default parameter */
@@ -72,40 +125,51 @@ int	SYSTEM_CPU_UTIL(const char *cmd, const char *param, unsigned flags, AGENT_RE
 		zbx_snprintf(mode, sizeof(mode), "avg1");
 	}
 
-	if(NULL == collector)
+	if ( !CPU_COLLECTOR_STARTED(collector) )
 	{
 		SET_MSG_RESULT(result, strdup("Collector is not started!"));
 		return SYSINFO_RET_OK;
 	}
 
+	if(strcmp(cpuname,"all") == 0)
+	{
+		cpu_num = 0;
+	}
+	else
+	{
+		cpu_num = atoi(cpuname)+1;
+		if ((cpu_num < 1) || (cpu_num > collector->cpus.count))
+			return SYSINFO_RET_FAIL;
+	}
+
 	if( 0 == strcmp(type,"idle"))
 	{
-		if( 0 == strcmp(mode,"avg1"))		SET_DBL_RESULT(result, collector->cpus.idle1)
-		else if( 0 == strcmp(mode,"avg5"))	SET_DBL_RESULT(result, collector->cpus.idle5)
-		else if( 0 == strcmp(mode,"avg15"))	SET_DBL_RESULT(result, collector->cpus.idle15)
+		if( 0 == strcmp(mode,"avg1"))		SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].idle1)
+		else if( 0 == strcmp(mode,"avg5"))	SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].idle5)
+		else if( 0 == strcmp(mode,"avg15"))	SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].idle15)
 		else return SYSINFO_RET_FAIL;
 
 	}
 	else if( 0 == strcmp(type,"nice"))
 	{
-		if( 0 == strcmp(mode,"avg1")) 		SET_DBL_RESULT(result, collector->cpus.nice1)
-		else if( 0 == strcmp(mode,"avg5")) 	SET_DBL_RESULT(result, collector->cpus.nice5)
-		else if( 0 == strcmp(mode,"avg15"))	SET_DBL_RESULT(result, collector->cpus.nice15)
+		if( 0 == strcmp(mode,"avg1")) 		SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].nice1)
+		else if( 0 == strcmp(mode,"avg5")) 	SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].nice5)
+		else if( 0 == strcmp(mode,"avg15"))	SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].nice15)
 		else return SYSINFO_RET_FAIL;
 
 	}
 	else if( 0 == strcmp(type,"user"))
 	{
-		if( 0 == strcmp(mode,"avg1")) 		SET_DBL_RESULT(result, collector->cpus.user1)
-		else if( 0 == strcmp(mode,"avg5")) 	SET_DBL_RESULT(result, collector->cpus.user5)
-		else if( 0 == strcmp(mode,"avg15"))	SET_DBL_RESULT(result, collector->cpus.user15)
+		if( 0 == strcmp(mode,"avg1")) 		SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].user1)
+		else if( 0 == strcmp(mode,"avg5")) 	SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].user5)
+		else if( 0 == strcmp(mode,"avg15"))	SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].user15)
 		else return SYSINFO_RET_FAIL;
 	}
 	else if( 0 == strcmp(type,"system"))
 	{
-		if( 0 == strcmp(mode,"avg1")) 		SET_DBL_RESULT(result, collector->cpus.system1)
-		else if( 0 == strcmp(mode,"avg5")) 	SET_DBL_RESULT(result, collector->cpus.system5)
-		else if( 0 == strcmp(mode,"avg15"))	SET_DBL_RESULT(result, collector->cpus.system15)
+		if( 0 == strcmp(mode,"avg1")) 		SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].system1)
+		else if( 0 == strcmp(mode,"avg5")) 	SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].system5)
+		else if( 0 == strcmp(mode,"avg15"))	SET_DBL_RESULT(result, collector->cpus.cpu[cpu_num].system15)
 		else return SYSINFO_RET_FAIL;
 	}
 	else
