@@ -222,6 +222,7 @@ int	SYSTEM_CPU_UTIL(const char *cmd, const char *param, unsigned flags, AGENT_RE
 
 static int	SYSTEM_CPU_LOAD1(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
+#ifdef	HAVE_PROC_LOADAVG
 	double	load[3];
 
 	assert(result);
@@ -237,10 +238,14 @@ static int	SYSTEM_CPU_LOAD1(const char *cmd, const char *param, unsigned flags,
 	{
 		return SYSINFO_RET_FAIL;	
 	}
+#else
+	return SYSINFO_RET_FAIL;	
+#endif
 }
 
 static int	SYSTEM_CPU_LOAD5(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
+#ifdef	HAVE_PROC_LOADAVG
 	double	load[3];
 
 	assert(result);
@@ -256,10 +261,14 @@ static int	SYSTEM_CPU_LOAD5(const char *cmd, const char *param, unsigned flags,
 	{
 		return SYSINFO_RET_FAIL;	
 	}
+#else
+	return SYSINFO_RET_FAIL;	
+#endif
 }
 	       
 static int	SYSTEM_CPU_LOAD15(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
+#ifdef	HAVE_PROC_LOADAVG
 	double	load[3];
 
 	assert(result);
@@ -275,6 +284,9 @@ static int	SYSTEM_CPU_LOAD15(const char *cmd, const char *param, unsigned flags,
 	{
 		return SYSINFO_RET_FAIL;	
 	}
+#else
+	return SYSINFO_RET_FAIL;	
+#endif
 }
 
 int	SYSTEM_CPU_LOAD(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
