@@ -17,9 +17,8 @@
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/
 
-#include "config.h"
-
 #include "common.h"
+
 #include "sysinfo.h"
 
 #include "md5.h"
@@ -125,8 +124,9 @@ static int	SYSTEM_SWAP_PFREE(const char *cmd, const char *param, unsigned flags,
         init_result(result);
         init_result(&result_tmp);
 
-	if(SYSTEM_SWAP_TOTAL(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK)
-                return  SYSINFO_RET_FAIL;
+	if(SYSTEM_SWAP_TOTAL(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK ||
+		!(result_tmp.type & AR_UINT64))
+	                return  SYSINFO_RET_FAIL;
 	tot_val = result_tmp.ui64;
 
 	/* Check fot division by zero */
@@ -136,8 +136,9 @@ static int	SYSTEM_SWAP_PFREE(const char *cmd, const char *param, unsigned flags,
                 return  SYSINFO_RET_FAIL;
 	}
 
-	if(SYSTEM_SWAP_FREE(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK)
-                return  SYSINFO_RET_FAIL;
+	if(SYSTEM_SWAP_FREE(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK ||
+		!(result_tmp.type & AR_UINT64))
+                	return  SYSINFO_RET_FAIL;
 	free_val = result_tmp.ui64;
 
 	free_result(&result_tmp);
@@ -158,8 +159,9 @@ static int	SYSTEM_SWAP_PUSED(const char *cmd, const char *param, unsigned flags,
         init_result(result);
         init_result(&result_tmp);
 
-	if(SYSTEM_SWAP_TOTAL(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK)
-                return  SYSINFO_RET_FAIL;
+	if(SYSTEM_SWAP_TOTAL(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK ||
+		!(result_tmp.type & AR_UINT64))
+                	return  SYSINFO_RET_FAIL;
 	tot_val = result_tmp.ui64;
 
 	/* Check fot division by zero */
@@ -169,8 +171,9 @@ static int	SYSTEM_SWAP_PUSED(const char *cmd, const char *param, unsigned flags,
                 return  SYSINFO_RET_FAIL;
 	}
 
-	if(SYSTEM_SWAP_FREE(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK)
-                return  SYSINFO_RET_FAIL;
+	if(SYSTEM_SWAP_FREE(cmd, param, flags, &result_tmp) != SYSINFO_RET_OK ||
+		!(result_tmp.type & AR_UINT64))
+                	return  SYSINFO_RET_FAIL;
 	free_val = result_tmp.ui64;
 
 	free_result(&result_tmp);
@@ -194,8 +197,8 @@ SWP_FNCLIST
 	{
 		{"total",	SYSTEM_SWAP_TOTAL},
 		{"free",	SYSTEM_SWAP_FREE},
-		{"pfree",	SYSTEM_SWAP_PFREE},
-		{"pused",	SYSTEM_SWAP_PUSED},
+		{"pfree",       SYSTEM_SWAP_PFREE},
+		{"pused",       SYSTEM_SWAP_PUSED},
 		{0,		0}
 	};
 
@@ -212,7 +215,7 @@ SWP_FNCLIST
                 return SYSINFO_RET_FAIL;
         }
 
-        if(get_param(param, 1, swapdev, MAX_STRING_LEN) != 0)
+        if(get_param(param, 1, swapdev, sizeof(swapdev)) != 0)
         {
                 return SYSINFO_RET_FAIL;
         }
@@ -220,15 +223,15 @@ SWP_FNCLIST
         if(swapdev[0] == '\0')
 	{
 		/* default parameter */
-		sprintf(swapdev, "all");
+		zbx_snprintf(swapdev, sizeof(swapdev), "all");
 	}
 
-	if(strncmp(swapdev, "all", MAX_STRING_LEN))
+	if(strncmp(swapdev, "all", sizeof(swapdev)))
 	{
 		return SYSINFO_RET_FAIL;
 	}
 	
-	if(get_param(param, 2, mode, MAX_STRING_LEN) != 0)
+	if(get_param(param, 2, mode, sizeof(mode)) != 0)
         {
                 mode[0] = '\0';
         }
@@ -236,7 +239,7 @@ SWP_FNCLIST
         if(mode[0] == '\0')
 	{
 		/* default parameter */
-		sprintf(mode, "free");
+		zbx_snprintf(mode, sizeof(mode), "free");
 	}
 
 	for(i=0; fl[i].mode!=0; i++)
@@ -311,22 +314,22 @@ int	get_swap_io(double *swapin, double *pgswapin, double *swapout, double *pgswa
 		cpu = (cpu_stat_t*) k->ks_data;
 		if(swapin)
 		{
-		   /* uint_t   swapin;	    	// swapins */
+		   /* uint_t   swapin;	    	*/ /* swapins */
 		   (*swapin) += (double) cpu->cpu_vminfo.swapin;
 		}
 		if(pgswapin)
 		{
-		   /* uint_t   pgswapin;	// pages swapped in */
+		   /* uint_t   pgswapin;	*/ /* pages swapped in */
 		  (*pgswapin) += (double) cpu->cpu_vminfo.pgswapin;
 		}
 		if(swapout)
 		{
-		   /* uint_t   swapout;	    	// swapout */
+		   /* uint_t   swapout;	    	*/ /* swapout */
 		   (*swapout) += (double) cpu->cpu_vminfo.swapout;
 		}
 		if(pgswapout)
 		{
-		   /* uint_t   pgswapout;	// pages swapped out */
+		   /* uint_t   pgswapout;	*/ /* pages swapped out */
 		  (*pgswapout) += (double) cpu->cpu_vminfo.pgswapout;
 		}
 		cpu_count += 1;
@@ -360,7 +363,7 @@ int	SYSTEM_SWAP_IN(const char *cmd, const char *param, unsigned flags, AGENT_RES
         return SYSINFO_RET_FAIL;
     }
 
-    if(get_param(param, 1, swapdev, MAX_STRING_LEN) != 0)
+    if(get_param(param, 1, swapdev, sizeof(swapdev)) != 0)
     {
 	return SYSINFO_RET_FAIL;
     }
@@ -368,22 +371,22 @@ int	SYSTEM_SWAP_IN(const char *cmd, const char *param, unsigned flags, AGENT_RES
     if(swapdev[0] == '\0')
     {
 	/* default parameter */
-	sprintf(swapdev, "all");
+	zbx_snprintf(swapdev, sizeof(swapdev), "all");
     }
 
-    if(strncmp(swapdev, "all", MAX_STRING_LEN))
+    if(strncmp(swapdev, "all", sizeof(swapdev)))
     {
 	return SYSINFO_RET_FAIL;
     }
     
-    if(get_param(param, 2, mode, MAX_STRING_LEN) != 0)
+    if(get_param(param, 2, mode, sizeof(mode)) != 0)
     {
 	mode[0] = '\0';
     }
     
     if(mode[0] == '\0')
     {
-        strscpy(mode, "count");
+        zbx_snprintf(mode, sizeof(mode), "count");
     }
     
     if(strcmp(mode,"count") == 0)
@@ -422,7 +425,7 @@ int	SYSTEM_SWAP_OUT(const char *cmd, const char *param, unsigned flags, AGENT_RE
         return SYSINFO_RET_FAIL;
     }
 
-    if(get_param(param, 1, swapdev, MAX_STRING_LEN) != 0)
+    if(get_param(param, 1, swapdev, sizeof(swapdev)) != 0)
     {
 	return SYSINFO_RET_FAIL;
     }
@@ -430,22 +433,22 @@ int	SYSTEM_SWAP_OUT(const char *cmd, const char *param, unsigned flags, AGENT_RE
     if(swapdev[0] == '\0')
     {
 	/* default parameter */
-	sprintf(swapdev, "all");
+	zbx_snprintf(swapdev, sizeof(swapdev), "all");
     }
 
-    if(strncmp(swapdev, "all", MAX_STRING_LEN))
+    if(strncmp(swapdev, "all", sizeof(swapdev)))
     {
 	return SYSINFO_RET_FAIL;
     }
     
-    if(get_param(param, 2, mode, MAX_STRING_LEN) != 0)
+    if(get_param(param, 2, mode, sizeof(mode)) != 0)
     {
 	mode[0] = '\0';
     }
     
     if(mode[0] == '\0')
     {
-        strscpy(mode, "count");
+        zbx_snprintf(mode, sizeof(mode), "count");
     }
     
     if(strcmp(mode,"count") == 0)
