@@ -22,6 +22,44 @@
 #include "sysinfo.h"
 #include "stats.h"
 
+int	SYSTEM_CPU_NUM(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
+{
+	SYSTEM_INFO	sysInfo;
+
+	char	mode[128];
+	
+        assert(result);
+
+        init_result(result);
+	
+        if(num_param(param) > 1)
+        {
+                return SYSINFO_RET_FAIL;
+        }
+
+        if(get_param(param, 1, mode, sizeof(mode)) != 0)
+        {
+                mode[0] = '\0';
+        }
+        if(mode[0] == '\0')
+	{
+		/* default parameter */
+		zbx_snprintf(mode, sizeof(mode), "online");
+	}
+
+	if(0 != strncmp(mode, "online", sizeof(mode)))
+	{
+		return SYSINFO_RET_FAIL;
+	}
+
+	GetSystemInfo(&sysInfo);
+
+
+	SET_UI64_RESULT(result, sysInfo.dwNumberOfProcessors);
+	
+	return SYSINFO_RET_OK;
+}
+
 int     OLD_CPU(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
 	/* SKIP REALIZATION */
@@ -78,7 +116,7 @@ int	SYSTEM_CPU_UTIL(const char *cmd, const char *param, unsigned flags, AGENT_RE
 		zbx_snprintf(mode, sizeof(mode), "avg1");
 	}
 	
-	if(NULL == collector)
+	if ( !CPU_COLLECTOR_STARTED(collector) )
 	{
 		SET_MSG_RESULT(result, strdup("Collector is not started!"));
 		return SYSINFO_RET_OK;
@@ -159,7 +197,7 @@ int	SYSTEM_CPU_LOAD(const char *cmd, const char *param, unsigned flags, AGENT_RE
 		return SYSINFO_RET_FAIL;
 	}
 
-	if(NULL == collector)
+	if ( !CPU_COLLECTOR_STARTED(collector) )
 	{
 		SET_MSG_RESULT(result, strdup("Collector is not started!"));
 		return SYSINFO_RET_OK;
