@@ -173,66 +173,59 @@ static void	add_check(char *key, int refresh, long lastlogsize)
  *           <key>:<refresh time>:<last log size>                             *
  *                                                                            *
  ******************************************************************************/
-
 static int	parse_list_of_checks(char *str)
 {
-	char 
-		*p = NULL, 
-		*pstrend = NULL, 
-		*key = NULL, 
-		*refresh = NULL, 
-		*lastlogsize = NULL;
+	char	*p, *pstrend, *refresh, *lastlogsize;
 
-	zabbix_log( LOG_LEVEL_DEBUG, "In parse_list_of_checks('%s')", str);
+	zabbix_log(LOG_LEVEL_DEBUG, "In parse_list_of_checks() [%s]",
+		str);
 
 	disable_all_metrics();
 
-	while(str)
-	{
-		pstrend = strchr(str,'\n');
-		if(pstrend) *pstrend = '\0'; /* prepare line */
+	while (NULL != str) {
+		if (NULL != (pstrend = strchr(str,'\n')))
+			*pstrend = '\0'; /* prepare line */
 
 		zabbix_log(LOG_LEVEL_DEBUG, "Parsed [%s]", str);
 
-		if(strcmp(str, "ZBX_EOF") == 0)	break;
+		if (0 == strcmp(str, "ZBX_EOF"))
+			break;
+
+		refresh = NULL; 
+		lastlogsize = NULL;
 
 		/* parse string from end of line */
 		/* line format "key:refresh:lastlogsize" */
 
+		p = (NULL != pstrend) ? pstrend : str + strlen(str);
+
 		/* Lastlogsize */
-		for(p = str + strlen(str); p != str; p--)
-		{
-			if(*p == ':')
-			{
+		for (; p != str; p--) {
+			if (*p == ':') {
 				*p = '\0';
 
-				lastlogsize = p+1;
+				lastlogsize = p + 1;
 				break;
 			}
 		}
 
 		/* Refresh */
-		for(; p != str; p--)
-		{
-			if(*p == ':')
-			{
+		for (; p != str; p--) {
+			if (*p == ':') {
 				*p = '\0';
 
-				refresh = p+1;
+				refresh = p + 1;
 				break;
 			}
 		}
 
-		key = str;
+		if (str && refresh && lastlogsize)
+			add_check(str, atoi(refresh), atoi(lastlogsize));
 
-		if(key && refresh && lastlogsize)
-		{
-			add_check(key, atoi(refresh), atoi(lastlogsize));
-		}
+		if (pstrend == NULL)
+			break;
 
-		if(pstrend == NULL) break;
-
-		str = pstrend+1;
+		str = pstrend + 1;
 	}
 	return SUCCEED;
 }
@@ -270,10 +263,7 @@ static int	get_active_checks(
 
 	zabbix_log( LOG_LEVEL_DEBUG, "get_active_checks('%s',%u)", host, port);
 
-
-	if( SUCCEED == (ret = zbx_tcp_connect(&s, host, port)) )
-	{
-
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, host, port, CONFIG_TIMEOUT))) {
 		zbx_snprintf(packet, sizeof(packet), "%s\n%s\n","ZBX_GET_ACTIVE_CHECKS", CONFIG_HOSTNAME);
 		zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]", packet);
 
@@ -286,8 +276,8 @@ static int	get_active_checks(
 				parse_list_of_checks(buf);
 			}
 		}
+		zbx_tcp_close(&s);
 	}
-	zbx_tcp_close(&s);
 
 	if( FAIL == ret )
 	{
@@ -334,15 +324,11 @@ static int	send_value(
 	)
 {
 	zbx_sock_t	s;
-
-	char
-		*buf = NULL,
-		*request = NULL;
-
+	char		*buf = NULL,
+			*request = NULL;
 	int		ret;
 
-	if( SUCCEED == (ret = zbx_tcp_connect(&s, host, port)) )
-	{
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, host, port, CONFIG_TIMEOUT))) {
 		request = comms_create_request(hostname, key, value, lastlogsize, timestamp, source, severity);
 
 		zabbix_log(LOG_LEVEL_DEBUG, "XML before sending [%s]",request);
@@ -365,34 +351,30 @@ static int	send_value(
 				{
 					zabbix_log( LOG_LEVEL_DEBUG, "NOT OK [%s:%s] [%s]", host, key, buf);
 				}
-			}
-		}
-	}
-	zbx_tcp_close(&s);
+			} else
+				zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [recv] %s", zbx_tcp_strerror());
+		} else
+			zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [send] %s", zbx_tcp_strerror());
+		zbx_tcp_close(&s);
+	} else
+		zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [connect] %s", zbx_tcp_strerror());
 
-	if( FAIL == ret )
-	{
-		zabbix_log(LOG_LEVEL_DEBUG, "Send value error: %s", zbx_tcp_strerror());
-	}
 	return ret;
 }
 
-static int	process_active_checks(char *server, unsigned short port)
+static void	process_active_checks(char *server, unsigned short port)
 {
 	register int	i, s_count, p_count;
-
-	char	**pvalue;
-
-	int		now, send_err = SUCCEED, ret = SUCCEED;
-
+	char		**pvalue;
+	int		now, send_err = SUCCEED, ret;
 	unsigned long	timestamp;
 	char		*source = NULL;
 	char		*value = NULL;
 	unsigned short	severity;
-
-	char	params[MAX_STRING_LEN];
-	char	*filename;
-	char	*pattern;
+	long		lastlogsize;
+	char		params[MAX_STRING_LEN];
+	char		filename[MAX_STRING_LEN];
+	char		pattern[MAX_STRING_LEN];
 
 	AGENT_RESULT	result;
 
@@ -411,46 +393,48 @@ static int	process_active_checks(char *server, unsigned short port)
 		if(strncmp(active_metrics[i].key,"log[",4) == 0)
 		{
 			do{ /* simple try realization */
-				if(parse_command(active_metrics[i].key, NULL, 0, params, MAX_STRING_LEN) != 2)
+				if (parse_command(active_metrics[i].key, NULL, 0, params, MAX_STRING_LEN) != 2)
 					break;
 				
-				if(num_param(params) > 2)
+				if (num_param(params) > 2)
 					break;
 
-				filename = params;
+				if (get_param(params, 1, filename, sizeof(filename)) != 0)
+					break;
 
-				if( (pattern = strchr(params, ',')) ) /* TODO: rewrite for get_param */
-				{
+				if (get_param(params, 2, pattern, sizeof(pattern)) != 0)
 					*pattern = '\0';
-					pattern++;
-				}
 
 				s_count = 0;
 				p_count = 0;
-				while( SUCCEED == (ret = process_log(filename, &active_metrics[i].lastlogsize, &value)) )
-				{
-					if( !value ) /* EOF */	break;
+				lastlogsize = active_metrics[i].lastlogsize;
+				while (SUCCEED == (ret = process_log(filename, &lastlogsize, &value))) {
+					if (!value) /* EOF */
+						break;
 
-					if( !pattern || NULL != zbx_regexp_match(value, pattern, NULL) )
-					{
+					if ('\0' == *pattern || NULL != zbx_regexp_match(value, pattern, NULL)) {
 						send_err = send_value(
 									server,
 									port,
 									CONFIG_HOSTNAME,
 									active_metrics[i].key,
 									value,
-									&active_metrics[i].lastlogsize,
+									&lastlogsize,
 									NULL,
 									NULL,
 									NULL
 								);
-
 						s_count++;
 					}
 					p_count++;
 
 					zbx_free(value);
 
+					if (SUCCEED == send_err)
+						active_metrics[i].lastlogsize = lastlogsize;
+					else
+						lastlogsize = active_metrics[i].lastlogsize;
+
 					/* Do not flood ZABBIX server if file grows too fast */
 					if(s_count >= (MAX_LINES_PER_SECOND * active_metrics[i].refresh))	break;
 
@@ -483,38 +467,39 @@ static int	process_active_checks(char *server, unsigned short port)
 		else if(strncmp(active_metrics[i].key,"eventlog[",9) == 0)
 		{
 			do{ /* simple try realization */
-				if(parse_command(active_metrics[i].key, NULL, 0, params, MAX_STRING_LEN) != 2)
+				if (parse_command(active_metrics[i].key, NULL, 0, params, MAX_STRING_LEN) != 2)
 					break;
 				
-				if(num_param(params) > 2)
+				if (num_param(params) > 2)
 					break;
 
-				filename = params;
+				if (get_param(params, 1, filename, sizeof(filename)) != 0)
+					break;
 
-				if( (pattern = strchr(params, ',')) )
-				{
+				if (get_param(params, 2, pattern, sizeof(pattern)) != 0)
 					*pattern = '\0';
-					pattern++;
-				}
 
 				s_count = 0;
 				p_count = 0;
-				while( SUCCEED == (ret = process_eventlog(filename,&active_metrics[i].lastlogsize, &timestamp, &source, &severity, &value)) )
+				lastlogsize = active_metrics[i].lastlogsize;
+				while (SUCCEED == (ret = process_eventlog(filename, &lastlogsize,
+					&timestamp, &source, &severity, &value)))
 				{
-					if( value  && (!pattern || NULL != zbx_regexp_match(value, pattern, NULL)) )
-					{
+					if (!value) /* EOF */
+						break;
+
+					if (!pattern || NULL != zbx_regexp_match(value, pattern, NULL)) {
 						send_err = send_value(
 									server,
 									port,
 									CONFIG_HOSTNAME,
 									active_metrics[i].key,
 									value,
-									&active_metrics[i].lastlogsize,
+									&lastlogsize,
 									&timestamp,
 									source,
 									&severity
 								);
-
 						s_count++;
 					}
 					p_count++;
@@ -522,6 +507,11 @@ static int	process_active_checks(char *server, unsigned short port)
 					zbx_free(source);
 					zbx_free(value);
 
+					if (SUCCEED == send_err)
+						active_metrics[i].lastlogsize = lastlogsize;
+					else
+						lastlogsize = active_metrics[i].lastlogsize;
+
 					/* Do not flood ZABBIX server if file grows too fast */
 					if(s_count >= (MAX_LINES_PER_SECOND * active_metrics[i].refresh))	break;
 
@@ -584,7 +574,6 @@ static int	process_active_checks(char *server, unsigned short port)
 		}
 		active_metrics[i].nextcheck = (int)time(NULL)+active_metrics[i].refresh;
 	}
-	return ret;
 }
 
 static void	refresh_metrics(char *server, unsigned short port)
@@ -605,10 +594,20 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 {
 	ZBX_THREAD_ACTIVECHK_ARGS activechk_args;
 
+#if defined(ZABBIX_DAEMON)
+	struct	sigaction phan;
+#endif /* ZABBIX_DAEMON */
 	int	sleeptime, nextcheck;
 	int	nextrefresh;
 	char	*p = NULL;
 
+#if defined(ZABBIX_DAEMON)
+	phan.sa_handler = child_signal_handler;
+	sigemptyset(&phan.sa_mask);
+	phan.sa_flags = 0;
+	sigaction(SIGALRM, &phan, NULL);
+#endif /* ZABBIX_DAEMON */
+
 	activechk_args.host = strdup(((ZBX_THREAD_ACTIVECHK_ARGS *)args)->host);
 	activechk_args.port = ((ZBX_THREAD_ACTIVECHK_ARGS *)args)->port;
 
@@ -628,29 +627,19 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 
 	while(ZBX_IS_RUNNING)
 	{
-
 		zbx_setproctitle("processing active checks");
 
-		if(process_active_checks(activechk_args.host, activechk_args.port) == FAIL)
-		{
-			zbx_sleep(60);
-			continue;
-		}
+		process_active_checks(activechk_args.host, activechk_args.port);
 
 		nextcheck = get_min_nextcheck();
-		if(FAIL == nextcheck)
-		{
+		if (FAIL == nextcheck)
 			sleeptime = 60;
-		}
-		else
-		{
+		else {
 			sleeptime = nextcheck - (int)time(NULL);
-
 			sleeptime = MAX(sleeptime, 0);
 		}
 
-		if(sleeptime > 0)
-		{
+		if (sleeptime > 0) {
 			sleeptime = MIN(sleeptime, 60);
 
 			zabbix_log(LOG_LEVEL_DEBUG, "Sleeping for %d seconds", sleeptime );
@@ -658,11 +647,8 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 			zbx_setproctitle("poller [sleeping for %d seconds]", sleeptime);
 
 			zbx_sleep( sleeptime );
-		}
-		else
-		{
+		} else
 			zabbix_log(LOG_LEVEL_DEBUG, "No sleeping" );
-		}
 
 		if(time(NULL) >= nextrefresh)
 		{
