@@ -127,14 +127,13 @@ int	init_cpu_collector(ZBX_CPUS_STAT_DATA *pcpus)
 #ifdef _WINDOWS
 
 	PDH_STATUS	status;
-	int	i;
-
-	char counter_path[MAX_COUNTER_PATH];
-
-	pcpus->count = zbx_get_cpu_num();
+	int		i;
+	char		counter_path[MAX_COUNTER_PATH];
 
 	memset(pcpus, 0, sizeof(ZBX_CPUS_STAT_DATA));
 
+	pcpus->count = zbx_get_cpu_num();
+
 	if (PdhOpenQuery(NULL,0,&pcpus->pdh_query)!=ERROR_SUCCESS)
 	{
 		zabbix_log( LOG_LEVEL_ERR, "Call to PdhOpenQuery() failed: %s", strerror_from_system(GetLastError()));
@@ -177,7 +176,6 @@ int	init_cpu_collector(ZBX_CPUS_STAT_DATA *pcpus)
 		PdhGetRawCounterValue(pcpus->cpu[i].usage_couter, NULL, &pcpus->cpu[i].usage_old);
 	}
 
-
 	zbx_snprintf(counter_path, sizeof(counter_path), "\\%s\\%s", GetCounterName(PCI_SYSTEM), GetCounterName(PCI_PROCESSOR_QUEUE_LENGTH));
 
 	/* Prepare for CPU execution queue usage collection */
@@ -272,12 +270,17 @@ static int	get_cpustat(
 	char	line[1024];
 	char	cpu_name[10];
 	
-    #elif defined(HAVE_SYS_PSTAT_H) /* not HAVE_PROC_STAT */
+    #elif defined(HAVE_SYS_PSTAT_H)
 	
 	struct	pst_dynamic stats;
-	struct pst_processor psp;
-	
-    #else /* not HAVE_SYS_PSTAT_H */
+	struct	pst_processor psp;
+
+    #elif defined(HAVE_FUNCTION_SYSCTLBYNAME)
+
+	static long	cp_time[5];
+	size_t		nlen = sizeof(cp_time);
+ 	
+    #else /* not HAVE_FUNCTION_SYSCTLBYNAME */
 
 	return 1;
 	
@@ -336,8 +339,21 @@ static int	get_cpustat(
 		return 1;
 	}
 
+    #elif defined(HAVE_FUNCTION_SYSCTLBYNAME)
 	
-    #endif /* HAVE_SYS_PSTAT_H */
+	if (sysctlbyname("kern.cp_time", &cp_time, &nlen, NULL, 0) == -1)
+		return 1;
+
+	if (nlen != sizeof(cp_time))
+		return 1;
+
+	*cpu_user = (zbx_uint64_t)cp_time[0];
+	*cpu_nice = (zbx_uint64_t)cp_time[1];
+	*cpu_system = (zbx_uint64_t)cp_time[2];
+	*cpu_idle = (zbx_uint64_t)cp_time[4];
+ 	
+    #endif /* HAVE_FUNCTION_SYSCTLBYNAME */
+
 	return 0;
 }
 
