@@ -17,7 +17,21 @@
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/
 
-#include "config.h"
+#include "common.h"
+#include "interfaces.h"
+
+
+void	collect_stats_interfaces(ZBX_INTERFACES_DATA *pinterfaces)
+{
+#if defined(TODO)
+#error "Realize function collect_stats_interfaces IF needed"
+#endif
+}
+
+
+#if OFF && (!defined(_WINDOWS) || (defined(TODO) && defined(_WINDOWS)))
+
+/*TODO!!! Make same as cpustat.c*/
 
 #include <netdb.h>
 
@@ -50,9 +64,7 @@
 /* Required for getpwuid */
 #include <pwd.h>
 
-#include "common.h"
 #include "sysinfo.h"
-#include "security.h"
 #include "zabbix_agent.h"
 
 #include "log.h"
@@ -106,10 +118,9 @@ void	init_stats_interfaces()
 		}
 	}
 
-	file=fopen("/proc/net/dev","r");
-	if(NULL == file)
+	if( NULL == (file = fopen("/proc/net/dev","r") ))
 	{
-		fprintf(stderr, "Cannot open config file [%s] [%s]\n","/proc/net/dev", strerror(errno));
+		zbx_error("Cannot open statistic file [%s] [%s].","/proc/net/dev", strerror(errno));
 		return;
 	}
 	i=0;
@@ -117,8 +128,7 @@ void	init_stats_interfaces()
 	{
 		if( (s=strstr(line,":")) == NULL)
 			continue;
-		zbx_strlcpy(interface,line,s-line);
-		interface[s-line]=0;
+		zbx_strlcpy(interface,line,s-line+1);
 		j1=0;
 		for(j=0;j<(int)strlen(interface);j++)
 		{
@@ -132,7 +142,7 @@ void	init_stats_interfaces()
 		i++;
 	}
 
-	fclose(file);
+	zbx_fclose(file);
 }
 
 void	report_stats_interfaces(FILE *file, int now)
@@ -141,7 +151,7 @@ void	report_stats_interfaces(FILE *file, int now)
 		time1=0,
 		time5=0,
 		time15=0;
-	float
+	double
 		sent=0,
 		sent1=0,
 		sent5=0,
@@ -216,7 +226,7 @@ void	report_stats_interfaces(FILE *file, int now)
 		}
 		if((sent!=0)&&(sent1!=0))
 		{
-			fprintf(file,"netloadout1[%s] %f\n", interfaces[i].interface, (float)((sent-sent1)/(now-time1)));
+			fprintf(file,"netloadout1[%s] " ZBX_FS_DBL "\n", interfaces[i].interface, (double)((sent-sent1)/(now-time1)));
 		}
 		else
 		{
@@ -224,7 +234,7 @@ void	report_stats_interfaces(FILE *file, int now)
 		}
 		if((sent!=0)&&(sent5!=0))
 		{
-			fprintf(file,"netloadout5[%s] %f\n", interfaces[i].interface, (float)((sent-sent5)/(now-time5)));
+			fprintf(file,"netloadout5[%s] " ZBX_FS_DBL "\n", interfaces[i].interface, (double)((sent-sent5)/(now-time5)));
 		}
 		else
 		{
@@ -232,7 +242,7 @@ void	report_stats_interfaces(FILE *file, int now)
 		}
 		if((sent!=0)&&(sent15!=0))
 		{
-			fprintf(file,"netloadout15[%s] %f\n", interfaces[i].interface, (float)((sent-sent15)/(now-time15)));
+			fprintf(file,"netloadout15[%s] " ZBX_FS_DBL "\n", interfaces[i].interface, (double)((sent-sent15)/(now-time15)));
 		}
 		else
 		{
@@ -240,7 +250,7 @@ void	report_stats_interfaces(FILE *file, int now)
 		}
 		if((received!=0)&&(received1!=0))
 		{
-			fprintf(file,"netloadin1[%s] %f\n", interfaces[i].interface, (float)((received-received1)/(now-time1)));
+			fprintf(file,"netloadin1[%s] " ZBX_FS_DBL "\n", interfaces[i].interface, (double)((received-received1)/(now-time1)));
 		}
 		else
 		{
@@ -248,7 +258,7 @@ void	report_stats_interfaces(FILE *file, int now)
 		}
 		if((received!=0)&&(received5!=0))
 		{
-			fprintf(file,"netloadin5[%s] %f\n", interfaces[i].interface, (float)((received-received5)/(now-time5)));
+			fprintf(file,"netloadin5[%s] " ZBX_FS_DBL "\n", interfaces[i].interface, (double)((received-received5)/(now-time5)));
 		}
 		else
 		{
@@ -256,7 +266,7 @@ void	report_stats_interfaces(FILE *file, int now)
 		}
 		if((received!=0)&&(received15!=0))
 		{
-			fprintf(file,"netloadin15[%s] %f\n", interfaces[i].interface, (float)((received-received15)/(now-time15)));
+			fprintf(file,"netloadin15[%s] " ZBX_FS_DBL "\n", interfaces[i].interface, (double)((received-received15)/(now-time15)));
 		}
 		else
 		{
@@ -267,13 +277,13 @@ void	report_stats_interfaces(FILE *file, int now)
 }
 
 
-void	add_values_interfaces(int now,char *interface,float value_sent,float value_received)
+void	add_values_interfaces(int now,char *interface,double value_sent,double value_received)
 {
 	int i,j;
 
 	int bounced;
 
-/*	printf("Add_values [%s] [%f] [%f]\n",interface,value_sent,value_received);*/
+/*	printf("Add_values [%s] [" ZBX_FS_DBL "] [" ZBX_FS_DBL "]\n",interface,value_sent,value_received);*/
 
 	for(i=0;i<MAX_INTERFACE;i++)
 	{
@@ -330,7 +340,7 @@ void	collect_stats_interfaces(FILE *outfile)
 	int	i1,j1;
 	char	interface[MAX_STRING_LEN];
 	int	now;
-	float	received=0,sent;
+	double	received=0,sent;
 
 	/* Must be static */
 	static	int initialised=0;
@@ -343,10 +353,9 @@ void	collect_stats_interfaces(FILE *outfile)
 
 	now=time(NULL);
 
-	file=fopen("/proc/net/dev","r");
-	if(NULL == file)
+	if(NULL == (file = fopen("/proc/net/dev","r") ))
 	{
-		fprintf(stderr, "Cannot open config file [%s] [%s]\n","/proc/net/dev", strerror(errno));
+		zbx_error("Cannot open statistic file [%s] [%s].","/proc/net/dev", strerror(errno));
 		return;
 	}
 
@@ -356,8 +365,7 @@ void	collect_stats_interfaces(FILE *outfile)
 	{
 		if( (s=strstr(line,":")) == NULL)
 			continue;
-		zbx_strlcpy(interface,line,s-line);
-		interface[s-line]=0;
+		zbx_strncpy(interface,line,s-line+1);
 		j1=0;
 		for(i1=0;i1<(int)strlen(interface);i1++)
 		{
@@ -388,9 +396,12 @@ void	collect_stats_interfaces(FILE *outfile)
 		}
 		i++;
 	}
-	fclose(file);
+	zbx_fclose(file);
 
 	report_stats_interfaces(outfile, now);
 
 #endif /* HAVE_PROC_NET_DEV */
 }
+
+#endif /* TODO */
+
