@@ -20,6 +20,10 @@
 #ifndef ZABBIX_LOGFILES_H
 #define ZABBIX_LOGFILES_H
 
-int   process_log(char *filename,long *lastlogsize, char *value);
+int   process_log(
+	char *filename,
+	long *lastlogsize,
+	char **value
+	);
 
 #endif
