@@ -741,7 +741,7 @@ void	execute_operations(DB_EVENT *event, DB_ACTION *action)
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
  *                                                                            *
- * Comments: we check also trigger dependencies                               *
+ * Comments: dependencies are checked in a different place                    *
  *                                                                            *
  ******************************************************************************/
 void	process_actions(DB_EVENT *event)
@@ -755,31 +755,6 @@ void	process_actions(DB_EVENT *event)
 		(event->source == EVENT_SOURCE_TRIGGERS)?"TRIGGERS":"DISCOVERY",
 		event->eventid);
 
-/*      Do not react on any events if we depend on other trigger */
-/*	if(TRIGGER_VALUE_TRUE == event->value)*/
-/*	For events generated by triggers only */
-	if(event->source == EVENT_SOURCE_TRIGGERS)
-	{
-		zabbix_log( LOG_LEVEL_DEBUG, "Check dependencies");
-
-		result = DBselect("select count(*) from trigger_depends d,triggers t where d.triggerid_down=" ZBX_FS_UI64 " and d.triggerid_up=t.triggerid and t.value=%d",
-			event->objectid,
-			TRIGGER_VALUE_TRUE);
-		row=DBfetch(result);
-		if(row && DBis_null(row[0]) != SUCCEED)
-		{
-			if(atoi(row[0])>0)
-			{
-				zabbix_log( LOG_LEVEL_DEBUG, "Will not apply actions");
-				DBfree_result(result);
-				return;
-			}
-		}
-		DBfree_result(result);
-	}
-
-	zabbix_log( LOG_LEVEL_DEBUG, "Processing actions");
-
 	result = DBselect("select actionid,evaltype,status,eventsource from actions where status=%d and eventsource=%d and" ZBX_COND_NODEID,
 		ACTION_STATUS_ACTIVE,
 		event->source,
